@@ -46,10 +46,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+#if !defined(_OS_WIN32_)
+#include <stdint.h>
+#endif
+
 #if defined(_OS_SUN_) && defined(_CC_GNU_)
 #include <strings.h>
 #endif
 
+
 class QGString;
 
 /*****************************************************************************
@@ -86,10 +91,10 @@ Q_EXPORT void *qmemmove( void *dst, const void *src, uint len );
 Q_EXPORT char *qstrdup( const char * );
 
 Q_EXPORT inline uint cstrlen( const char *str )
-{ return strlen(str); }
+{ return (uint)strlen(str); }
 
 Q_EXPORT inline uint qstrlen( const char *str )
-{ return str ? strlen(str) : 0; }
+{ return str ? (uint)strlen(str) : 0; }
 
 Q_EXPORT inline char *cstrcpy( char *dst, const char *src )
 { return strcpy(dst,src); }
@@ -97,25 +102,26 @@ Q_EXPORT inline char *cstrcpy( char *dst, const char *src )
 Q_EXPORT inline char *qstrcpy( char *dst, const char *src )
 { return src ? strcpy(dst, src) : 0; }
 
-Q_EXPORT char *qstrncpy( char *dst, const char *src, uint len );
+Q_EXPORT char * qstrncpy(char *src,const char *dst, uint len);
 
 Q_EXPORT inline int cstrcmp( const char *str1, const char *str2 )
 { return strcmp(str1,str2); }
 
 Q_EXPORT inline int qstrcmp( const char *str1, const char *str2 )
-{ return (str1 && str2) ? strcmp(str1,str2) : (int)((long)str2 - (long)str1); }
+{ return (str1 && str2) ? strcmp(str1,str2) : (int)((intptr_t)str2 - (intptr_t)str1); }
 
 Q_EXPORT inline int cstrncmp( const char *str1, const char *str2, uint len )
 { return strncmp(str1,str2,len); }
 
 Q_EXPORT inline int qstrncmp( const char *str1, const char *str2, uint len )
 { return (str1 && str2) ? strncmp(str1,str2,len) :
-			  (int)((long)str2 - (long)str1); }
+			  (int)((intptr_t)str2 - (intptr_t)str1); }
 
-Q_EXPORT int qstricmp( const char *, const char * );
+Q_EXPORT int qstricmp( const char *str1, const char *str2 );
 
-Q_EXPORT int qstrnicmp( const char *, const char *, uint len );
+Q_EXPORT int qstrnicmp( const char *str1, const char *str2, uint len );
 
+#if 0
 // ### TODO for 3.0: these and the cstr* functions should be used if
 //                   !defined(QT_CLEAN_NAMESPACE)
 //                   We want to keep source compatibility for 2.x
@@ -141,6 +147,7 @@ Q_EXPORT int qstrnicmp( const char *, const char *, uint len );
 #undef	strnicmp
 #define strnicmp qstrnicmp
 
+#endif
 #endif
 
 // qChecksum: Internet checksum
@@ -204,6 +211,7 @@ public:
 
     int		find( char c, int index=0, bool cs=TRUE ) const;
     int		find( const char *str, int index=0, bool cs=TRUE ) const;
+    int		find( const QCString &str, int index=0, bool cs=TRUE ) const;
     int		find( const QRegExp &, int index=0 ) const;
     int		findRev( char c, int index=-1, bool cs=TRUE) const;
     int		findRev( const char *str, int index=-1, bool cs=TRUE) const;
@@ -272,28 +280,33 @@ inline void QCString::duplicate( const QCString &s )
 {
   if (!s.isEmpty()) 
   {
-    uint l = strlen(s.data());
+    uint l = (uint)strlen(s.data());
     m_data = (char *)malloc(l+1);
     if (m_data) memcpy(m_data,s.data(),l+1);
   }
   else 
+  {
     m_data=0; 
+  }
 }
 
 inline void QCString::duplicate( const char *str)
 {
   if (str && str[0]!='\0') 
   {
-    uint l = strlen(str);
+    uint l = (uint)strlen(str);
     m_data = (char *)malloc(l+1);
     if (m_data) memcpy(m_data,str,l+1);
   }
   else 
+  {
     m_data=0;
+  }
 }
 
 inline QCString &QCString::duplicate( const char *str, int)
 {
+  if (m_data==str) return *this;
   if (m_data) free(m_data);
   duplicate(str);
   return *this;
@@ -447,5 +460,15 @@ Q_EXPORT inline QCString operator+( char c1, const QCString &s2 )
     return tmp;
 }
 
+inline const char *qPrint(const char *s)
+{
+  if (s) return s; else return "";
+}
+
+inline const char *qPrint(const QCString &s)
+{
+  if (!s.isEmpty()) return s.data(); else return "";
+}
+
 
 #endif // QCSTRING_H
