@@ -70,8 +70,34 @@
 //   UNIX	- Any UNIX bsd/sysv system
 //
 
-#if defined(macintosh)
+#if defined(__APPLE__) || defined(macintosh)
 #define _OS_MAC_
+#  ifdef MAC_OS_X_VERSION_MIN_REQUIRED
+#    undef MAC_OS_X_VERSION_MIN_REQUIRED
+#  endif
+#  define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_3
+#  include <AvailabilityMacros.h>
+#  if !defined(MAC_OS_X_VERSION_10_3)
+#     define MAC_OS_X_VERSION_10_3 MAC_OS_X_VERSION_10_2 + 10
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_4)
+#       define MAC_OS_X_VERSION_10_4 MAC_OS_X_VERSION_10_3 + 10
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_5)
+#       define MAC_OS_X_VERSION_10_5 MAC_OS_X_VERSION_10_4 + 10
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_6)
+#       define MAC_OS_X_VERSION_10_6 MAC_OS_X_VERSION_10_5 + 10
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_7)
+#       define MAC_OS_X_VERSION_10_7 MAC_OS_X_VERSION_10_6 + 10
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_8)
+#       define MAC_OS_X_VERSION_10_8 MAC_OS_X_VERSION_10_7 + 10
+#  endif
+#  if (MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_8)
+#    warning "This version of Mac OS X is unsupported"
+#  endif
 #elif defined(MSDOS) || defined(_MSDOS) || defined(__MSDOS__)
 #define _OS_MSDOS_
 #elif defined(OS2) || defined(_OS2) || defined(__OS2__)
@@ -262,6 +288,19 @@
 #error "Qt has not been tested with this compiler - talk to qt-bugs@trolltech.com"
 #endif
 
+// detect Microsoft compiler version
+#ifdef _CC_MSVC_
+#if _MSC_VER >= 1400
+#define _CC_V2005
+#elif _MSC_VER >= 1310
+#define _CC_V2003
+#elif _MSC_VER > 1300
+#define _CC_V2002
+#else
+#define _CC_V1998
+#endif 
+#endif
+
 #ifndef Q_PACKED
 #define Q_PACKED
 #endif
@@ -336,6 +375,13 @@ typedef unsigned long	ulong;
 typedef char	       *pchar;
 typedef uchar	       *puchar;
 typedef const char     *pcchar;
+#if defined(_OS_WIN32_) && !defined(_CC_GNU_)
+typedef __int64            int64;
+typedef unsigned __int64   uint64;
+#else
+typedef long long          int64;
+typedef unsigned long long uint64;
+#endif
 
 
 //
