@@ -3,7 +3,7 @@
  * $Id: bufstr.h,v 1.85 2000/11/18 12:58:19 root Exp $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,10 +18,6 @@
 #ifndef _BUFSTR_H
 #define _BUFSTR_H
 
-#include "qtbc.h"
-#include <stdio.h>
-#include <stdlib.h>
-
 /*! @brief Buffer used to store strings
  *  
  *  This buffer is used append characters and strings. It will automatically
