@@ -2,7 +2,7 @@
  *
  * $Id: classlist.cpp,v 1.14 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,6 +22,8 @@
 #include "language.h"
 #include "doxygen.h"
 #include "vhdldocgen.h"
+#include "defargs.h"
+#include "arguments.h"
 
 ClassList::ClassList() : QList<ClassDef>()
 {
@@ -39,22 +41,22 @@ static int compItems(void *item1,void *item2)
   //printf("compItems: %d %s<->%s\n",b,c1->name().data(),c2->name().data());
   if (b) 
   { 
-     return stricmp(c1->name(),
+     return qstricmp(c1->name(),
                     c2->name());
   }
   else
   {
-     return stricmp(c1->className(),
+     return qstricmp(c1->className(),
                     c2->className());
   }
 }
 
-int ClassList::compareItems(GCI item1, GCI item2)
+int ClassList::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   return compItems(item1,item2);
 }
 
-int ClassSDict::compareItems(GCI item1, GCI item2)
+int ClassSDict::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   return compItems(item1,item2);
 }
@@ -96,6 +98,7 @@ bool ClassSDict::declVisible(const ClassDef::CompoundType *filter) const
 void ClassSDict::writeDeclaration(OutputList &ol,const ClassDef::CompoundType *filter,
                                   const char *header,bool localNames)
 {
+  static bool extractPrivate = Config_getBool("EXTRACT_PRIVATE");
   if (count()>0)
   {
     ClassSDict::Iterator sdi(*this);
@@ -105,6 +108,8 @@ void ClassSDict::writeDeclaration(OutputList &ol,const ClassDef::CompoundType *f
     {
       //printf("  ClassSDict::writeDeclaration for %s\n",cd->name().data());
       if (cd->name().find('@')==-1 && 
+          !cd->isExtension() && 
+          (cd->protection()!=Private || extractPrivate) &&
           (filter==0 || *filter==cd->compoundType())
          )
       {
@@ -161,3 +166,54 @@ void ClassSDict::writeDocumentation(OutputList &ol,Definition * container)
   }
 }
 
+//-------------------------------------------
+
+void GenericsSDict::insert(const QCString &key,ClassDef *cd)
+{
+  int i=key.find('<');
+  if (i==-1) return;
+  ArgumentList argList;
+  stringToArgumentList(key.mid(i),&argList);
+  int c = argList.count();
+  if (c==0) return;
+  GenericsCollection *collection = m_dict.find(key.left(i));
+  if (collection==0) // new name
+  {
+    collection = new GenericsCollection;
+    m_dict.append(key.left(i),collection);
+  }
+  if (collection->find(c)==0) // should always be 0!
+  {
+    collection->insert(c,cd);
+  }
+}
+
+ClassDef *GenericsSDict::find(const QCString &key)
+{
+  int i=key.find('<');
+  if (i==-1)
+  {
+    GenericsCollection *collection = m_dict.find(key);
+    if (collection && collection->count()==1)
+    {
+      QIntDictIterator<ClassDef> it(*collection);
+      return it.current();
+    }
+  }
+  else
+  {
+    GenericsCollection *collection = m_dict.find(key.left(i));
+    if (collection)
+    {
+      ArgumentList argList;
+      stringToArgumentList(key.mid(i),&argList);
+      int c = argList.count();
+      return collection->find(c);
+    }
+  }
+  return 0;
+}
+
+
+
+
