@@ -2,7 +2,7 @@
  *
  * $Id: code.h,v 1.9 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,17 +18,14 @@
 #ifndef CODE_H
 #define CODE_H
 
-#include "qtbc.h"
-#include <stdio.h>
-
 class CodeOutputInterface;
 class FileDef;
 class MemberDef;
 
 void parseCCode(CodeOutputInterface &,const char *,const QCString &, 
-            bool ,const char *,FileDef *fd=0,
-            int startLine=-1,int endLine=-1,bool inlineFragment=FALSE,
-            MemberDef *memberDef=0,bool showLineNumbers=TRUE);
+            bool ,const char *,FileDef *fd,
+            int startLine,int endLine,bool inlineFragment,
+            MemberDef *memberDef,bool showLineNumbers,Definition *searchCtx);
 void resetCCodeParserState();
 void codeFreeScanner();
 
