@@ -2,7 +2,7 @@
  *
  * $Id: debug.cpp,v 1.7 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,11 +20,11 @@
 
 #include <qdict.h>
 
-#include "qtbc.h"
 #include "debug.h"
 
 //------------------------------------------------------------------------
 
+/** Helper struct representing a mapping from debug label to a debug ID */
 struct LabelMap
 {
   const char *name;
@@ -44,9 +44,12 @@ static LabelMap s_labels[] =
   { "printtree",    Debug::PrintTree    },
   { "time",         Debug::Time         },
   { "extcmd",       Debug::ExtCmd       },
+  { "markdown",     Debug::Markdown     },
+  { "filteroutput", Debug::FilterOutput },
   { 0,             (Debug::DebugMask)0  }
 };
 
+/** Class representing a mapping from debug labels to debug IDs. */
 class LabelMapper
 {
   public:
