@@ -2,7 +2,7 @@
  *
  * $Id: define.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,12 +18,12 @@
 #ifndef DEFINE_H
 #define DEFINE_H
 
-#include "qtbc.h"
 #include <qdict.h>
 #include <qlist.h>
 
 class FileDef;
 
+/** A class representing a macro definition. */
 class Define
 {
   public:
@@ -47,45 +47,51 @@ class Define
     bool nonRecursive;
 };
 
+/** A list of Define objects. */
 class DefineList : public QList<Define>
 {
   public:
     DefineList() : QList<Define>() {}
    ~DefineList() {}
-    int compareItems(GCI i1,GCI i2) 
+    int compareItems(QCollection::Item i1,QCollection::Item i2) 
     {
-      return stricmp(((Define *)i1)->name,((Define *)i2)->name); 
+      return qstricmp(((Define *)i1)->name,((Define *)i2)->name); 
     }
 };
 
+/** A list of Define objects associated with a specific name. */
 class DefineName : public QList<Define>
 {
   public:
     DefineName(const char *n) : QList<Define>() { name=n; }
    ~DefineName() {}
     const char *nameString() const { return name; }
-    int compareItems(GCI i1,GCI i2) 
+    int compareItems(QCollection::Item i1,QCollection::Item i2) 
     {
-      return stricmp(((Define *)i1)->name,((Define *)i2)->name); 
+      return qstricmp(((Define *)i1)->name,((Define *)i2)->name); 
     }
     
   private:
     QCString name;
 };
 
+/** A list of DefineName objects. */
 class DefineNameList : public QList<DefineName>
 {
   public:
     DefineNameList() : QList<DefineName>() {}
    ~DefineNameList() {}
-    int compareItems(GCI i1,GCI i2)
+    int compareItems(QCollection::Item i1,QCollection::Item i2)
     {
-      return stricmp(((DefineName *)i1)->nameString(),
+      return qstricmp(((DefineName *)i1)->nameString(),
                     ((DefineName *)i2)->nameString());
     }
 };
 
+/** An unsorted dictionary of Define objects. */
 typedef QDict<Define> DefineDict;
+
+/** A sorted dictionary of DefineName object. */
 typedef QDict<DefineName> DefineNameDict;
 
 #endif
