@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,7 +15,6 @@
  *
  */
 
-#include "qtbc.h"
 #include <ctype.h>
 #include <qregexp.h>
 #include "md5.h"
@@ -38,6 +37,10 @@
 #include "marshal.h"
 #include "debug.h"
 #include "vhdldocgen.h"
+#include "memberlist.h"
+#include "namespacedef.h"
+#include "filedef.h"
+#include "dirdef.h"
 
 #define START_MARKER 0x4445465B // DEF[
 #define END_MARKER   0x4445465D // DEF]
@@ -45,7 +48,7 @@
 //-----------------------------------------------------------------------------------------
 
 
-/** Private data associated with a Definition object. */
+/** Private data associated with a Symbol Definition object. */
 class DefinitionImpl
 {
   public:
@@ -292,6 +295,85 @@ Definition::Definition(const char *df,int dl,
   }
 }
 
+Definition::Definition(const Definition &d) : DefinitionIntf(), LockableObj()
+{
+  m_name = d.m_name;
+  m_defLine = d.m_defLine;
+  m_impl = new DefinitionImpl;
+  *m_impl = *d.m_impl;
+  m_impl->sectionDict = 0;
+  m_impl->sourceRefByDict = 0;
+  m_impl->sourceRefsDict = 0;
+  m_impl->partOfGroups = 0;
+  m_impl->xrefListItems = 0;
+  m_impl->brief = 0;
+  m_impl->details = 0;
+  m_impl->body = 0;
+  m_impl->inbodyDocs = 0;
+  if (d.m_impl->sectionDict)
+  {
+    m_impl->sectionDict = new SectionDict(17);
+    SDict<SectionInfo>::Iterator it(*d.m_impl->sectionDict);
+    SectionInfo *si;
+    for (it.toFirst();(si=it.current());++it)
+    {
+      m_impl->sectionDict->append(si->label,si);
+    }
+  }
+  if (d.m_impl->sourceRefByDict)
+  {
+    m_impl->sourceRefByDict = new MemberSDict;
+    MemberSDict::IteratorDict it(*d.m_impl->sourceRefByDict);
+    MemberDef *md;
+    for (it.toFirst();(md=it.current());++it)
+    {
+      m_impl->sourceRefByDict->append(it.currentKey(),md);
+    }
+  }
+  if (d.m_impl->sourceRefsDict)
+  {
+    m_impl->sourceRefsDict = new MemberSDict;
+    MemberSDict::IteratorDict it(*d.m_impl->sourceRefsDict);
+    MemberDef *md;
+    for (it.toFirst();(md=it.current());++it)
+    {
+      m_impl->sourceRefsDict->append(it.currentKey(),md);
+    }
+  }
+  if (d.m_impl->partOfGroups)
+  {
+    GroupListIterator it(*d.m_impl->partOfGroups);
+    GroupDef *gd;
+    for (it.toFirst();(gd=it.current());++it)
+    {
+      makePartOfGroup(gd);
+    }
+  }
+  if (d.m_impl->xrefListItems)
+  {
+    setRefItems(d.m_impl->xrefListItems);
+  }
+  if (d.m_impl->brief)
+  {
+    m_impl->brief = new BriefInfo(*d.m_impl->brief);
+  }
+  if (d.m_impl->details)
+  {
+    m_impl->details = new DocInfo(*d.m_impl->details);
+  }
+  if (d.m_impl->body)
+  {
+    m_impl->body = new BodyInfo(*d.m_impl->body);
+  }
+  if (d.m_impl->inbodyDocs)
+  {
+    m_impl->details = new DocInfo(*d.m_impl->inbodyDocs);
+  }
+
+  m_isSymbol = d.m_isSymbol;
+  if (m_isSymbol) addToMap(m_name,this);
+}
+
 Definition::~Definition()
 {
   if (m_isSymbol) 
@@ -321,12 +403,12 @@ void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
   {
     //printf("Add section `%s' to definition `%s'\n",
     //    si->label.data(),name().data());
-    SectionInfo *gsi=Doxygen::sectionDict.find(si->label);
+    SectionInfo *gsi=Doxygen::sectionDict->find(si->label);
     //printf("===== label=%s gsi=%p\n",si->label.data(),gsi);
     if (gsi==0)
     {
       gsi = new SectionInfo(*si);
-      Doxygen::sectionDict.append(si->label,gsi);
+      Doxygen::sectionDict->append(si->label,gsi);
     }
     if (m_impl->sectionDict==0) 
     {
@@ -384,19 +466,19 @@ void Definition::addSectionsToIndex()
       {
         for (i=level;i<nextLevel;i++)
         {
-          Doxygen::indexList.incContentsDepth();
+          Doxygen::indexList->incContentsDepth();
         }
       }
       else if (nextLevel<level)
       {
         for (i=nextLevel;i<level;i++)
         {
-          Doxygen::indexList.decContentsDepth();
+          Doxygen::indexList->decContentsDepth();
         }
       }
       QCString title = si->title;
       if (title.isEmpty()) title = si->label;
-      Doxygen::indexList.addContentsItem(TRUE,title,
+      Doxygen::indexList->addContentsItem(TRUE,title,
                                          getReference(),
                                          getOutputFileBase(),
                                          si->label,
@@ -407,68 +489,11 @@ void Definition::addSectionsToIndex()
   }
   while (level>1)
   {
-    Doxygen::indexList.decContentsDepth();
+    Doxygen::indexList->decContentsDepth();
     level--;
   }
 }
 
-void Definition::writeToc(OutputList &ol)
-{
-  makeResident();
-  if (m_impl->sectionDict==0) return;
-  ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Html);
-  ol.writeString("<div class=\"toc\">");
-  ol.writeString("<h3>");
-  ol.writeString(theTranslator->trRTFTableOfContents());
-  ol.writeString("</h3>\n");
-  ol.writeString("<ul>");
-  SDict<SectionInfo>::Iterator li(*m_impl->sectionDict);
-  SectionInfo *si;
-  int level=1;
-  char cs[2];
-  cs[1]='\0';
-  bool inLi[5]={ FALSE, FALSE, FALSE, FALSE };
-  for (li.toFirst();(si=li.current());++li)
-  {
-    if (si->type==SectionInfo::Section       || 
-        si->type==SectionInfo::Subsection    || 
-        si->type==SectionInfo::Subsubsection ||
-        si->type==SectionInfo::Paragraph)
-    {
-      //printf("  level=%d title=%s\n",level,si->title.data());
-      int nextLevel = (int)si->type;
-      if (nextLevel>level)
-      {
-        ol.writeString("<ul>");
-      }
-      else if (nextLevel<level)
-      {
-        if (inLi[level]) ol.writeString("</li>\n");
-        inLi[level]=FALSE;
-        ol.writeString("</ul>\n");
-      }
-      cs[0]='0'+nextLevel;
-      if (inLi[nextLevel]) ol.writeString("</li>\n");
-      ol.writeString("<li class=\"level"+QCString(cs)+"\"><a href=\"#"+si->label+"\">"+si->title+"</a>");
-      inLi[nextLevel]=TRUE;
-      level = nextLevel;
-    }
-  }
-  while (level>1)
-  {
-    if (inLi[level]) ol.writeString("</li>\n");
-    inLi[level]=FALSE;
-    ol.writeString("</ul>\n");
-    level--;
-  }
-  if (inLi[level]) ol.writeString("</li>\n");
-  inLi[level]=FALSE;
-  ol.writeString("</ul>\n");
-  ol.writeString("</div>\n");
-  ol.popGeneratorState();
-}
-
 void Definition::writeDocAnchorsToTagFile()
 {
   makeResident();
@@ -484,7 +509,12 @@ void Definition::writeDocAnchorsToTagFile()
         //printf("write an entry!\n");
         if (definitionType()==TypeMember) Doxygen::tagFile << "  ";
         Doxygen::tagFile << "    <docanchor file=\"" 
-                         << si->fileName << "\">" << si->label 
+                         << si->fileName << "\"";
+        if (!si->title.isEmpty())
+        {
+          Doxygen::tagFile << " title=\"" << convertToXML(si->title) << "\"";
+        }
+        Doxygen::tagFile << ">" << si->label 
                          << "</docanchor>" << endl;
       }
     }
@@ -669,7 +699,7 @@ void Definition::setInbodyDocumentation(const char *d,const char *inbodyFile,int
  * The line actually containing the bracket is returned via endLine.
  * Note that for VHDL code the bracket search is not done.
  */
-static bool readCodeFragment(const char *fileName,
+bool readCodeFragment(const char *fileName,
                       int &startLine,int &endLine,QCString &result)
 {
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
@@ -978,11 +1008,12 @@ void Definition::setBodyDef(FileDef *fd)
 /*! Write code of this definition into the documentation */
 void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
 {
+  static bool inlineSources = Config_getBool("INLINE_SOURCES");
   makeResident();
   ol.pushGeneratorState();
   //printf("Source Fragment %s: %d-%d bodyDef=%p\n",name().data(),
   //        m_startBodyLine,m_endBodyLine,m_bodyDef);
-  if (Config_getBool("INLINE_SOURCES") && 
+  if (inlineSources && 
       m_impl->body && m_impl->body->startLine!=-1 && 
       m_impl->body->endLine>=m_impl->body->startLine && m_impl->body->fileDef)
   {
@@ -1001,7 +1032,7 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
       if (definitionType()==TypeMember) thisMd = (MemberDef *)this;
 
       // vhdl  parser can' t start at an arbitrary point in the source code
-      if(this->getLanguage()==SrcLangExt_VHDL)
+      if (getLanguage()==SrcLangExt_VHDL)
       {
         if (thisMd) VhdlDocGen::writeCodeFragment(ol,actualStart,codeFragment,thisMd);
         return;
@@ -1018,7 +1049,7 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
                        actualEnd,        // endLine
                        TRUE,             // inlineFragment
                        thisMd,           // memberDef
-                       FALSE             // show line numbers
+                       TRUE              // show line numbers
                       );
       ol.endCodeFragment();
     }
@@ -1297,6 +1328,7 @@ QCString Definition::qualifiedName() const
 void Definition::setOuterScope(Definition *d) 
 {
   makeResident();
+  //printf("%s::setOuterScope(%s)\n",name().data(),d?d->name().data():"<none>");
   if (m_impl->outerScope!=d)
   { 
     m_impl->qualifiedName.resize(0); // flush cached scope name
@@ -1373,7 +1405,7 @@ int Definition::_getXRefListId(const char *listName) const
     ListItemInfo *lii;
     for (slii.toFirst();(lii=slii.current());++slii)
     {
-      if (strcmp(lii->type,listName)==0)
+      if (qstrcmp(lii->type,listName)==0)
       {
         return lii->itemId;
       }
@@ -1433,6 +1465,9 @@ QCString Definition::pathFragment() const
   return result;
 }
 
+//----------------------------------------------------------------------------------------
+
+// TODO: move to htmlgen
 /*! Returns the string used in the footer for $navpath when 
  *  GENERATE_TREEVIEW is enabled
  */
@@ -1440,9 +1475,11 @@ QCString Definition::navigationPathAsString() const
 {
   makeResident();
   QCString result;
-  if (m_impl->outerScope && m_impl->outerScope!=Doxygen::globalScope)
+  Definition *outerScope = getOuterScope();
+  QCString locName = localName();
+  if (outerScope && outerScope!=Doxygen::globalScope)
   {
-    result+=m_impl->outerScope->navigationPathAsString();
+    result+=outerScope->navigationPathAsString();
   }
   else if (definitionType()==Definition::TypeFile && ((const FileDef*)this)->getDirDef())
   {
@@ -1453,39 +1490,40 @@ QCString Definition::navigationPathAsString() const
   {
     if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
     {
-      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+      result+="<a class=\"el\" href=\"$relpath^"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
               ((const GroupDef*)this)->groupTitle()+"</a>";
     }
     else if (definitionType()==Definition::TypePage && !((const PageDef*)this)->title().isEmpty())
     {
-      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+      result+="<a class=\"el\" href=\"$relpath^"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
               ((const PageDef*)this)->title()+"</a>";
     }
     else if (definitionType()==Definition::TypeClass)
     {
-      QCString name = m_impl->localName;
-      if (name.right(2)=="-p" || name.right(2)=="-g")
+      QCString name = locName;
+      if (name.right(2)=="-p" /*|| name.right(2)=="-g"*/)
       {
         name = name.left(name.length()-2);
       }
-      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension;
+      result+="<a class=\"el\" href=\"$relpath^"+getOutputFileBase()+Doxygen::htmlFileExtension;
       if (!anchor().isEmpty()) result+="#"+anchor();
       result+="\">"+name+"</a>";
     }
     else
     {
-      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
-              m_impl->localName+"</a>";
+      result+="<a class=\"el\" href=\"$relpath^"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+              locName+"</a>";
     }
   }
   else
   {
-    result+="<b>"+m_impl->localName+"</b>";
+    result+="<b>"+locName+"</b>";
   }
   result+="</li>";
   return result;
 }
 
+// TODO: move to htmlgen
 void Definition::writeNavigationPath(OutputList &ol) const
 {
   ol.pushGeneratorState();
@@ -1502,6 +1540,74 @@ void Definition::writeNavigationPath(OutputList &ol) const
   ol.popGeneratorState();
 }
 
+// TODO: move to htmlgen
+void Definition::writeToc(OutputList &ol)
+{
+  makeResident();
+  SectionDict *sectionDict = m_impl->sectionDict;
+  if (sectionDict==0) return;
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  ol.writeString("<div class=\"toc\">");
+  ol.writeString("<h3>");
+  ol.writeString(theTranslator->trRTFTableOfContents());
+  ol.writeString("</h3>\n");
+  ol.writeString("<ul>");
+  SDict<SectionInfo>::Iterator li(*sectionDict);
+  SectionInfo *si;
+  int level=1,l;
+  char cs[2];
+  cs[1]='\0';
+  bool inLi[5]={ FALSE, FALSE, FALSE, FALSE };
+  for (li.toFirst();(si=li.current());++li)
+  {
+    if (si->type==SectionInfo::Section       || 
+        si->type==SectionInfo::Subsection    || 
+        si->type==SectionInfo::Subsubsection ||
+        si->type==SectionInfo::Paragraph)
+    {
+      //printf("  level=%d title=%s\n",level,si->title.data());
+      int nextLevel = (int)si->type;
+      if (nextLevel>level)
+      {
+        for (l=level;l<nextLevel;l++)
+        {
+          ol.writeString("<ul>");
+        }
+      }
+      else if (nextLevel<level)
+      {
+        for (l=level;l>nextLevel;l--)
+        {
+          if (inLi[l]) ol.writeString("</li>\n");
+          inLi[l]=FALSE;
+          ol.writeString("</ul>\n");
+        }
+      }
+      cs[0]='0'+nextLevel;
+      if (inLi[nextLevel]) ol.writeString("</li>\n");
+      ol.writeString("<li class=\"level"+QCString(cs)+"\"><a href=\"#"+si->label+"\">"+si->title+"</a>");
+      inLi[nextLevel]=TRUE;
+      level = nextLevel;
+    }
+  }
+  while (level>1)
+  {
+    if (inLi[level]) ol.writeString("</li>\n");
+    inLi[level]=FALSE;
+    ol.writeString("</ul>\n");
+    level--;
+  }
+  if (inLi[level]) ol.writeString("</li>\n");
+  inLi[level]=FALSE;
+  ol.writeString("</ul>\n");
+  ol.writeString("</div>\n");
+  ol.popGeneratorState();
+}
+
+//----------------------------------------------------------------------------------------
+
+
 QCString Definition::symbolName() const 
 { 
   return m_symbolName; 
@@ -1773,17 +1879,18 @@ void Definition::setLanguage(SrcLangExt lang)
   m_impl->lang=lang; 
 }
 
-void Definition::makeResident() const
-{
-}
-
-//---------------
 
 void Definition::_setSymbolName(const QCString &name) 
 { 
   m_symbolName=name; 
 }
 
+//---------------
+
+void Definition::makeResident() const
+{
+}
+
 void Definition::flushToDisk() const
 {
   //printf("%p: Definition::flushToDisk()\n",this);
