@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,11 @@
 #ifndef DEFINITION_H
 #define DEFINITION_H
 
-#include "qtbc.h"
 #include <qlist.h>
 #include <qdict.h>
-#include <sys/types.h>
 
+#include "types.h"
 #include "lockingptr.h"
-#include "util.h"
 
 class FileDef;
 class OutputList;
@@ -37,7 +35,7 @@ struct ListItemInfo;
 struct SectionInfo;
 class Definition;
 class DefinitionImpl;
-
+  
 /** Data associated with a detailed description. */
 struct DocInfo
 {
@@ -336,8 +334,9 @@ class Definition : public DefinitionIntf, public LockableObj
     void lock() const {}
     void unlock() const {}
 
-  private: 
+    Definition(const Definition &d);
 
+  private: 
     static void addToMap(const char *name,Definition *d);
     static void removeFromMap(Definition *d);
 
@@ -363,9 +362,9 @@ class DefinitionList : public QList<Definition>, public DefinitionIntf
   public:
     ~DefinitionList() {}
     DefType definitionType() const { return TypeSymbolList; }
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return stricmp(((Definition *)item1)->name(),
+      return qstricmp(((Definition *)item1)->name(),
                      ((Definition *)item2)->name()
                     );
     }
@@ -381,4 +380,12 @@ class DefinitionListIterator : public QListIterator<Definition>
     ~DefinitionListIterator() {}
 };
 
+/** Reads a fragment from file \a fileName starting with line \a startLine
+ *  and ending with line \a endLine. The result is returned as a string 
+ *  via \a result. The function returns TRUE if successful and FALSE 
+ *  in case of an error.
+ */
+bool readCodeFragment(const char *fileName, 
+                      int &startLine,int &endLine,
+                      QCString &result);
 #endif
