@@ -3,7 +3,7 @@
  * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,7 +16,6 @@
  *
  */
 
-#include "qtbc.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <qlist.h>
@@ -33,6 +32,109 @@
 #include "doxygen.h"
 #include "portable.h"
 #include "index.h"
+#include "classlist.h"
+
+//-----------------------------------------------------------------------------
+
+class DiagramItemList;
+
+/** Class representing a single node in the built-in class diagram */
+class DiagramItem 
+{
+  public:
+    DiagramItem(DiagramItem *p,int number,ClassDef *cd,
+                Protection prot,Specifier virt,const char *ts);
+   ~DiagramItem();
+    QCString label() const;
+    QCString fileName() const;
+    DiagramItem *parentItem() { return parent; } 
+    DiagramItemList *getChildren() { return children; }
+    void move(int dx,int dy) { x+=dx; y+=dy; }
+    int xPos() const { return x; }
+    int yPos() const { return y; }
+    int avgChildPos() const;
+    int numChildren() const;
+    void addChild(DiagramItem *di);
+    int number() const { return num; }
+    Protection protection() const { return prot; }
+    Specifier virtualness() const { return virt; }
+    void putInList() { inList=TRUE; }
+    bool isInList() const { return inList; } 
+    ClassDef *getClassDef() const { return classDef; }
+  private:
+    DiagramItemList *children;
+    DiagramItem *parent;
+    int x,y;
+    int num;
+    Protection prot;
+    Specifier virt;
+    QCString templSpec;
+    bool inList;
+    ClassDef *classDef;
+};
+
+/** Class representing a list of DiagramItem object. */
+class DiagramItemList : public QList<DiagramItem>
+{
+  public:
+    DiagramItemList() : QList<DiagramItem>() {}
+   ~DiagramItemList() {}
+};
+
+/** Class representing a row in the built-in class diagram */
+class DiagramRow : public QList<DiagramItem> 
+{
+  public:
+    DiagramRow(TreeDiagram *d,int l) : QList<DiagramItem>() 
+    { 
+      diagram=d; 
+      level=l;
+      setAutoDelete(TRUE); 
+    }
+    void insertClass(DiagramItem *parent,ClassDef *cd,bool doBases,
+                     Protection prot,Specifier virt,const char *ts);
+    uint number() { return level; }
+  private:
+    TreeDiagram *diagram;
+    uint level;
+};
+
+/** Class representing iterator for the rows in the built-in class diagram. */
+class DiagramRowIterator : public QListIterator<DiagramRow>
+{
+  public:
+    DiagramRowIterator(const QList<DiagramRow> &d) 
+      : QListIterator<DiagramRow>(d) {}
+};
+
+/** Class represeting the tree layout for the built-in class diagram. */
+class TreeDiagram : public QList<DiagramRow>
+{
+  public:
+    TreeDiagram(ClassDef *root,bool doBases);
+   ~TreeDiagram();
+    void computeLayout();
+    uint computeRows();
+    //uint computeCols();
+    void moveChildren(DiagramItem *root,int dx);
+    void computeExtremes(uint *labelWidth,uint *xpos);
+    void drawBoxes(FTextStream &t,Image *image,
+                   bool doBase,bool bitmap,
+                   uint baseRows,uint superRows,
+                   uint cellWidth,uint cellHeight,
+                   QCString relPath="",
+                   bool generateMap=TRUE);
+    void drawConnectors(FTextStream &t,Image *image,
+                   bool doBase,bool bitmap,
+                   uint baseRows,uint superRows,
+                   uint cellWidth,uint cellheight);
+  private:
+    bool layoutTree(DiagramItem *root,int row);
+    TreeDiagram &operator=(const TreeDiagram &);
+    TreeDiagram(const TreeDiagram &);
+};
+
+
 
 //-----------------------------------------------------------------------------
 
@@ -209,7 +311,12 @@ QCString DiagramItem::label() const
   {
     // we use classDef->name() here and not diplayName() in order
     // to get the name used in the inheritance relation.
-    result=insertTemplateSpecifierInScope(classDef->name(),templSpec);
+    QCString n = classDef->name();
+    if (/*n.right(2)=="-g" ||*/ n.right(2)=="-p")
+    {
+      n = n.left(n.length()-2);
+    }
+    result=insertTemplateSpecifierInScope(n,templSpec);
   }
   else
   {
@@ -499,7 +606,7 @@ void TreeDiagram::drawBoxes(FTextStream &t,Image *image,
   while (dr && !done)
   {
     int x=0,y=0;
-    float xf=0.0,yf=0.0;
+    float xf=0.0f,yf=0.0f;
     DiagramItem *di=dr->first();
     if (di->isInList()) // put boxes in a list
     {
@@ -516,8 +623,8 @@ void TreeDiagram::drawBoxes(FTextStream &t,Image *image,
           }
           else
           {
-            if (doBase) yf += 1.0;
-            else        yf -= 1.0;
+            if (doBase) yf += 1.0f;
+            else        yf -= 1.0f;
           }
         }
         else
@@ -629,7 +736,7 @@ void TreeDiagram::drawConnectors(FTextStream &t,Image *image,
     if (di->isInList()) // row consists of list connectors
     {
       int x=0,y=0,ys=0;
-      float xf=0.0,yf=0.0,ysf=0.0;
+      float xf=0.0f,yf=0.0f,ysf=0.0f;
       while (di)
       {
         DiagramItem *pi=di->parentItem();
@@ -701,12 +808,12 @@ void TreeDiagram::drawConnectors(FTextStream &t,Image *image,
             if (doBase)
             {
               ysf = di->yPos()/(float)gridHeight+superRows-1;
-              yf = ysf + 0.5;
+              yf = ysf + 0.5f;
             }
             else
             {
-              ysf = (float)superRows-0.25-di->yPos()/(float)gridHeight;
-              yf = ysf - 0.25;
+              ysf = (float)superRows-0.25f-di->yPos()/(float)gridHeight;
+              yf = ysf - 0.25f;
             }
           }
           while (di!=last) // more children to add
@@ -734,12 +841,12 @@ void TreeDiagram::drawConnectors(FTextStream &t,Image *image,
               if (doBase)
               {
                 t << "1 " << xf << " " << yf << " hedge\n";
-                yf += 1.0;
+                yf += 1.0f;
               }
               else
               {
                 t << "0 " << xf << " " << yf << " hedge\n";
-                yf -= 1.0;
+                yf -= 1.0f;
               }
             }
             di=dr->next();
@@ -985,9 +1092,9 @@ void ClassDiagram::writeFigure(FTextStream &output,const char *path,
   uint estWidth  = cols*(20+QMAX(baseMaxLabelWidth,superMaxLabelWidth));
   //printf("Estimated size %d x %d\n",estWidth,estHeight);
   
-  const float pageWidth = 14.0; // estimated page width in cm.
-                                // Somewhat lower to deal with estimation
-                                // errors. 
+  const float pageWidth = 14.0f; // estimated page width in cm.
+                                 // Somewhat lower to deal with estimation
+                                 // errors. 
   
   // compute the image height in centimeters based on the estimates
   float realHeight = QMIN(rows,12); // real height in cm
@@ -1015,7 +1122,7 @@ void ClassDiagram::writeFigure(FTextStream &output,const char *path,
   f1.setName(epsName.data());
   if (!f1.open(IO_WriteOnly))
   {
-    err("Could not open file %s for writing\n",convertToQCString(f1.name()).data());
+    err("Could not open file %s for writing\n",f1.name().data());
     exit(1);
   }
   FTextStream t(&f1);
@@ -1294,7 +1401,7 @@ void ClassDiagram::writeImage(FTextStream &t,const char *path,
 
 #define IMAGE_EXT ".png"
   image.save((QCString)path+"/"+fileName+IMAGE_EXT);
-  Doxygen::indexList.addImageFile(QCString(fileName)+IMAGE_EXT);
+  Doxygen::indexList->addImageFile(QCString(fileName)+IMAGE_EXT);
   
   if (generateMap) t << "</map>" << endl;
 }
