@@ -10,6 +10,7 @@
 #include "dot.h"
 #include "layout.h"
 #include "ftextstream.h"
+#include "config.h"
 
 //----------------------------------------------------------------------
 // method implementation
@@ -18,8 +19,8 @@ static int g_dirCount=0;
 
 DirDef::DirDef(const char *path) : Definition(path,1,path)
 {
+  bool fullPathNames = Config_getBool("FULL_PATH_NAMES");
   // get display name (stipping the paths mentioned in STRIP_FROM_PATH)
-  m_dispName = stripFromPath(path);
   // get short name (last part of path)
   m_shortName = path;
   m_diskName = path;
@@ -33,6 +34,11 @@ DirDef::DirDef(const char *path) : Definition(path,1,path)
     m_shortName = m_shortName.mid(pi+1);
   }
   setLocalName(m_shortName);
+  m_dispName = fullPathNames ? stripFromPath(path) : m_shortName;
+  if (m_dispName.length()>0 && m_dispName.at(m_dispName.length()-1)=='/')
+  { // strip trailing /
+    m_dispName = m_dispName.left(m_dispName.length()-1);
+  }
   
   m_fileList   = new FileList;
   m_usedDirs   = new QDict<UsedDir>(257);
@@ -198,7 +204,7 @@ void DirDef::writeDirectoryGraph(OutputList &ol)
       ol.disable(OutputGenerator::Man);
       //ol.startParagraph();
       ol.startDirDepGraph();
-      ol.parseText(theTranslator->trDirDepGraph(displayName()));
+      ol.parseText(theTranslator->trDirDepGraph(shortName()));
       ol.endDirDepGraph(dirDep);
       //ol.endParagraph();
       ol.enableAll();
@@ -218,6 +224,7 @@ void DirDef::writeSubDirList(OutputList &ol)
     DirDef *dd=m_subdirs.first();
     while (dd)
     {
+      ol.startMemberDeclaration();
       ol.startMemberItem(dd->getOutputFileBase(),0);
       ol.parseText(theTranslator->trDir(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
@@ -239,6 +246,7 @@ void DirDef::writeSubDirList(OutputList &ol)
            );
         ol.endMemberDescription();
       }
+      ol.endMemberDeclaration(0,0);
       dd=m_subdirs.next();
     }
 
@@ -258,6 +266,7 @@ void DirDef::writeFileList(OutputList &ol)
     FileDef *fd=m_fileList->first();
     while (fd)
     {
+      ol.startMemberDeclaration();
       ol.startMemberItem(fd->getOutputFileBase(),0);
       ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
@@ -300,6 +309,7 @@ void DirDef::writeFileList(OutputList &ol)
            );
         ol.endMemberDescription();
       }
+      ol.endMemberDeclaration(0,0);
       fd=m_fileList->next();
     }
     ol.endMemberList();
@@ -353,6 +363,7 @@ void DirDef::writeDocumentation(OutputList &ol)
   
   //---------------------------------------- start flexible part -------------------------------
 
+  SrcLangExt lang = getLanguage();
   QListIterator<LayoutDocEntry> eli(
       LayoutDocManager::instance().docEntries(LayoutDocManager::Directory));
   LayoutDocEntry *lde;
@@ -381,7 +392,7 @@ void DirDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::DetailedDesc: 
         {
           LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
-          writeDetailedDescription(ol,ls->title);
+          writeDetailedDescription(ol,ls->title(lang));
         }
         break;
       case LayoutDocEntry::ClassIncludes:
@@ -564,12 +575,12 @@ bool DirDef::depGraphIsTrivial() const
 
 //----------------------------------------------------------------------
 
-int FilePairDict::compareItems(GCI item1,GCI item2)
+int FilePairDict::compareItems(QCollection::Item item1,QCollection::Item item2)
 {
   FilePair *left  = (FilePair*)item1;
   FilePair *right = (FilePair*)item2;
-  int orderHi = stricmp(left->source()->name(),right->source()->name());
-  int orderLo = stricmp(left->destination()->name(),right->destination()->name());
+  int orderHi = qstricmp(left->source()->name(),right->source()->name());
+  int orderLo = qstricmp(left->destination()->name(),right->destination()->name());
   return orderHi==0 ? orderLo : orderHi;
 }
 
@@ -618,7 +629,7 @@ bool DirDef::matchPath(const QCString &path,QStrList &l)
   while (s)
   {
     QCString prefix = s;
-    if (stricmp(prefix.left(path.length()),path)==0) // case insensitive compare
+    if (qstricmp(prefix.left(path.length()),path)==0) // case insensitive compare
     {
       return TRUE;
     }
@@ -638,7 +649,7 @@ DirDef *DirDef::mergeDirectoryInTree(const QCString &path)
   while ((i=path.find('/',p))!=-1)
   {
     QCString part=path.left(i+1);
-    if (!matchPath(part,Config_getList("STRIP_FROM_PATH")) && part!="/")
+    if (!matchPath(part,Config_getList("STRIP_FROM_PATH")) && (part!="/" && part!="//"))
     {
       dir=createNewDir(part); 
     }
@@ -774,7 +785,7 @@ static void computeCommonDirPrefix()
           QCString dirName = dir->name();
           if (dirName.length()>path.length())
           {
-            if (strncmp(dirName,path,l)!=0) // dirName does not start with path
+            if (qstrncmp(dirName,path,l)!=0) // dirName does not start with path
             {
               int i=path.findRev('/',l-2);
               if (i==-1) // no unique prefix -> stop
