@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -72,14 +72,15 @@ class DocRef;
 class DocFormula;
 class DocSecRefItem;
 class DocSecRefList;
-//class DocLanguage;
 class DocLinkedWord;
 class DocParamSect;
 class DocParamList;
 class DocInternalRef;
-class DocCopy;
+class DocCopy; // TODO: no longer generated => remove
 class DocText;
 class DocSimpleSectSep;
+class DocHtmlBlockQuote;
+class DocVhdlFlow;
 
 /*! @brief Abstract visitor that participates in the visitor pattern.
  */
@@ -171,8 +172,6 @@ class DocVisitor
     virtual void visitPost(DocSecRefItem *) = 0;
     virtual void visitPre(DocSecRefList *) = 0;
     virtual void visitPost(DocSecRefList *) = 0;
-    //virtual void visitPre(DocLanguage *) = 0;
-    //virtual void visitPost(DocLanguage *) = 0;
     virtual void visitPre(DocParamSect *) = 0;
     virtual void visitPost(DocParamSect *) = 0;
     virtual void visitPre(DocParamList *) = 0;
@@ -185,6 +184,10 @@ class DocVisitor
     virtual void visitPost(DocCopy *) = 0;
     virtual void visitPre(DocText *) = 0;
     virtual void visitPost(DocText *) = 0;
+    virtual void visitPre(DocHtmlBlockQuote *) = 0;
+    virtual void visitPost(DocHtmlBlockQuote *) = 0;
+    virtual void visitPre(DocVhdlFlow *) = 0;
+    virtual void visitPost(DocVhdlFlow *) = 0;
     /*! @} */
 };
 
