@@ -1,4 +1,4 @@
-"/* The standard CSS for doxygen */\n"
+"/* The standard CSS for doxygen $doxygenversion */\n"
 "\n"
 "body, table, div, p, dl {\n"
 "	font: 400 14px/19px Roboto,sans-serif;\n"
@@ -6,7 +6,7 @@
 "\n"
 "/* @group Heading Levels */\n"
 "\n"
-"h1 {\n"
+"h1.groupheader {\n"
 "	font-size: 150%;\n"
 "}\n"
 "\n"
@@ -16,7 +16,7 @@
 "	margin: 10px 2px;\n"
 "}\n"
 "\n"
-"h2 {\n"
+"h2.groupheader {\n"
 "	border-bottom: 1px solid ##99;\n"
 "	color: ##44;\n"
 "	font-size: 150%;\n"
@@ -27,7 +27,7 @@
 "	width: 100%;\n"
 "}\n"
 "\n"
-"h3 {\n"
+"h3.groupheader {\n"
 "	font-size: 100%;\n"
 "}\n"
 "\n"
@@ -455,8 +455,11 @@
 "	color: #555;\n"
 "}\n"
 "\n"
-".memItemLeft, .memItemRight, .memTemplParams {\n"
-"	border-bottom: 1px solid ##E2;\n"
+".memSeparator {\n"
+"        border-bottom: 1px solid #DEE4F0;\n"
+"        line-height: 1px;\n"
+"        margin: 0px;\n"
+"        padding: 0px;\n"
 "}\n"
 "\n"
 ".memItemLeft, .memTemplItemLeft {\n"
@@ -470,6 +473,7 @@
 ".memTemplParams {\n"
 "	color: ##60;\n"
 "        white-space: nowrap;\n"
+"	font-size: 80%;\n"
 "}\n"
 "\n"
 "/* @end */\n"
@@ -648,12 +652,13 @@
 "        border-right:1px solid ##CC;\n"
 "        border-bottom:1px solid ##CC;\n"
 "	text-shadow: none;\n"
-"        color: white;\n"
-"        margin-right: 4px;\n"
-"        padding: 2px 3px;\n"
-"        border-radius: 3px;\n"
-"        font-size: 7pt;\n"
+"	color: white;\n"
+"	margin-right: 4px;\n"
+"	padding: 2px 3px;\n"
+"	border-radius: 3px;\n"
+"	font-size: 7pt;\n"
 "	white-space: nowrap;\n"
+"	vertical-align: middle;\n"
 "}\n"
 "\n"
 "\n"
@@ -758,7 +763,7 @@
 "}\n"
 "\n"
 "table.fieldtable {\n"
-"        width: 100%;\n"
+"        /*width: 100%;*/\n"
 "        margin-bottom: 10px;\n"
 "        border: 1px solid ##B4;\n"
 "        border-spacing: 0px;\n"
@@ -781,9 +786,21 @@
 "        vertical-align: top;\n"
 "}\n"
 "\n"
+".fieldtable td.fieldname {\n"
+"        padding-top: 5px;\n"
+"}\n"
+"\n"
 ".fieldtable td.fielddoc {\n"
 "        border-bottom: 1px solid ##B4;\n"
-"        width: 100%;\n"
+"        /*width: 100%;*/\n"
+"}\n"
+"\n"
+".fieldtable td.fielddoc p:first-child {\n"
+"        margin-top: 2px;\n"
+"}       \n"
+"        \n"
+".fieldtable td.fielddoc p:last-child {\n"
+"        margin-bottom: 2px;\n"
 "}\n"
 "\n"
 ".fieldtable tr:last-child td {\n"
@@ -824,6 +841,7 @@
 "	font-size: 11px;\n"
 "	background-image:url('tab_b.png');\n"
 "	background-repeat:repeat-x;\n"
+"	background-position: 0 -5px;\n"
 "	height:30px;\n"
 "	line-height:30px;\n"
 "	color:##9b;\n"
@@ -851,7 +869,10 @@
 "	display:block;\n"
 "	text-decoration: none;\n"
 "	outline: none;\n"
+"	color: ##30;\n"
 "	font-family: 'Lucida Grande',Geneva,Helvetica,Arial,sans-serif;\n"
+"	text-shadow: 0px 1px 1px rgba(255, 255, 255, 0.9);\n"
+"	text-decoration: none;        \n"
 "}\n"
 "\n"
 ".navpath li.navelem a:hover\n"
