@@ -2,7 +2,7 @@
  *
  * $Id: entry.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,6 +23,7 @@
 #include "section.h"
 #include "doxygen.h"
 #include "filestorage.h"
+#include "arguments.h"
 
 //------------------------------------------------------------------
 
@@ -30,23 +31,6 @@
 
 //------------------------------------------------------------------
 
-/*! the argument list is documented if one of its
- *  arguments is documented 
- */
-bool ArgumentList::hasDocumentation() const
-{
-  bool hasDocs=FALSE;
-  ArgumentListIterator ali(*this);
-  Argument *a;
-  for (ali.toFirst();!hasDocs && (a=ali.current());++ali)
-  {
-    hasDocs = a->hasDocumentation(); 
-  }
-  return hasDocs;
-}
-
-//------------------------------------------------------------------
-
 int Entry::num=0;
 
 Entry::Entry()
@@ -97,8 +81,7 @@ Entry::Entry(const Entry &e)
   virt        = e.virt;
   args        = e.args;
   bitfields   = e.bitfields;
-  argList     = new ArgumentList;
-  argList->setAutoDelete(TRUE);
+  argList     = e.argList->deepCopy();
   tArgLists = 0;
   program     = e.program;
   initializer = e.initializer;
@@ -185,27 +168,10 @@ Entry::Entry(const Entry &e)
     anchors->append(new SectionInfo(*s));
   }
 
-  // deep copy argument list
-  QListIterator<Argument> ali(*e.argList);
-  Argument *a;
-  for (;(a=ali.current());++ali)
-  {
-    argList->append(new Argument(*a));
-  }
-  argList->constSpecifier    = e.argList->constSpecifier;
-  argList->volatileSpecifier = e.argList->volatileSpecifier;
-  argList->pureSpecifier     = e.argList->pureSpecifier;
-  
   // deep copy type contraint list
   if (e.typeConstr)
   {
-    typeConstr  = new ArgumentList;
-    typeConstr->setAutoDelete(TRUE);
-    QListIterator<Argument> tcli(*e.typeConstr);
-    for (;(a=tcli.current());++tcli)
-    {
-      typeConstr->append(new Argument(*a));
-    }
+    typeConstr  = e.typeConstr->deepCopy();
   }
 
   // deep copy template argument lists
