@@ -2,7 +2,7 @@
  *
  * $Id: entry.h,v 1.36 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,10 +18,9 @@
 #ifndef ENTRY_H
 #define ENTRY_H
 
-#include "qtbc.h"
-#include <qlist.h>
 #include "types.h"
 
+#include <qlist.h>
 #include <qgstring.h>
 
 struct SectionInfo;
@@ -140,9 +139,11 @@ class Entry
       Strong      = 0x00400000,
       Weak        = 0x00800000,
       Unretained  = 0x01000000,
-      Composition = 0x02000000,
-      Aggregation = 0x04000000,
-      Association = 0x08000000
+      Alias       = 0x02000000,
+      ConstExp    = 0x04000000,
+      Default     = 0x08000000,
+      Delete      = 0x10000000,
+      NoExcept    = 0x20000000
     };
     enum ClassSpecifier
     {
