@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,7 +15,6 @@
  *
  */
 
-#include "qtbc.h"
 #include "memberlist.h"
 #include "classlist.h"
 #include "filedef.h"
@@ -37,6 +36,11 @@
 #include "debug.h"
 #include "layout.h"
 #include "entry.h"
+#include "groupdef.h"
+#include "filename.h"
+#include "membergroup.h"
+#include "dirdef.h"
+#include "config.h"
 
 //---------------------------------------------------------------------------
 
@@ -58,6 +62,8 @@ class DevNullCodeDocInterface : public CodeOutputInterface
     virtual void endFontClass() {}
     virtual void writeCodeAnchor(const char *) {}
     virtual void linkableSymbol(int, const char *,Definition *,Definition *) {}
+    virtual void setCurrentDoc(Definition *,const char *,bool) {}
+    virtual void addWord(const char *,bool) {}
 };
 
 //---------------------------------------------------------------------------
@@ -122,8 +128,8 @@ FileDef::~FileDef()
 /*! Compute the HTML anchor names for all members in the class */ 
 void FileDef::computeAnchors()
 {
-  MemberList *ml = getMemberList(MemberList::allMembersList);
-  if (ml) setAnchors(0,'a',ml);
+  MemberList *ml = getMemberList(MemberListType_allMembersList);
+  if (ml) setAnchors(ml);
 }
 
 void FileDef::distributeMemberGroupDocumentation()
@@ -157,7 +163,7 @@ void FileDef::findSectionsInDocumentation()
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if (ml->listType()&MemberList::declarationLists)
+    if (ml->listType()&MemberListType_declarationLists)
     {
       ml->findSectionsInDocumentation();
     }
@@ -167,7 +173,7 @@ void FileDef::findSectionsInDocumentation()
 void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 {
   if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
-      !documentation().isEmpty() ||
+      !documentation().stripWhiteSpace().isEmpty() || // avail empty section
       (Config_getBool("SOURCE_BROWSER") && getStartBodyLine()!=-1 && getBodyDef())
      )
   {
@@ -487,6 +493,7 @@ void FileDef::writeSummaryLinks(OutputList &ol)
       LayoutDocManager::instance().docEntries(LayoutDocManager::File));
   LayoutDocEntry *lde;
   bool first=TRUE;
+  SrcLangExt lang=getLanguage();
   for (eli.toFirst();(lde=eli.current());++eli)
   {
     if ((lde->kind()==LayoutDocEntry::FileClasses && classSDict && classSDict->declVisible()) || 
@@ -495,7 +502,7 @@ void FileDef::writeSummaryLinks(OutputList &ol)
     {
       LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
       QCString label = lde->kind()==LayoutDocEntry::FileClasses ? "nested-classes" : "namespaces";
-      ol.writeSummaryLink(0,label,ls->title,first);
+      ol.writeSummaryLink(0,label,ls->title(lang),first);
       first=FALSE;
     }
     else if (lde->kind()==LayoutDocEntry::MemberDecl)
@@ -504,7 +511,7 @@ void FileDef::writeSummaryLinks(OutputList &ol)
       MemberList * ml = getMemberList(lmd->type);
       if (ml && ml->declVisible())
       {
-        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title,first);
+        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title(lang),first);
         first=FALSE;
       }
     }
@@ -586,7 +593,7 @@ void FileDef::writeDocumentation(OutputList &ol)
   
   if (Doxygen::searchIndex)
   {
-    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
+    Doxygen::searchIndex->setCurrentDoc(this,anchor(),FALSE);
     Doxygen::searchIndex->addWord(localName(),TRUE);
   }
   
@@ -602,6 +609,7 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   //---------------------------------------- start flexible part -------------------------------
   
+  SrcLangExt lang = getLanguage();
   QListIterator<LayoutDocEntry> eli(
       LayoutDocManager::instance().docEntries(LayoutDocManager::File));
   LayoutDocEntry *lde;
@@ -630,13 +638,13 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::FileClasses: 
         {
           LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
-          writeClassDeclarations(ol,ls->title);
+          writeClassDeclarations(ol,ls->title(lang));
         }
         break; 
       case LayoutDocEntry::FileNamespaces: 
         {
           LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
-          writeNamespaceDeclarations(ol,ls->title);
+          writeNamespaceDeclarations(ol,ls->title(lang));
         }
         break; 
       case LayoutDocEntry::MemberGroups: 
@@ -645,7 +653,7 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::MemberDecl: 
         {
           LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
-          writeMemberDeclarations(ol,lmd->type,lmd->title);
+          writeMemberDeclarations(ol,lmd->type,lmd->title(lang));
         }
         break; 
       case LayoutDocEntry::MemberDeclEnd: 
@@ -654,7 +662,7 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::DetailedDesc: 
         {
           LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
-          writeDetailedDescription(ol,ls->title);
+          writeDetailedDescription(ol,ls->title(lang));
         }
         break;
       case LayoutDocEntry::MemberDefStart: 
@@ -666,7 +674,7 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::MemberDef: 
         {
           LayoutDocEntryMemberDef *lmd = (LayoutDocEntryMemberDef*)lde;
-          writeMemberDocumentation(ol,lmd->type,lmd->title);
+          writeMemberDocumentation(ol,lmd->type,lmd->title(lang));
         }
         break;
       case LayoutDocEntry::MemberDefEnd: 
@@ -716,7 +724,7 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    MemberList *ml = getMemberList(MemberList::allMembersList);
+    MemberList *ml = getMemberList(MemberListType_allMembersList);
     if (ml) ml->sort();
     writeMemberPages(ol);
   }
@@ -731,7 +739,7 @@ void FileDef::writeMemberPages(OutputList &ol)
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if (ml->listType()&MemberList::documentationLists)
+    if (ml->listType()&MemberListType_documentationLists)
     {
       ml->writeDocumentationPage(ol,name(),this);
     }
@@ -747,7 +755,7 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
   ol.writeString("      <div class=\"navtab\">\n");
   ol.writeString("        <table>\n");
 
-  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  MemberList *allMemberList = getMemberList(MemberListType_allMembersList);
   if (allMemberList)
   {
     MemberListIterator mli(*allMemberList);
@@ -805,7 +813,7 @@ void FileDef::writeSource(OutputList &ol)
   {
     startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,
         !generateTreeView,
-        !isDocFile && genSourceFile ? 0 : getOutputFileBase());
+        !isDocFile && genSourceFile ? QCString() : getOutputFileBase());
     if (!generateTreeView)
     {
       getDirDef()->writeNavigationPath(ol);
@@ -818,7 +826,7 @@ void FileDef::writeSource(OutputList &ol)
   else
   {
     startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,FALSE,
-        !isDocFile && genSourceFile ? 0 : getOutputFileBase());
+        !isDocFile && genSourceFile ? QCString() : getOutputFileBase());
     startTitle(ol,getSourceFileBase());
     ol.parseText(title);
     endTitle(ol,getSourceFileBase(),0);
@@ -867,7 +875,7 @@ void FileDef::addMembersToMemberGroup()
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if (ml->listType()&MemberList::declarationLists)
+    if (ml->listType()&MemberListType_declarationLists)
     {
       ::addMembersToMemberGroup(ml,&memberGroupSDict,this);
     }
@@ -895,7 +903,7 @@ void FileDef::insertMember(MemberDef *md)
   if (md->isHidden()) return;
   //printf("%s:FileDef::insertMember(%s (=%p) list has %d elements)\n",
   //    name().data(),md->name().data(),md,allMemberList.count());
-  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  MemberList *allMemberList = getMemberList(MemberListType_allMembersList);
   if (allMemberList && allMemberList->findRef(md)!=-1)  // TODO optimize the findRef!
   { 
     return;
@@ -903,35 +911,35 @@ void FileDef::insertMember(MemberDef *md)
 
   if (allMemberList==0)
   {
-    allMemberList = new MemberList(MemberList::allMembersList);;
+    allMemberList = new MemberList(MemberListType_allMembersList);
     m_memberLists.append(allMemberList);
   }
   allMemberList->append(md); 
   //::addFileMemberNameToIndex(md);
   switch (md->memberType())
   {
-    case MemberDef::Variable:     
-    case MemberDef::Property:     
-      addMemberToList(MemberList::decVarMembers,md);
-      addMemberToList(MemberList::docVarMembers,md);
+    case MemberType_Variable:     
+    case MemberType_Property:     
+      addMemberToList(MemberListType_decVarMembers,md);
+      addMemberToList(MemberListType_docVarMembers,md);
       break;
-    case MemberDef::Function: 
-      addMemberToList(MemberList::decFuncMembers,md);
-      addMemberToList(MemberList::docFuncMembers,md);
+    case MemberType_Function: 
+      addMemberToList(MemberListType_decFuncMembers,md);
+      addMemberToList(MemberListType_docFuncMembers,md);
       break;
-    case MemberDef::Typedef:      
-      addMemberToList(MemberList::decTypedefMembers,md);
-      addMemberToList(MemberList::docTypedefMembers,md);
+    case MemberType_Typedef:      
+      addMemberToList(MemberListType_decTypedefMembers,md);
+      addMemberToList(MemberListType_docTypedefMembers,md);
       break;
-    case MemberDef::Enumeration:  
-      addMemberToList(MemberList::decEnumMembers,md);
-      addMemberToList(MemberList::docEnumMembers,md);
+    case MemberType_Enumeration:  
+      addMemberToList(MemberListType_decEnumMembers,md);
+      addMemberToList(MemberListType_docEnumMembers,md);
       break;
-    case MemberDef::EnumValue:    // enum values are shown inside their enums
+    case MemberType_EnumValue:    // enum values are shown inside their enums
       break;
-    case MemberDef::Define:       
-      addMemberToList(MemberList::decDefineMembers,md);
-      addMemberToList(MemberList::docDefineMembers,md);
+    case MemberType_Define:       
+      addMemberToList(MemberListType_decDefineMembers,md);
+      addMemberToList(MemberListType_docDefineMembers,md);
       break;
     default:
        err("FileDef::insertMembers(): "
@@ -975,6 +983,14 @@ void FileDef::insertNamespace(NamespaceDef *nd)
   }
 }
 
+QCString FileDef::name() const 
+{ 
+  if (Config_getBool("FULL_PATH_NAMES")) 
+    return filename; 
+  else 
+    return Definition::name(); 
+} 
+
 void FileDef::addSourceRef(int line,Definition *d,MemberDef *md)
 {
   //printf("FileDef::addSourceDef(%d,%p,%p)\n",line,d,md);
@@ -985,7 +1001,7 @@ void FileDef::addSourceRef(int line,Definition *d,MemberDef *md)
     srcDefDict->insert(line,d);
     if (md) srcMemberDict->insert(line,md);
     //printf("Adding member %s with anchor %s at line %d to file %s\n",
-    //    md->name().data(),md->anchor().data(),line,name().data());
+    //    md?md->name().data():"<none>",md?md->anchor().data():"<none>",line,name().data());
   }
 }
 
@@ -1171,13 +1187,15 @@ bool FileDef::isIncluded(const QCString &name) const
 
 bool FileDef::generateSourceFile() const 
 { 
+  static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
+  static bool verbatimHeaders = Config_getBool("VERBATIM_HEADERS");
   QCString extension = name().right(4);
   return !isReference() && 
-         (Config_getBool("SOURCE_BROWSER") || 
-           (Config_getBool("VERBATIM_HEADERS") && guessSection(name())==Entry::HEADER_SEC) 
+         (sourceBrowser || 
+           (verbatimHeaders && guessSection(name())==Entry::HEADER_SEC) 
          ) &&
          extension!=".doc" && extension!=".txt" && extension!=".dox" &&
-         extension!=".md" && extension!=".markdown";  
+         extension!=".md" && name().right(9)!=".markdown";  
 }
 
 
@@ -1205,7 +1223,7 @@ void FileDef::addListReferences()
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if (ml->listType()&MemberList::documentationLists)
+    if (ml->listType()&MemberListType_documentationLists)
     {
       ml->addListReferences(this);
     }
@@ -1524,7 +1542,7 @@ void FileDef::acquireFileVersion()
     }
     const int bufSize=1024;
     char buf[bufSize];
-    int numRead = fread(buf,1,bufSize,f);
+    int numRead = (int)fread(buf,1,bufSize,f);
     portable_pclose(f);
     if (numRead>0 && !(fileVersion=QCString(buf,numRead).stripWhiteSpace()).isEmpty())
     {
@@ -1563,7 +1581,7 @@ QCString FileDef::includeName() const
   }
 }
 
-MemberList *FileDef::createMemberList(MemberList::ListType lt)
+MemberList *FileDef::createMemberList(MemberListType lt)
 {
   m_memberLists.setAutoDelete(TRUE);
   QListIterator<MemberList> mli(m_memberLists);
@@ -1581,14 +1599,14 @@ MemberList *FileDef::createMemberList(MemberList::ListType lt)
   return ml;
 }
 
-void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
+void FileDef::addMemberToList(MemberListType lt,MemberDef *md)
 {
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
   ml->setNeedsSorting(
-       ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-       ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+       ((ml->listType()&MemberListType_declarationLists) && sortBriefDocs) ||
+       ((ml->listType()&MemberListType_documentationLists) && sortMemberDocs));
   ml->append(md);
 #if 0
   if (ml->needsSorting())
@@ -1596,11 +1614,11 @@ void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   else
     ml->append(md);
 #endif
-  if (lt&MemberList::documentationLists)
+  if (lt&MemberListType_documentationLists)
   {
     ml->setInFile(TRUE);
   }
-  if (ml->listType()&MemberList::declarationLists) md->setSectionList(this,ml);
+  if (ml->listType()&MemberListType_declarationLists) md->setSectionList(this,ml);
 }
 
 void FileDef::sortMemberLists()
@@ -1613,7 +1631,7 @@ void FileDef::sortMemberLists()
   }
 }
 
-MemberList *FileDef::getMemberList(MemberList::ListType lt) const
+MemberList *FileDef::getMemberList(MemberListType lt) const
 {
   FileDef *that = (FileDef*)this;
   MemberList *ml = that->m_memberLists.first();
@@ -1628,7 +1646,7 @@ MemberList *FileDef::getMemberList(MemberList::ListType lt) const
   return 0;
 }
 
-void FileDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title)
+void FileDef::writeMemberDeclarations(OutputList &ol,MemberListType lt,const QCString &title)
 {
   static bool optVhdl = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   MemberList * ml = getMemberList(lt);
@@ -1646,7 +1664,7 @@ void FileDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,con
   }
 }
 
-void FileDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title)
+void FileDef::writeMemberDocumentation(OutputList &ol,MemberListType lt,const QCString &title)
 {
   MemberList * ml = getMemberList(lt);
   if (ml) ml->writeDocumentation(ol,name(),this,title);
