@@ -2,7 +2,7 @@
  *
  * $Id: filename.cpp,v 1.18 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,6 +17,7 @@
 
 #include "filename.h"
 #include "util.h"
+#include "config.h"
 
 FileName::FileName(const char *fn,const char *n) : FileList()
 {
@@ -97,11 +98,11 @@ void FileName::generateDiskNames()
   }
 }
 
-int FileName::compareItems(GCI item1, GCI item2)
+int FileName::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   FileName *f1=(FileName *)item1;
   FileName *f2=(FileName *)item2;
-  return stricmp(f1->fileName(),f2->fileName());
+  return qstricmp(f1->fileName(),f2->fileName());
 }
 
 FileNameIterator::FileNameIterator(const FileName &fname) :
@@ -127,18 +128,29 @@ void FileNameList::generateDiskNames()
   }
 }
 
-int FileNameList::compareItems(GCI item1, GCI item2)
+int FileNameList::compareItems(QCollection::Item item1, QCollection::Item item2)
 {
   FileName *f1=(FileName *)item1;
   FileName *f2=(FileName *)item2;
   //printf("FileNameList::compareItems `%s'<->`%s'\n",
   //    f1->fileName(),f2->fileName());
   return Config_getBool("FULL_PATH_NAMES") ?
-         stricmp(f1->fullName(),f2->fullName()) :
-         stricmp(f1->fileName(),f2->fileName());
+         qstricmp(f1->fullName(),f2->fullName()) :
+         qstricmp(f1->fileName(),f2->fileName());
 }
 
 FileNameListIterator::FileNameListIterator(const FileNameList &fnlist) :
   QListIterator<FileName>(fnlist)
 {
 }
+
+static bool getCaseSenseNames()
+{
+  static bool caseSenseNames = Config_getBool("CASE_SENSE_NAMES");
+  return caseSenseNames;
+}
+
+FileNameDict::FileNameDict(uint size) : QDict<FileName>(size,getCaseSenseNames()) 
+{
+}
+
