@@ -1,7 +1,7 @@
 /******************************************************************************
- * $Id: formula.cpp,v 1.16 2001/03/19 19:27:40 root Exp $
+ * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,10 +17,9 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "qtbc.h"
 #include <qfile.h>
-#include <qtextstream.h>
 #include <qfileinfo.h>
+#include <qtextstream.h>
 #include <qdir.h>
 
 #include "formula.h"
@@ -31,6 +30,7 @@
 #include "portable.h"
 #include "index.h"
 #include "doxygen.h"
+#include "ftextstream.h"
 
 Formula::Formula(const char *text)
 {
@@ -53,8 +53,8 @@ void FormulaList::generateBitmaps(const char *path)
   int x1,y1,x2,y2;
   QDir d(path);
   // store the original directory
-  if (!d.exists()) { err("Error: Output dir %s does not exist!\n",path); exit(1); }
-  QCString oldDir = convertToQCString(QDir::currentDirPath());
+  if (!d.exists()) { err("error: Output dir %s does not exist!\n",path); exit(1); }
+  QCString oldDir = QDir::currentDirPath().utf8();
   // go to the html output directory (i.e. path)
   QDir::setCurrent(d.absPath());
   QDir thisDir;
@@ -68,7 +68,7 @@ void FormulaList::generateBitmaps(const char *path)
   bool formulaError=FALSE;
   if (f.open(IO_WriteOnly))
   {
-    QTextStream t(&f);
+    FTextStream t(&f);
     if (Config_getBool("LATEX_BATCHMODE")) t << "\\batchmode" << endl;
     t << "\\documentclass{article}" << endl;
     t << "\\usepackage{epsfig}" << endl; // for those who want to include images
@@ -93,7 +93,7 @@ void FormulaList::generateBitmaps(const char *path)
         t << formula->getFormulaText() << endl << "\\pagebreak\n\n";
         pagesToGenerate.append(new int(page));
       }
-      Doxygen::indexList.addImageFile(resultName);
+      Doxygen::indexList->addImageFile(resultName);
       page++;
     }
     t << "\\end{document}" << endl;
@@ -105,6 +105,7 @@ void FormulaList::generateBitmaps(const char *path)
     //system("latex _formulas.tex </dev/null >/dev/null");
     QCString latexCmd = Config_getString("LATEX_CMD_NAME");
     if (latexCmd.isEmpty()) latexCmd="latex";
+    portable_sysTimerStart();
     if (portable_system(latexCmd,"_formulas.tex")!=0)
     {
       err("Problems running latex. Check your installation or look "
@@ -112,6 +113,7 @@ void FormulaList::generateBitmaps(const char *path)
       formulaError=TRUE;
       //return;
     }
+    portable_sysTimerStop();
     //printf("Running dvips...\n");
     QListIterator<int> pli(pagesToGenerate);
     int *pagePtr;
@@ -127,11 +129,14 @@ void FormulaList::generateBitmaps(const char *path)
       // encapsulated postscript.
       sprintf(dviArgs,"-q -D 600 -E -n 1 -p %d -o %s.eps _formulas.dvi",
           pageIndex,formBase.data());
+      portable_sysTimerStart();
       if (portable_system("dvips",dviArgs)!=0)
       {
         err("Problems running dvips. Check your installation!\n");
+        portable_sysTimerStop();
         return;
       }
+      portable_sysTimerStop();
       // now we read the generated postscript file to extract the bounding box
       QFileInfo fi(formBase+".eps");
       if (fi.exists())
@@ -144,7 +149,7 @@ void FormulaList::generateBitmaps(const char *path)
         }
         else
         {
-          err("Error: Couldn't extract bounding box!\n");
+          err("error: Couldn't extract bounding box!\n");
         }
       } 
       // next we generate a postscript file which contains the eps
@@ -152,7 +157,7 @@ void FormulaList::generateBitmaps(const char *path)
       f.setName(formBase+".ps");
       if (f.open(IO_WriteOnly))
       {
-        QTextStream t(&f);
+        FTextStream t(&f);
         t << "1 1 1 setrgbcolor" << endl;  // anti-alias to white background
         t << "newpath" << endl;
         t << "-1 -1 moveto" << endl;
@@ -172,8 +177,8 @@ void FormulaList::generateBitmaps(const char *path)
       int zoomFactor = Config_getInt("FORMULA_FONTSIZE");
       if (zoomFactor<8 || zoomFactor>50) zoomFactor=10;
       scaleFactor *= zoomFactor/10.0;
-      int gx = (((int)((x2-x1)*scaleFactor))+3)&~2;
-      int gy = (((int)((y2-y1)*scaleFactor))+3)&~2;
+      int gx = (((int)((x2-x1)*scaleFactor))+3)&~1;
+      int gy = (((int)((y2-y1)*scaleFactor))+3)&~1;
       // Then we run ghostscript to convert the postscript to a pixmap
       // The pixmap is a truecolor image, where only black and white are
       // used.  
@@ -184,11 +189,14 @@ void FormulaList::generateBitmaps(const char *path)
                     gx,gy,(int)(scaleFactor*72),(int)(scaleFactor*72),
                     formBase.data(),formBase.data()
              );
+      portable_sysTimerStart();
       if (portable_system(portable_ghostScriptCommand(),gsArgs)!=0)
       {
         err("Problem running ghostscript %s %s. Check your installation!\n",portable_ghostScriptCommand(),gsArgs);
+        portable_sysTimerStop();
         return;
       }
+      portable_sysTimerStop();
       f.setName(formBase+".pnm");
       uint imageX=0,imageY=0;
       // we read the generated image again, to obtain the pixel data.
@@ -197,14 +205,14 @@ void FormulaList::generateBitmaps(const char *path)
         QTextStream t(&f);
         QCString s;
         if (!t.eof())
-          s=t.readLine();
+          s=t.readLine().utf8();
         if (s.length()<2 || s.left(2)!="P6")
-          err("Error: ghostscript produced an illegal image format!");
+          err("error: ghostscript produced an illegal image format!");
         else
         {
-          // assume the size if after the first line that does not start with
+          // assume the size is after the first line that does not start with
           // # excluding the first line of the file.
-          while (!t.eof() && (s=t.readLine()) && !s.isEmpty() && s.at(0)=='#') { }
+          while (!t.eof() && (s=t.readLine().utf8()) && !s.isEmpty() && s.at(0)=='#') { }
           sscanf(s,"%d %d",&imageX,&imageY);
         }
         if (imageX>0 && imageY>0)
@@ -266,7 +274,7 @@ void FormulaList::generateBitmaps(const char *path)
               dstImage.setPixel(x,y,QMIN(15,(c*15)/(16*10)));
             }
           }
-          // save the result as a png
+          // save the result as a bitmap
           QCString resultName;
           resultName.sprintf("form_%d.png",pageNum);
           // the option parameter 1 is used here as a temporary hack
@@ -289,13 +297,13 @@ void FormulaList::generateBitmaps(const char *path)
   // remove the latex file itself
   if (!formulaError) thisDir.remove("_formulas.tex");
   // write/update the formula repository so we know what text the 
-  // generated pngs represent (we use this next time to avoid regeneration
-  // of the pngs, and to avoid forcing the user to delete all pngs in order
+  // generated images represent (we use this next time to avoid regeneration
+  // of the images, and to avoid forcing the user to delete all images in order
   // to let a browser refresh the images).
   f.setName("formula.repository");
   if (f.open(IO_WriteOnly))
   {
-    QTextStream t(&f);
+    FTextStream t(&f);
     for (fli.toFirst();(formula=fli.current());++fli)
     {
       t << "\\form#" << formula->getId() << ":" << formula->getFormulaText() << endl;
