@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.h,v 1.18 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,10 @@
 #ifndef GROUPDEF_H
 #define GROUPDEF_H
 
-#include "qtbc.h"
 #include "sortdict.h"
 #include "definition.h"
-#include "memberlist.h"
-#include "memberdef.h"
-#include "htmlhelp.h"
 
+class MemberList;
 class FileList;
 class ClassSDict;
 class FileDef;
@@ -40,7 +37,10 @@ class PageDef;
 class DirDef;
 class DirList;
 class FTVHelp;
+class Entry;
+class MemberDef;
 
+/** A model of a group of symbols. */
 class GroupDef : public Definition
 {
   public:
@@ -49,9 +49,10 @@ class GroupDef : public Definition
     DefType definitionType() const { return TypeGroup; }
     QCString getOutputFileBase() const;
     QCString anchor() const { return QCString(); }
+    QCString displayName(bool=TRUE) const { return hasGroupTitle() ? title : Definition::name(); }
     const char *groupTitle() const { return title; }
     void setGroupTitle( const char *newtitle );
-    bool hasGroupTitle( ) { return titleSet; }
+    bool hasGroupTitle( ) const { return titleSet; }
     void addFile(const FileDef *def); 
     bool addClass(const ClassDef *def);
     bool addNamespace(const NamespaceDef *def);
@@ -66,15 +67,9 @@ class GroupDef : public Definition
     void writeDocumentation(OutputList &ol);
     void writeMemberPages(OutputList &ol);
     void writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const;
-    int countMembers() const;
-    bool isLinkableInProject() const
-    {
-      return !isReference();
-    }
-    bool isLinkable() const
-    {
-      return TRUE;
-    }
+    int  countMembers() const;
+    bool isLinkableInProject() const;
+    bool isLinkable() const;
     bool isASubGroup() const;
     void computeAnchors();
 
@@ -87,13 +82,13 @@ class GroupDef : public Definition
 
     bool visited;    // number of times accessed for output - KPW
 
-    friend void writeGroupTreeNode(OutputList&, GroupDef*, int, FTVHelp*);      
+    //friend void writeGroupTreeNode(OutputList&, GroupDef*, int, FTVHelp*);      
                     // make accessible for writing tree view of group in index.cpp - KPW
 
     void setGroupScope(Definition *d) { groupScope = d; }
     Definition *getGroupScope() const { return groupScope; }
 
-    MemberList *getMemberList(MemberList::ListType lt) const;
+    MemberList *getMemberList(MemberListType lt) const;
     const QList<MemberList> &getMemberLists() const { return m_memberLists; }
 
     /* user defined member groups */
@@ -105,17 +100,19 @@ class GroupDef : public Definition
     GroupList *     getSubGroups() const    { return groupList; }
     PageSDict *     getPages() const        { return pageDict; }
     DirList *       getDirs() const         { return dirList; }
+    PageSDict *     getExamples() const     { return exampleDict; }
     //MemberList*     getMembers() const      { return allMemberList; }
+    void sortSubGroups();
     
   protected:
     void addMemberListToGroup(MemberList *,bool (MemberDef::*)() const);
 
   private: 
-    MemberList *createMemberList(MemberList::ListType lt);
-    void addMemberToList(MemberList::ListType lt,MemberDef *md);
-    void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
-    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
-    void removeMemberFromList(MemberList::ListType lt,MemberDef *md);
+    MemberList *createMemberList(MemberListType lt);
+    void addMemberToList(MemberListType lt,MemberDef *md);
+    void writeMemberDeclarations(OutputList &ol,MemberListType lt,const QCString &title);
+    void writeMemberDocumentation(OutputList &ol,MemberListType lt,const QCString &title);
+    void removeMemberFromList(MemberListType lt,MemberDef *md);
     void writeGroupGraph(OutputList &ol);
     void writeFiles(OutputList &ol,const QCString &title);
     void writeNamespaces(OutputList &ol,const QCString &title);
@@ -133,6 +130,7 @@ class GroupDef : public Definition
     void endMemberDocumentation(OutputList &ol);
     void writeAuthorSection(OutputList &ol);
     void writeSummaryLinks(OutputList &ol);
+    void updateLanguage(const Definition *);
 
     QCString title;                      // title of the group
     bool titleSet;                       // true if title is not the same as the name
@@ -155,26 +153,29 @@ class GroupDef : public Definition
 
 };
 
+/** A sorted dictionary of GroupDef objects. */
 class GroupSDict : public SDict<GroupDef>
 {
   public:
     GroupSDict(uint size) : SDict<GroupDef>(size) {}
     virtual ~GroupSDict() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return strcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
     }
 };
 
+/** A list of GroupDef objects. */
 class GroupList : public QList<GroupDef>
 {
   public:
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return strcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
+      return qstrcmp(((GroupDef*)item1)->groupTitle(),((GroupDef*)item2)->groupTitle());
     }
 };
 
+/** An iterator for GroupDef objects in a GroupList. */
 class GroupListIterator : public QListIterator<GroupDef>
 {
   public:
