@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,9 @@
 #include "parserintf.h"
 #include "msc.h"
 #include "util.h"
-
+#include "vhdldocgen.h"
+#include "filedef.h"
+#include "memberdef.h"
 
 static const int NUM_HTML_LIST_TYPES = 4;
 static const char types[][NUM_HTML_LIST_TYPES] = {"1", "a", "i", "A"};
@@ -130,10 +132,11 @@ static QString htmlAttribsToString(const HtmlAttribList &attribs)
 //-------------------------------------------------------------------------
 
 HtmlDocVisitor::HtmlDocVisitor(FTextStream &t,CodeOutputInterface &ci,
-                               const char *langExt) 
+                               Definition *ctx,MemberDef *md) 
   : DocVisitor(DocVisitor_Html), m_t(t), m_ci(ci), m_insidePre(FALSE), 
-                                 m_hide(FALSE), m_langExt(langExt)
+                                 m_hide(FALSE), m_ctx(ctx), m_md(md)
 {
+  if (ctx) m_langExt=ctx->getDefFileExtension();
 }
 
   //--------------------------------------
@@ -324,10 +327,12 @@ void HtmlDocVisitor::visit(DocLineBreak *)
   m_t << "<br/>\n";
 }
 
-void HtmlDocVisitor::visit(DocHorRuler *)
+void HtmlDocVisitor::visit(DocHorRuler *hr)
 {
   if (m_hide) return;
+  forceEndParagraph(hr);
   m_t << "<hr/>\n";
+  forceStartParagraph(hr);
 }
 
 void HtmlDocVisitor::visit(DocStyleChange *s)
@@ -413,8 +418,19 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
       forceEndParagraph(s);
       m_t << PREFRAG_START;
       Doxygen::parserManager->getParser(lang)
-                            ->parseCode(m_ci,s->context(),s->text(),
-                                        s->isExample(),s->exampleFile());
+                            ->parseCode(m_ci,
+                                        s->context(),
+                                        s->text(),
+                                        s->isExample(),
+                                        s->exampleFile(),
+                                        0,     // fileDef
+                                        -1,    // startLine
+                                        -1,    // endLine
+                                        FALSE, // inlineFragment
+                                        0,     // memberDef
+                                        TRUE,  // show line numbers
+                                        m_ctx  // search context
+                                       );
       m_t << PREFRAG_END;
       forceStartParagraph(s);
       break;
@@ -464,13 +480,15 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
       break;
     case DocVerbatim::Msc:
       {
+        forceEndParagraph(s);
+
         static int mscindex = 1;
         QCString baseName(4096);
 
         baseName.sprintf("%s%d", 
             (Config_getString("HTML_OUTPUT")+"/inline_mscgraph_").data(), 
             mscindex++
-           );
+            );
         QFile file(baseName+".msc");
         if (!file.open(IO_WriteOnly))
         {
@@ -479,17 +497,16 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
         QCString text = "msc {";
         text+=s->text();
         text+="}";
+
         file.writeBlock( text, text.length() );
         file.close();
 
-        forceEndParagraph(s);
         m_t << "<div align=\"center\">" << endl;
         writeMscFile(baseName+".msc",s->relPath(),s->context());
-        m_t << "</div>" << endl;
-        forceStartParagraph(s);
-
         if (Config_getBool("DOT_CLEANUP")) file.remove();
       }
+      m_t << "</div>" << endl;
+      forceStartParagraph(s);
       break;
   }
 }
@@ -514,10 +531,13 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                         inc->text(),
                                         inc->isExample(),
                                         inc->exampleFile(),
-                                        0,   // fd
-                                        -1,  // startLine
-                                        -1,  // endLine
-                                        TRUE // inlineFragment
+                                        0,     // fileDef
+                                        -1,    // startLine
+                                        -1,    // endLine
+                                        TRUE,  // inlineFragment
+                                        0,     // memberDef
+                                        TRUE,  // show line numbers
+                                        m_ctx  // search context 
                                        );
       m_t << PREFRAG_END;
       forceStartParagraph(inc);
@@ -533,7 +553,15 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                            inc->context(),
                                            inc->text(),
                                            inc->isExample(),
-                                           inc->exampleFile(), &fd);
+                                           inc->exampleFile(), 
+                                           &fd,   // fileDef,
+                                           -1,    // start line
+                                           -1,    // end line
+                                           FALSE, // inline fragment
+                                           0,     // memberDef
+                                           TRUE,  // show line numbers
+                                           m_ctx  // search context
+                                           );
          m_t << PREFRAG_END;
          forceStartParagraph(inc);
       }
@@ -561,9 +589,12 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                            inc->isExample(),
                                            inc->exampleFile(), 
                                            0,
-                                           -1,  // startLine
-                                           -1,  // endLine
-                                           TRUE // inlineFragment
+                                           -1,    // startLine
+                                           -1,    // endLine
+                                           TRUE,  // inlineFragment
+                                           0,     // memberDef
+                                           TRUE,  // show line number
+                                           m_ctx  // search context
                                           );
          m_t << PREFRAG_END;
          forceStartParagraph(inc);
@@ -588,9 +619,20 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
     if (!m_hide) 
     {
       Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,op->context(),
-                                op->text(),op->isExample(),
-                                op->exampleFile());
+                            ->parseCode(
+                                m_ci,
+                                op->context(),
+                                op->text(),
+                                op->isExample(),
+                                op->exampleFile(),
+                                0,     // fileDef
+                                -1,    // startLine
+                                -1,    // endLine
+                                FALSE, // inline fragment
+                                0,     // memberDef
+                                TRUE,  // show line numbers
+                                m_ctx  // search context
+                               );
     }
     pushEnabled();
     m_hide=TRUE;
@@ -665,7 +707,7 @@ void HtmlDocVisitor::visit(DocIndexEntry *e)
   //       e->scope()  ? e->scope()->name().data()  : "<null>",
   //       e->member() ? e->member()->name().data() : "<null>"
   //      );
-  Doxygen::indexList.addIndexItem(e->scope(),e->member(),e->entry());
+  Doxygen::indexList->addIndexItem(e->scope(),e->member(),anchor,e->entry());
 }
 
 void HtmlDocVisitor::visit(DocSimpleSectSep *)
@@ -1724,6 +1766,37 @@ void HtmlDocVisitor::visitPost(DocHtmlBlockQuote *b)
   forceStartParagraph(b);
 }
 
+void HtmlDocVisitor::visitPre(DocVhdlFlow *vf)
+{
+  if (m_hide) return;
+  if (VhdlDocGen::getFlowMember()) // use VHDL flow chart creator
+  {
+    forceEndParagraph(vf);
+    QCString fname=FlowChart::convertNameToFileName(); 
+    m_t << "<p>";
+    m_t << "flowchart: " ; // TODO: translate me
+    m_t << "<a href=\"";
+    m_t << fname.data(); 
+    m_t << ".svg\">";
+    m_t << VhdlDocGen::getFlowMember()->name().data(); 
+    m_t << "</a>";
+    if (vf->hasCaption())
+    {
+      m_t << "<br/>";
+    }
+  }
+}
+
+void HtmlDocVisitor::visitPost(DocVhdlFlow *vf)
+{
+  if (m_hide) return;
+  if (VhdlDocGen::getFlowMember()) // use VHDL flow chart creator
+  {
+    m_t << "</p>";
+    forceStartParagraph(vf);
+  }
+}
+
 void HtmlDocVisitor::filter(const char *str)
 { 
   if (str==0) return;
@@ -1783,6 +1856,7 @@ void HtmlDocVisitor::startLink(const QCString &ref,const QCString &file,
                                const QCString &relPath,const QCString &anchor,
                                const QCString &tooltip)
 {
+  //printf("HtmlDocVisitor: file=%s anchor=%s\n",file.data(),anchor.data());
   if (!ref.isEmpty()) // link to entity imported via tag file
   {
     m_t << "<a class=\"elRef\" ";
