@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,18 +22,23 @@
 #include <qlist.h>
 #include <qdict.h>
 #include <qregexp.h>
+#include <qfile.h>
+
 #include "qtextcodec.h"
 #include "sortdict.h"
-
 #include "htmlhelp.h"
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
 #include "language.h"
 #include "portable.h"
+#include "groupdef.h"
+#include "memberdef.h"
+#include "filedef.h"
 
 //----------------------------------------------------------------------------
 
+/** Class representing a field in the HTML help index. */
 struct IndexField
 {
   QCString name;
@@ -43,24 +48,25 @@ struct IndexField
   bool     reversed;
 };
 
+/** Sorted dictionary of IndexField objects. */
 class IndexFieldSDict : public SDict<IndexField>
 {
   public:
     IndexFieldSDict() : SDict<IndexField>(17) {}
    ~IndexFieldSDict() {}
-    int compareItems(GCI item1, GCI item2)
+    int compareItems(QCollection::Item item1, QCollection::Item item2)
     {
-      return stricmp(((IndexField *)item1)->name,((IndexField *)item2)->name);
+      return qstricmp(((IndexField *)item1)->name,((IndexField *)item2)->name);
     }
 };
 
-/*! A helper class for HtmlHelp that manages a two level index in 
- * alphabetical order 
+/** A helper class for HtmlHelp that manages a two level index in 
+ *  alphabetical order.
  */
 class HtmlHelpIndex
 {
   public:
-    HtmlHelpIndex();
+    HtmlHelpIndex(HtmlHelp *help);
    ~HtmlHelpIndex();
     void addItem(const char *first,const char *second, 
                  const char *url, const char *anchor,
@@ -68,10 +74,11 @@ class HtmlHelpIndex
     void writeFields(FTextStream &t);
   private:
     IndexFieldSDict *dict;   
+    HtmlHelp *m_help;
 };
 
 /*! Constructs a new HtmlHelp index */
-HtmlHelpIndex::HtmlHelpIndex()
+HtmlHelpIndex::HtmlHelpIndex(HtmlHelp *help) : m_help(help)
 {
   dict = new IndexFieldSDict;
   dict->setAutoDelete(TRUE);
@@ -120,6 +127,16 @@ void HtmlHelpIndex::addItem(const char *level1,const char *level2,
   }
 }
 
+static QCString field2URL(const IndexField *f,bool checkReversed)
+{
+  QCString result = f->url + Doxygen::htmlFileExtension;
+  if (!f->anchor.isEmpty() && (!checkReversed || f->reversed)) 
+  {
+    result+="#"+f->anchor;  
+  }
+  return result;
+}
+
 /*! Writes the sorted list of index items into a html like list.
  *
  *  An list of calls with <code>name = level1,level2</code> as follows:
@@ -195,10 +212,9 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
       if (level2.isEmpty())
       {
         t << "  <LI><OBJECT type=\"text/sitemap\">";
-        t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension;
-        if (!f->anchor.isEmpty() && f->reversed) t << "#" << f->anchor;  
+        t << "<param name=\"Local\" value=\"" << field2URL(f,TRUE);
         t << "\">";
-        t << "<param name=\"Name\" value=\"" << level1 << "\">"
+        t << "<param name=\"Name\" value=\"" << m_help->recode(level1) << "\">"
            "</OBJECT>\n";
       }
       else
@@ -206,17 +222,16 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
         if (f->link)
         {
           t << "  <LI><OBJECT type=\"text/sitemap\">";
-          t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension;
-          if (!f->anchor.isEmpty() && f->reversed) t << "#" << f->anchor;  
+          t << "<param name=\"Local\" value=\"" << field2URL(f,TRUE);
           t << "\">";
-          t << "<param name=\"Name\" value=\"" << level1 << "\">"
+          t << "<param name=\"Name\" value=\"" << m_help->recode(level1) << "\">"
                "</OBJECT>\n";
         }
         else
         {
           t << "  <LI><OBJECT type=\"text/sitemap\">";
-          t << "<param name=\"See Also\" value=\"" << level1 << "\">";
-          t << "<param name=\"Name\" value=\"" << level1 << "\">"
+          t << "<param name=\"See Also\" value=\"" << m_help->recode(level1) << "\">";
+          t << "<param name=\"Name\" value=\"" << m_help->recode(level1) << "\">"
                "</OBJECT>\n";
         }
       }
@@ -234,10 +249,9 @@ void HtmlHelpIndex::writeFields(FTextStream &t)
     if (level2Started)
     {
       t << "    <LI><OBJECT type=\"text/sitemap\">";
-      t << "<param name=\"Local\" value=\"" << f->url << Doxygen::htmlFileExtension;
-      if (!f->anchor.isEmpty()) t << "#" << f->anchor;  
+      t << "<param name=\"Local\" value=\"" << field2URL(f,FALSE);
       t << "\">";
-      t << "<param name=\"Name\" value=\"" << level2 << "\">"
+      t << "<param name=\"Name\" value=\"" << m_help->recode(level2) << "\">"
          "</OBJECT>\n";
     }
     lastLevel1 = level1.copy();
@@ -258,7 +272,7 @@ HtmlHelp::HtmlHelp() : indexFileDict(1009)
   /* initial depth */
   dc = 0;
   cf = kf = 0;
-  index = new HtmlHelpIndex;
+  index = new HtmlHelpIndex(this);
   m_fromUtf8 = (void *)(-1);
 }
 
@@ -446,7 +460,6 @@ void HtmlHelp::createProjectFile()
     FTextStream t(&f);
     
     QCString indexName="index"+Doxygen::htmlFileExtension;
-    //if (Config_getBool("GENERATE_TREEVIEW")) indexName="main"+Doxygen::htmlFileExtension;
     t << "[OPTIONS]\n";
     if (!Config_getString("CHM_FILE").isEmpty())
     {
@@ -482,52 +495,6 @@ void HtmlHelp::createProjectFile()
       t << s << endl;
       s = indexFiles.next();
     }
-#if 0
-    // items not found by the html help compiler scan.
-    t << "tabs.css" << endl;
-    t << "tab_a.png" << endl;
-    t << "tab_b.png" << endl;
-    t << "tab_h.png" << endl;
-    t << "tab_s.png" << endl;
-    t << "nav_h.png" << endl;
-    t << "nav_f.png" << endl;
-    t << "bc_s.png" << endl;
-    if (Config_getBool("HTML_DYNAMIC_SECTIONS"))
-    {
-      t << "open.png" << endl;
-      t << "closed.png" << endl;
-    }
-    if (Config_getBool("GENERATE_HTMLHELP"))
-    {
-      t << "ftv2blank.png" << endl;
-      t << "ftv2doc.png" << endl;
-      t << "ftv2folderclosed.png" << endl;
-      t << "ftv2folderopen.png" << endl;
-      t << "ftv2lastnode.png" << endl;
-      t << "ftv2link.png" << endl;
-      t << "ftv2mlastnode.png" << endl;
-      t << "ftv2mnode.png" << endl;
-      t << "ftv2node.png" << endl;
-      t << "ftv2plastnode.png" << endl;
-      t << "ftv2pnode.png" << endl;
-      t << "ftv2vertline.png" << endl;
-    }
-    if (Config_getBool("SEARCHENGINE"))
-    {
-      t << "search_l.png" << endl;
-      t << "search_m.png" << endl;
-      t << "search_r.png" << endl;
-      if (Config_getBool("SERVER_BASED_SEARCH"))
-      {
-        t << "mag.png" << endl;
-      }
-      else
-      {
-        t << "mag_sel.png" << endl;
-        t << "close.png" << endl;
-      }
-    }
-#endif
     uint i;
     for (i=0;i<imageFiles.count();i++)
     {
@@ -607,11 +574,11 @@ QCString HtmlHelp::recode(const QCString &s)
   QCString output(oSize);
   size_t iLeft     = iSize;
   size_t oLeft     = oSize;
-  const char *iPtr = s.data();
+  char *iPtr       = s.data();
   char *oPtr       = output.data();
   if (!portable_iconv(m_fromUtf8,&iPtr,&iLeft,&oPtr,&oLeft))
   {
-    oSize -= oLeft;
+    oSize -= (int)oLeft;
     output.resize(oSize+1);
     output.at(oSize)='\0';
     return output;
@@ -630,6 +597,7 @@ QCString HtmlHelp::recode(const QCString &s)
  *  \param anchor the anchor of the item.
  *  \param separateIndex not used.
  *  \param addToNavIndex not used.
+ *  \param def not used.
  */
 void HtmlHelp::addContentsItem(bool isDir,
                                const char *name,
@@ -637,7 +605,8 @@ void HtmlHelp::addContentsItem(bool isDir,
                                const char *file,
                                const char *anchor,
                                bool /* separateIndex */,
-                               bool /* addToNavIndex */)
+                               bool /* addToNavIndex */,
+                               Definition * /* def */)
 {
   // If we're using a binary toc then folders cannot have links. 
   if(Config_getBool("BINARY_TOC") && isDir) 
@@ -650,8 +619,19 @@ void HtmlHelp::addContentsItem(bool isDir,
   cts << "<param name=\"Name\" value=\"" << recode(name) << "\">";
   if (file)      // made file optional param - KPW
   {
-    cts << "<param name=\"Local\" value=\"" << file << Doxygen::htmlFileExtension;
-    if (anchor) cts << "#" << anchor;  
+    if (file && (file[0]=='!' || file[0]=='^')) // special markers for user defined URLs
+    {
+      cts << "<param name=\"";
+      if (file[0]=='^') cts << "URL"; else cts << "Local";
+      cts << "\" value=\"";
+      cts << &file[1];
+    }
+    else
+    {
+      cts << "<param name=\"Local\" value=\"";
+      cts << file << Doxygen::htmlFileExtension;
+      if (anchor) cts << "#" << anchor;  
+    }
     cts << "\">";
   }
   cts << "<param name=\"ImageNumber\" value=\"";
@@ -669,7 +649,7 @@ void HtmlHelp::addContentsItem(bool isDir,
 
 
 void HtmlHelp::addIndexItem(Definition *context,MemberDef *md,
-                            const char *word)
+                            const char *sectionAnchor,const char *word)
 {
   if (md)
   {
@@ -689,14 +669,14 @@ void HtmlHelp::addIndexItem(Definition *context,MemberDef *md,
     QCString level2  = md->name();
     QCString contRef = separateMemberPages ? cfname : cfiname;
     QCString memRef  = cfname;
-    QCString anchor  = md->anchor();
+    QCString anchor  = sectionAnchor ? QCString(sectionAnchor) : md->anchor();
     index->addItem(level1,level2,contRef,anchor,TRUE,FALSE);
     index->addItem(level2,level1,memRef,anchor,TRUE,TRUE);
   }
   else if (context)
   {
     QCString level1  = word ? QCString(word) : context->name();
-    index->addItem(level1,0,context->getOutputFileBase(),0,TRUE,FALSE);
+    index->addItem(level1,0,context->getOutputFileBase(),sectionAnchor,TRUE,FALSE);
   }
 }
 
