@@ -2,7 +2,7 @@
  *
  * $Id: htmlhelp.h,v 1.7 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,15 +21,16 @@
 #ifndef HTMLHELP_H
 #define HTMLHELP_H
 
-#include "qtbc.h"
 #include <qstrlist.h>
 #include "index.h"
 #include "ftextstream.h"
 
 class QFile;
+class Definition;
 class HtmlHelpIndex;
 
-/*! A class that generated the HTML Help specific files.
+/** A class that generated the HTML Help specific files.
+ *
  *  These files can be used with the Microsoft HTML Help workshop
  *  to generate compressed HTML files (.chm).
  */
@@ -75,16 +76,16 @@ class HtmlHelp  : public IndexIntf
                          const char *file,
                          const char *anchor,
                          bool separateIndex,
-                         bool addToNavIndex);
-    //void addIndexItem(const char *level1, const char *level2, 
-    //                  const char *contRef, const char *memRef,
-    //                  const char *anchor,const MemberDef *md);
-    void addIndexItem(Definition *context,MemberDef *md,const char *title);
+                         bool addToNavIndex,
+                         Definition *def);
+    void addIndexItem(Definition *context,MemberDef *md,
+                      const char *sectionAnchor, const char *title);
     void addIndexFile(const char *name);
     void addImageFile(const char *);
     void addStyleSheetFile(const char *) {}
 
   private:
+    friend class HtmlHelpIndex;
     void createProjectFile();
 
     QFile *cf,*kf; 
