@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,6 +16,8 @@
  */
 
 #include "message.h"
+#include "config.h"
+#include "util.h"
 #include "language.h"
 #include "lang_cfg.h"
 #include "translator.h"
@@ -148,7 +150,7 @@
 #endif
 #endif // !ENGLISH_ONLY
 
-#define L_EQUAL(a) !stricmp(langName,a)
+#define L_EQUAL(a) !qstricmp(langName,a)
 
 Translator *theTranslator=0;
 
