@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -28,6 +28,8 @@
 #include "msc.h"
 #include "htmlattrib.h"
 #include "cite.h"
+#include "filedef.h"
+#include "config.h"
 
 static QCString escapeLabelName(const char *s)
 {
@@ -1549,6 +1551,16 @@ void LatexDocVisitor::visitPost(DocHtmlBlockQuote *)
   m_t << "\\end{quotation}" << endl;
 }
 
+void LatexDocVisitor::visitPre(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
+void LatexDocVisitor::visitPost(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
 void LatexDocVisitor::filter(const char *str)
 { 
   filterLatexString(m_t,str,m_insideTabbing,m_insidePre,m_insideItem);
@@ -1651,9 +1663,18 @@ void LatexDocVisitor::startDotFile(const QCString &fileName,
   }
   else
   {
-    m_t << "[width=\\textwidth]";
+    m_t << "[width=\\textwidth,height=\\textheight/2,keepaspectratio=true]";
   }
-  m_t << "{" << baseName << "}";
+  m_t << "{" << baseName;
+  //if (Config_getBool("USE_PDFLATEX"))
+  //{
+  //  m_t << ".pdf";
+  //}
+  //else
+  //{
+  //  m_t << ".eps";
+  //}
+  m_t << "}";
 
   if (hasCaption)
   {
@@ -1715,9 +1736,18 @@ void LatexDocVisitor::startMscFile(const QCString &fileName,
   }
   else
   {
-    m_t << "[width=\\textwidth]";
+    m_t << "[width=\\textwidth,height=\\textheight/2,keepaspectratio=true]";
   }
-  m_t << "{" << baseName << "}";
+  m_t << "{" << baseName;
+  //if (Config_getBool("USE_PDFLATEX"))
+  //{
+  //  m_t << ".pdf";
+  //}
+  //else
+  //{
+  //  m_t << ".eps";
+  //}
+  m_t << "}";
 
   if (hasCaption)
   {
