@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,7 +22,8 @@
 #include "docvisitor.h"
 #include <qstack.h>
 #include <qcstring.h>
-#include <qmap.h>
+#include <qlist.h>
+//#include <qmap.h>
 
 class FTextStream;
 class CodeOutputInterface;
@@ -117,8 +118,6 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocSecRefItem *);
     void visitPre(DocSecRefList *);
     void visitPost(DocSecRefList *);
-    //void visitPre(DocLanguage *);
-    //void visitPost(DocLanguage *);
     void visitPre(DocParamSect *);
     void visitPost(DocParamSect *);
     void visitPre(DocParamList *);
@@ -131,9 +130,25 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocCopy *);
     void visitPre(DocText *);
     void visitPost(DocText *);
+    void visitPre(DocHtmlBlockQuote *);
+    void visitPost(DocHtmlBlockQuote *);
+    void visitPre(DocVhdlFlow *);
+    void visitPost(DocVhdlFlow *);
 
   private:
 
+    struct ActiveRowSpan
+    {
+      ActiveRowSpan(DocHtmlCell *c,int rs,int cs,int col) 
+        : cell(c), rowSpan(rs), colSpan(cs), column(col) {}
+      DocHtmlCell *cell;
+      int rowSpan;
+      int colSpan;
+      int column;
+    };
+
+    typedef QList<ActiveRowSpan> RowSpanList;
+
     //--------------------------------------
     // helper functions 
     //--------------------------------------
@@ -166,11 +181,14 @@ class LatexDocVisitor : public DocVisitor
     bool m_insideItem;
     bool m_hide;
     bool m_insideTabbing;
+    bool m_insideTable;
+    int  m_numCols;
     QStack<bool> m_enabled;
     QCString m_langExt;
-	QMap<int, int> m_rowspanIndices;
-	int m_currentColumn;
-	bool m_inRowspan;
+    RowSpanList m_rowSpans;
+    int m_currentColumn;
+    bool m_inRowspan;
+    bool m_inColspan;
 };
 
 #endif
