@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,7 +17,6 @@
 
 #include <stdlib.h>
 
-#include "qtbc.h"
 #include <qdir.h>
 #include "latexgen.h"
 #include "config.h"
@@ -33,6 +32,10 @@
 #include "latexdocvisitor.h"
 #include "dirdef.h"
 #include "cite.h"
+#include "groupdef.h"
+#include "classlist.h"
+#include "namespacedef.h"
+#include "filename.h"
 
 //static QCString filterTitle(const char *s)
 //{
@@ -794,7 +797,7 @@ static void writeDefaultStyleSheetPart3(FTextStream &t)
        //"      \\arrayrulecolor{gray}%\n"
        "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
        "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
-       "                          p{0.77\\textwidth}|}%\n"
+       "                          p{0.705\\textwidth}|}%\n"
        "      \\hline%\n"
        "}{%\n"
        "      \\end{longtable}%\n"
@@ -811,7 +814,7 @@ static void writeDefaultStyleSheetPart3(FTextStream &t)
        "      \\arrayrulecolor{gray}%\n"
        "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
        "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
-       "                          p{0.77\\textwidth}|}%\n"
+       "                          p{0.705\\textwidth}|}%\n"
        "      \\hline%\n"
        "}{%\n"
        "      \\end{longtable}%\n"
@@ -828,7 +831,7 @@ static void writeDefaultStyleSheetPart3(FTextStream &t)
        "      \\arrayrulecolor{gray}%\n"
        "      \\setlength{\\tabcolsep}{0.01\\textwidth}%\n"
        "      \\begin{longtable}{|>{\\raggedleft\\hspace{0pt}}p{0.25\\textwidth}|%\n"
-       "                          p{0.77\\textwidth}|}%\n"
+       "                          p{0.705\\textwidth}|}%\n"
        "      \\hline%\n"
        "}{%\n"
        "      \\end{longtable}%\n"
@@ -946,6 +949,7 @@ static void writeDefaultStyleSheetPart3(FTextStream &t)
 static void writeDefaultFooter(FTextStream &t)
 {
   Doxygen::citeDict->writeLatexBibliography(t);
+  t << "\\addcontentsline{toc}{part}{" << theTranslator->trRTFGeneralIndex() << "}\n";
   t << "\\printindex\n";
   t << "\\end{document}\n";
 }
@@ -953,6 +957,7 @@ static void writeDefaultFooter(FTextStream &t)
 void LatexGenerator::writeHeaderFile(QFile &f)
 {
   FTextStream t(&f);
+  t << "% Latex header for doxygen " << versionString << endl;
   writeDefaultHeaderPart1(t);
   t << "Your title here";
   writeDefaultHeaderPart2(t);
@@ -963,12 +968,14 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 void LatexGenerator::writeFooterFile(QFile &f)
 {
   FTextStream t(&f);
+  t << "% Latex footer for doxygen " << versionString << endl;
   writeDefaultFooter(t);
 }
 
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
   FTextStream t(&f);
+  t << "% stylesheet for doxygen " << versionString << endl;
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -976,12 +983,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2012";
+  //t << "Dimitri van Heesch \\copyright~1997-2013";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2012";
+  //t << "Dimitri van Heesch \\copyright~1997-2013";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -1651,7 +1658,7 @@ void LatexGenerator::writeCodeLink(const char *ref,const char *f,
 {
   static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
-  int l = strlen(name);
+  int l = qstrlen(name);
   if (col+l>80)
   {
     t << "\n      ";
@@ -1968,7 +1975,7 @@ void LatexGenerator::codify(const char *str)
     //char cs[5];
     int spacesToNextTabStop;
     static int tabSize = Config_getInt("TAB_SIZE");
-    const int maxLineLen = 80;
+    const int maxLineLen = 108;
     QCString result(4*maxLineLen+1); // worst case for 1 line of 4-byte chars
     int i;
     while ((c=*p))
@@ -2097,7 +2104,7 @@ void LatexGenerator::startMemberTemplateParams()
   }
 }
 
-void LatexGenerator::endMemberTemplateParams(const char *)
+void LatexGenerator::endMemberTemplateParams(const char *,const char *)
 {
   if (templateMemberItem)
   {
@@ -2372,9 +2379,10 @@ void LatexGenerator::endParameterName(bool last,bool /* emptyList */,bool closeB
 }
 
 
-void LatexGenerator::printDoc(DocNode *n,const char *langExt)
+void LatexGenerator::writeDoc(DocNode *n,Definition *ctx,MemberDef *)
 {
-  LatexDocVisitor *visitor = new LatexDocVisitor(t,*this,langExt,insideTabbing);
+  LatexDocVisitor *visitor = 
+    new LatexDocVisitor(t,*this,ctx?ctx->getDefFileExtension():QCString(""),insideTabbing);
   n->accept(visitor);
   delete visitor; 
 }
@@ -2425,7 +2433,7 @@ void LatexGenerator::escapeLabelName(const char *s)
   if (s==0) return;
   const char *p=s;
   char c;
-  QCString result(strlen(s)+1); // worst case allocation
+  QCString result(qstrlen(s)+1); // worst case allocation
   int i;
   while ((c=*p++))
   {
@@ -2454,7 +2462,7 @@ void LatexGenerator::escapeMakeIndexChars(const char *s)
   if (s==0) return;
   const char *p=s;
   char c;
-  QCString result(strlen(s)+1); // worst case allocation
+  QCString result(qstrlen(s)+1); // worst case allocation
   int i;
   while ((c=*p++))
   {
