@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -45,7 +45,7 @@ class LatexGenerator : public OutputGenerator
     bool isEnabled(OutputType o) { return (o==Latex && active); } 
     OutputGenerator *get(OutputType o) { return (o==Latex) ? this : 0; }
 
-    void printDoc(DocNode *,const char *);
+    void writeDoc(DocNode *,Definition *ctx,MemberDef *);
 
     void startFile(const char *name,const char *manName,const char *title);
     void writeSearchInfo() {}
@@ -117,7 +117,7 @@ class LatexGenerator : public OutputGenerator
     void startMemberItem(const char *,int,const char *);
     void endMemberItem();
     void startMemberTemplateParams();
-    void endMemberTemplateParams(const char *);
+    void endMemberTemplateParams(const char *,const char *);
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -165,6 +165,8 @@ class LatexGenerator : public OutputGenerator
     void endSmall()         { t << "\\normalsize "; }
     void startMemberDescription(const char *,const char *);
     void endMemberDescription();
+    void startMemberDeclaration() {} 
+    void endMemberDeclaration(const char *,const char *) {}
     void writeInheritedSectionTitle(const char *,const char *,const char *,
                       const char *,const char *,const char *) {}
     void startDescList(SectionTypes)     { t << "\\begin{Desc}\n\\item["; }
@@ -196,10 +198,15 @@ class LatexGenerator : public OutputGenerator
     void endContents() {}
     void writeNonBreakableSpace(int);
     
-    void startDescTable()
-    { t << "\\begin{description}" << endl; }
+    void startDescTable(const char *title)
+    { startSimpleSect(EnumValues,0,0,title);
+      startDescForItem();
+      t << "\\begin{description}" << endl; }
     void endDescTable()
-    { t << "\\end{description}" << endl; }
+    { t << "\\end{description}" << endl; 
+      endDescForItem();
+      endSimpleSect();
+    }
     void startDescTableTitle()
     { t << "\\item[{\\em " << endl; }
     void endDescTableTitle()
@@ -261,6 +268,9 @@ class LatexGenerator : public OutputGenerator
 
     void writeCodeAnchor(const char *) {}
     void linkableSymbol(int,const char *,Definition *,Definition *) {}
+    void setCurrentDoc(Definition *,const char *,bool) {}
+    void addWord(const char *,bool) {}
+
 
   private:
     LatexGenerator(const LatexGenerator &);
