@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,6 +16,8 @@
  *
  */
 
+#include <qfileinfo.h> 
+
 #include "mandocvisitor.h"
 #include "docparser.h"
 #include "language.h"
@@ -25,8 +27,8 @@
 #include "dot.h"
 #include "util.h"
 #include "message.h"
-#include <qfileinfo.h> 
 #include "parserintf.h"
+#include "filedef.h"
 
 ManDocVisitor::ManDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                              const char *langExt) 
@@ -191,7 +193,7 @@ void ManDocVisitor::visit(DocStyleChange *s)
 void ManDocVisitor::visit(DocVerbatim *s)
 {
   if (m_hide) return;
-  switch(s->type())
+  switch (s->type())
   {
     case DocVerbatim::Code: // fall though
       if (!m_firstCol) m_t << endl;
@@ -978,6 +980,14 @@ void ManDocVisitor::visitPost(DocHtmlBlockQuote *)
   m_firstCol=TRUE;
 }
 
+void ManDocVisitor::visitPre(DocVhdlFlow *)
+{
+}
+
+void ManDocVisitor::visitPost(DocVhdlFlow *)
+{
+}
+
 
 void ManDocVisitor::filter(const char *str)
 { 
