@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -46,6 +46,8 @@
 #include "entry.h"
 #include "bufstr.h"
 #include "commentcnv.h"
+#include "config.h"
+#include "section.h"
 
 //-----------
 
@@ -93,7 +95,7 @@ static QCString       g_fileName;
 // as a title of the page, in effect making it a level0 header, so the
 // level of all other sections needs to be corrected as well.
 // This flag is TRUE if corrections are needed.
-static bool           g_correctSectionLevel;
+//static bool           g_correctSectionLevel;
 
 
 //----------
@@ -224,7 +226,7 @@ static QCString isBlockCommand(const char *data,int offset,int size)
 /** looks for the next emph char, skipping other constructs, and
  *  stopping when either it is found, or we are at the end of a paragraph.
  */
-static int findEmphasisChar(const char *data, int size, char c)
+static int findEmphasisChar(const char *data, int size, char c, int c_size)
 {
   int i = 1;
 
@@ -242,16 +244,25 @@ static int findEmphasisChar(const char *data, int size, char c)
       i++;
       continue;
     }
-    else if (data[i] == c)
+    else
     {
-      if (i<size-1 && isIdChar(i+1)) // to prevent touching some_underscore_identifier
+      // get length of emphasis token
+      int len = 0;
+      while (i+len<size && data[i+len]==c)
       {
-        i++;
-        continue;
+        len++;
       }
-      return i; // found it
-    }
 
+      if (len>0)
+      {
+        if (len!=c_size || (i<size-len && isIdChar(i+len))) // to prevent touching some_underscore_identifier
+        {
+          i=i+len;
+          continue;
+        }
+        return i; // found it
+      }
+    }
 
     // skipping a code span
     if (data[i]=='`')
@@ -280,7 +291,7 @@ static int findEmphasisChar(const char *data, int size, char c)
           if ((data[i]=='\\' || data[i]=='@') && // command
               data[i-1]!='\\' && data[i-1]!='@') // not escaped
           {
-            if (strncmp(&data[i+1],endBlockName,l)==0)
+            if (qstrncmp(&data[i+1],endBlockName,l)==0)
             {
               break;
             }
@@ -288,6 +299,10 @@ static int findEmphasisChar(const char *data, int size, char c)
           i++;
         }
       }
+      else if (i<size-1 && isIdChar(i+1)) // @cmd, stop processing, see bug 690385
+      {
+        return 0;
+      }
       else
       {
         i++;
@@ -318,7 +333,7 @@ static int processEmphasis1(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 1);
     if (len==0) return 0; 
     i+=len;
     if (i>=size) return 0; 
@@ -346,7 +361,7 @@ static int processEmphasis2(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 2);
     if (len==0)
     {
       return 0;
@@ -375,7 +390,7 @@ static int processEmphasis3(GrowBuf &out, const char *data, int size, char c)
 
   while (i<size)
   {
-    len = findEmphasisChar(data+i, size-i, c);
+    len = findEmphasisChar(data+i, size-i, c, 3);
     if (len==0)
     {
       return 0;
@@ -945,7 +960,7 @@ static int processSpecialCommand(GrowBuf &out, const char *data, int offset, int
       if ((data[i]=='\\' || data[i]=='@') && // command
           data[i-1]!='\\' && data[i-1]!='@') // not escaped
       {
-        if (strncmp(&data[i+1],endBlockName,l)==0)
+        if (qstrncmp(&data[i+1],endBlockName,l)==0)
         {
           //printf("found end at %d\n",i);
           out.addStr(data,i+1+l);
@@ -1618,8 +1633,8 @@ void writeOneLineHeaderOrRuler(GrowBuf &out,const char *data,int size)
   }
   else if ((level=isAtxHeader(data,size,header,id)))
   {
-    if (level==1) g_correctSectionLevel=FALSE;
-    if (g_correctSectionLevel) level--;
+    //if (level==1) g_correctSectionLevel=FALSE;
+    //if (g_correctSectionLevel) level--;
     QCString hTag;
     if (level<5 && !id.isEmpty())
     {
@@ -1648,7 +1663,7 @@ void writeOneLineHeaderOrRuler(GrowBuf &out,const char *data,int size)
       {
         g_current->anchors->append(si);
       }
-      Doxygen::sectionDict.append(header,si);
+      Doxygen::sectionDict->append(header,si);
     }
     else
     {
@@ -1689,7 +1704,8 @@ static int writeBlockQuote(GrowBuf &out,const char *data,int size)
       else if (j>0 && data[j-1]=='>') indent=j+1;
       j++;
     }
-    if (j>0 && data[j-1]=='>') // disqualify last > if not followed by space
+    if (j>0 && data[j-1]=='>' && 
+        !(j==size || data[j]=='\n')) // disqualify last > if not followed by space
     {
       indent--;
       j--;
@@ -1737,7 +1753,8 @@ static int writeCodeBlock(GrowBuf &out,const char *data,int size,int refIndent)
     int j=i;
     int indent=0;
     while (j<end && data[j]==' ') j++,indent++;
-    //printf("j=%d end=%d indent=%d refIndent=%d data={%s}\n",j,end,indent,refIndent,QCString(data+i).left(end-i-1).data());
+    //printf("j=%d end=%d indent=%d refIndent=%d tabSize=%d data={%s}\n",
+    //    j,end,indent,refIndent,Config_getInt("TAB_SIZE"),QCString(data+i).left(end-i-1).data());
     if (j==end-1) // empty line 
     {
       emptyLines++;
@@ -1797,7 +1814,7 @@ static void findEndOfLine(GrowBuf &out,const char *data,int size,
               data[end-1]!='\\' && data[end-1]!='@'
              )
           {
-            if (strncmp(&data[end+1],endBlockName,l)==0)
+            if (qstrncmp(&data[end+1],endBlockName,l)==0)
             {
               if (pi!=-1) // output previous line if available
               {
@@ -1953,8 +1970,8 @@ static QCString processBlocks(const QCString &s,int indent)
       //printf("isHeaderLine(%s)=%d\n",QCString(data+i).left(size-i).data(),level);
       if ((level=isHeaderline(data+i,size-i))>0)
       {
-        if (level==1) g_correctSectionLevel=FALSE;
-        if (g_correctSectionLevel) level--;
+        //if (level==1) g_correctSectionLevel=FALSE;
+        //if (g_correctSectionLevel) level--;
         //printf("Found header at %d-%d\n",i,end);
         while (pi<size && data[pi]==' ') pi++;
         QCString header,id;
@@ -1975,7 +1992,7 @@ static QCString processBlocks(const QCString &s,int indent)
             {
               g_current->anchors->append(si);
             }
-            Doxygen::sectionDict.append(header,si);
+            Doxygen::sectionDict->append(header,si);
           }
           else
           {
@@ -2007,14 +2024,14 @@ static QCString processBlocks(const QCString &s,int indent)
         //printf("Found FencedCodeBlock lang='%s' start=%d end=%d code={%s}\n",
         //       lang.data(),blockStart,blockEnd,QCString(data+pi+blockStart).left(blockEnd-blockStart).data());
         if (!lang.isEmpty() && lang.at(0)=='.') lang=lang.mid(1);
-        if (lang.isEmpty()) out.addStr("@verbatim"); else out.addStr("@code");
+        out.addStr("@code");
         if (!lang.isEmpty())
         {
           out.addStr("{"+lang+"}");
         }
         out.addStr(data+pi+blockStart,blockEnd-blockStart);       
         out.addStr("\n");
-        if (lang.isEmpty()) out.addStr("@endverbatim"); else out.addStr("@endcode");
+        out.addStr("@endcode");
         i=pi+blockOffset;
         pi=-1;
         end=i+1;
@@ -2116,6 +2133,7 @@ static QCString detab(const QCString &s,int &refIndent)
       case '\t': // expand tab
         {
           int stop = tabSize - (col%tabSize);
+          //printf("expand at %d stop=%d\n",col,stop);
           col+=stop;
           while (stop--) out.addChar(' '); 
         }
@@ -2144,6 +2162,22 @@ static QCString detab(const QCString &s,int &refIndent)
 
 QCString processMarkdown(const QCString &fileName,Entry *e,const QCString &input)
 {
+  static bool init=FALSE;
+  if (!init)
+  {
+    // setup callback table for special characters
+    g_actions[(unsigned int)'_']=processEmphasis;
+    g_actions[(unsigned int)'*']=processEmphasis;
+    g_actions[(unsigned int)'`']=processCodeSpan;
+    g_actions[(unsigned int)'\\']=processSpecialCommand;
+    g_actions[(unsigned int)'@']=processSpecialCommand;
+    g_actions[(unsigned int)'[']=processLink;
+    g_actions[(unsigned int)'!']=processLink;
+    g_actions[(unsigned int)'<']=processHtmlTag;
+    g_actions[(unsigned int)'-']=processNmdash;
+    init=TRUE;
+  }
+
   g_linkRefs.setAutoDelete(TRUE);
   g_linkRefs.clear();
   g_current = e;
@@ -2154,24 +2188,15 @@ QCString processMarkdown(const QCString &fileName,Entry *e,const QCString &input
   int refIndent;
   // for replace tabs by spaces
   QCString s = detab(input,refIndent);
+  //printf("======== DeTab =========\n---- output -----\n%s\n---------\n",s.data());
   // then process quotation blocks (as these may contain other blocks)
   s = processQuotations(s,refIndent);
   //printf("======== Quotations =========\n---- output -----\n%s\n---------\n",s.data());
   // then process block items (headers, rules, and code blocks, references)
   s = processBlocks(s,refIndent);
   //printf("======== Blocks =========\n---- output -----\n%s\n---------\n",s.data());
-  int size=s.length();
-  g_actions['_']=processEmphasis;
-  g_actions['*']=processEmphasis;
-  g_actions['`']=processCodeSpan;
-  g_actions['\\']=processSpecialCommand;
-  g_actions['@']=processSpecialCommand;
-  g_actions['[']=processLink;
-  g_actions['!']=processLink;
-  g_actions['<']=processHtmlTag;
-  g_actions['-']=processNmdash;
   // finally process the inline markup (links, emphasis and code spans)
-  processInline(out,s,size);
+  processInline(out,s,s.length());
   out.addChar(0);
   Debug::print(Debug::Markdown,0,"======== Markdown =========\n---- input ------- \n%s\n---- output -----\n%s\n---------\n",input.data(),out.get());
   return out.get();
@@ -2187,21 +2212,28 @@ void MarkdownFileParser::parseInput(const char *fileName,
   current->lang = SrcLangExt_Markdown;
   current->fileName = fileName;
   current->docFile  = fileName;
-  int len = strlen(fileBuf);
+  int len = qstrlen(fileBuf);
   BufStr input(len);
   BufStr output(len);
-  input.addArray(fileBuf,strlen(fileBuf));
+  input.addArray(fileBuf,qstrlen(fileBuf));
   input.addChar('\0');
   convertCppComments(&input,&output,fileName);
   output.addChar('\0');
   QCString docs = output.data();
   QCString id;
   QCString title=extractPageTitle(docs,id).stripWhiteSpace();
-  g_correctSectionLevel = !title.isEmpty();
-  QCString baseName = substitute(QFileInfo(fileName).baseName().utf8()," ","_");
+  //g_correctSectionLevel = !title.isEmpty();
+  QCString baseFn = QFileInfo(fileName).baseName().utf8();
+  QCString fn     = QFileInfo(fileName).fileName().utf8();
+  QCString baseName = substitute(baseFn," ","_");
+  static QCString mdfileAsMainPage = Config_getString("USE_MDFILE_AS_MAINPAGE");
   if (id.isEmpty()) id = "md_"+baseName;
   if (title.isEmpty()) title = baseName;
-  if (id=="mainpage" || id=="index")
+  if (fn==mdfileAsMainPage)
+  {
+    docs.prepend("@mainpage\n");
+  }
+  else if (id=="mainpage" || id=="index")
   {
     docs.prepend("@mainpage "+title+"\n");
   }
@@ -2249,7 +2281,7 @@ void MarkdownFileParser::parseInput(const char *fileName,
 
   // restore setting
   Doxygen::markdownSupport = markdownEnabled;
-  g_correctSectionLevel = FALSE;
+  //g_correctSectionLevel = FALSE;
 }
 
 void MarkdownFileParser::parseCode(CodeOutputInterface &codeOutIntf,
@@ -2262,7 +2294,8 @@ void MarkdownFileParser::parseCode(CodeOutputInterface &codeOutIntf,
                int endLine,
                bool inlineFragment,
                MemberDef *memberDef,
-               bool showLineNumbers
+               bool showLineNumbers,
+               Definition *searchCtx
               )
 {
   ParserInterface *pIntf = Doxygen::parserManager->getParser("*.cpp");
@@ -2270,7 +2303,7 @@ void MarkdownFileParser::parseCode(CodeOutputInterface &codeOutIntf,
   {
     pIntf->parseCode(
        codeOutIntf,scopeName,input,isExampleBlock,exampleName,
-       fileDef,startLine,endLine,inlineFragment,memberDef,showLineNumbers);
+       fileDef,startLine,endLine,inlineFragment,memberDef,showLineNumbers,searchCtx);
   }
 }
 
