@@ -9,6 +9,7 @@
 #include "definition.h"
 #include "groupdef.h"
 #include "example.h"
+#include "arguments.h"
 
 #define HEADER ('D'<<24)+('O'<<16)+('X'<<8)+'!'
 
@@ -54,32 +55,7 @@ void marshalQGString(StorageIntf *s,const QGString &str)
 
 void marshalArgumentList(StorageIntf *s,ArgumentList *argList)
 {
-  if (argList==0)
-  {
-    marshalUInt(s,NULL_LIST); // null pointer representation
-  }
-  else
-  {
-    marshalUInt(s,argList->count());
-    if (argList->count()>0)
-    {
-      ArgumentListIterator ali(*argList);
-      Argument *a;
-      for (ali.toFirst();(a=ali.current());++ali)
-      {
-        marshalQCString(s,a->attrib);    
-        marshalQCString(s,a->type);    
-        marshalQCString(s,a->canType);    
-        marshalQCString(s,a->name);    
-        marshalQCString(s,a->array);    
-        marshalQCString(s,a->defval);    
-        marshalQCString(s,a->docs);    
-      }
-    }
-    marshalBool(s,argList->constSpecifier);
-    marshalBool(s,argList->volatileSpecifier);
-    marshalBool(s,argList->pureSpecifier);
-  }
+  ArgumentList::marshal(s,argList);
 }
 
 void marshalArgumentLists(StorageIntf *s,QList<ArgumentList> *argLists)
@@ -157,6 +133,7 @@ void marshalSectionInfoList(StorageIntf *s, QList<SectionInfo> *anchors)
       marshalQCString(s,si->ref);
       marshalInt(s,(int)si->type);
       marshalQCString(s,si->fileName);
+      marshalInt(s,si->level);
     }
   }
 }
@@ -195,7 +172,7 @@ void marshalSectionDict(StorageIntf *s,SectionDict *sections)
   else
   {
     marshalUInt(s,sections->count());
-    QDictIterator<SectionInfo> sli(*sections);
+    SDict<SectionInfo>::IteratorDict sli(*sections);
     SectionInfo *si;
     for (sli.toFirst();(si=sli.current());++sli)
     {
@@ -486,28 +463,7 @@ QGString unmarshalQGString(StorageIntf *s)
 
 ArgumentList *unmarshalArgumentList(StorageIntf *s)
 {
-  uint i;
-  uint count = unmarshalUInt(s);
-  if (count==NULL_LIST) return 0; // null list
-  ArgumentList *result = new ArgumentList;
-  assert(count<1000000);
-  //printf("unmarshalArgumentList: %d\n",count);
-  for (i=0;i<count;i++)
-  {
-    Argument *a = new Argument;
-    a->attrib  = unmarshalQCString(s);
-    a->type    = unmarshalQCString(s);
-    a->canType = unmarshalQCString(s);
-    a->name    = unmarshalQCString(s);
-    a->array   = unmarshalQCString(s);
-    a->defval  = unmarshalQCString(s);
-    a->docs    = unmarshalQCString(s);
-    result->append(a);
-  }
-  result->constSpecifier    = unmarshalBool(s);
-  result->volatileSpecifier = unmarshalBool(s);
-  result->pureSpecifier     = unmarshalBool(s);
-  return result;
+  return ArgumentList::unmarshal(s);
 }
 
 QList<ArgumentList> *unmarshalArgumentLists(StorageIntf *s)
@@ -576,7 +532,8 @@ QList<SectionInfo> *unmarshalSectionInfoList(StorageIntf *s)
     QCString ref   = unmarshalQCString(s);
     SectionInfo::SectionType type = (SectionInfo::SectionType)unmarshalInt(s);
     QCString fileName = unmarshalQCString(s);
-    result->append(new SectionInfo(fileName,label,title,type,ref));
+    int level = unmarshalInt(s);
+    result->append(new SectionInfo(fileName,label,title,type,level,ref));
   }
   return result;
 }
@@ -619,7 +576,7 @@ SectionDict *unmarshalSectionDict(StorageIntf *s)
     QCString key    = unmarshalQCString(s);
     SectionInfo *si = (SectionInfo *)unmarshalObjPointer(s);
     //printf("  unmarshalSectionDict i=%d key=%s si=%s\n",count,key.data(),si->label.data());
-    result->insert(key,si);
+    result->append(key,si);
   }
   return result;
 }
