@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,14 +18,11 @@
 #ifndef MEMBERDEF_H
 #define MEMBERDEF_H
 
-#include "qtbc.h"
 #include <qlist.h>
-#include <qdict.h>
-#include <qstack.h>
+#include <sys/types.h>
 
 #include "types.h"
 #include "definition.h"
-#include "sortdict.h"
 
 class ClassDef;
 class NamespaceDef;
@@ -39,27 +36,14 @@ class GroupDef;
 class QTextStream;
 class ArgumentList;
 class MemberDefImpl;
+class QStrList;
+struct TagInfo;
 
 /** A model of a class/file/namespace member symbol. */
 class MemberDef : public Definition
 {
   public:
     
-    enum MemberType { 
-      Define,
-      Function, 
-      Variable, 
-      Typedef, 
-      Enumeration, 
-      EnumValue,
-      Signal,
-      Slot,
-      Friend,
-      DCOP,
-      Property,
-      Event
-    };
-
     MemberDef(const char *defFileName,int defLine,
               const char *type,const char *name,const char *args,
               const char *excp,Protection prot,Specifier virt,bool stat,
@@ -68,6 +52,7 @@ class MemberDef : public Definition
    ~MemberDef(); 
     DefType definitionType() const        { return TypeMember; }
     // move this member into a different scope
+    MemberDef *deepCopy() const;
     void moveTo(Definition *);
     
     //-----------------------------------------------------------------------------------
@@ -159,6 +144,10 @@ class MemberDef : public Definition
     bool isSealed() const;
     bool isImplementation() const;
     bool isExternal() const;
+    bool isAlias() const;
+    bool isDefault() const;
+    bool isDelete() const;
+    bool isNoExcept() const;
     bool isTemplateSpecialization() const;
     bool hasDocumentedParams() const;
     bool hasDocumentedReturnType() const;
@@ -196,6 +185,8 @@ class MemberDef : public Definition
     bool isDocsForDefinition() const;
     MemberDef *getEnumScope() const;
     LockingPtr< MemberList > enumFieldList() const;
+    void setEnumBaseType(const QCString &type);
+    QCString enumBaseType() const;
 
     bool hasExamples();
     LockingPtr<ExampleSDict> getExamples() const;
@@ -235,6 +226,7 @@ class MemberDef : public Definition
     MemberDef *getGroupAlias() const;
 
     ClassDef *category() const;
+    MemberDef *categoryRelation() const;
 
     QCString displayName(bool=TRUE) const;
 
@@ -246,7 +238,7 @@ class MemberDef : public Definition
     void setMemberType(MemberType t);
     void setDefinition(const char *d);
     void setFileDef(FileDef *fd);
-    void setAnchor(const char *a);
+    void setAnchor();
     void setProtection(Protection p);
     void setMemberSpecifiers(int s);
     void mergeMemberSpecifiers(int s);
@@ -334,6 +326,7 @@ class MemberDef : public Definition
     void copyArgumentNames(MemberDef *bmd);
 
     void setCategory(ClassDef *);
+    void setCategoryRelation(MemberDef *);
 
     void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
     void setBriefDescription(const char *b,const char *briefFile,int briefLine);
@@ -354,14 +347,13 @@ class MemberDef : public Definition
                             bool inGroup,bool showEnumValues=FALSE,bool
                             showInline=FALSE);
     void writeMemberDocSimple(OutputList &ol,Definition *container);
+    void writeEnumDeclaration(OutputList &typeDecl,
+            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
     void warnIfUndocumented();
     
     MemberDef *createTemplateInstanceMember(ArgumentList *formalArgs,
                ArgumentList *actualArgs);
 
-    void writeEnumDeclaration(OutputList &typeDecl,
-            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
-
     void findSectionsInDocumentation();
     
     bool visited;
@@ -387,6 +379,9 @@ class MemberDef : public Definition
     void _writeEnumValues(OutputList &ol,Definition *container,
                           const QCString &cfname,const QCString &ciname,
                           const QCString &cname);
+    void _writeCategoryRelation(OutputList &ol);
+    void _writeTagData();
+    void _addToSearchIndex();
 
     static int s_indentLevel;
     // disable copying of member defs
@@ -406,4 +401,6 @@ class MemberDef : public Definition
     uchar m_isDestructorCached;  // 0 = not cached, 1=FALSE, 2=TRUE
 };
 
+void combineDeclarationAndDefinition(MemberDef *mdec,MemberDef *mdef);
+
 #endif
