@@ -2,7 +2,7 @@
  *
  * $Id: membername.h,v 1.17 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,6 +22,7 @@
 #include "memberdef.h"
 #include "sortdict.h"
 
+/** Class representing all MemberDef objects with the same name */
 class MemberName : public QList<MemberDef>
 { 
   public:
@@ -29,26 +30,29 @@ class MemberName : public QList<MemberDef>
    ~MemberName();
     const char *memberName() const { return name; }
    
-    int compareItems(GCI item1,GCI item2);
+    int compareItems(QCollection::Item item1,QCollection::Item item2);
   private:
     QCString name;
 };
 
+/** Iterator for MemberDef objects in a MemberName list. */
 class MemberNameIterator : public QListIterator<MemberDef>
 {
   public:
     MemberNameIterator( const MemberName &list);
 };
 
+/** Sorted dictionary of MemberName objects. */
 class MemberNameSDict : public SDict<MemberName>
 {
   public:
     MemberNameSDict(int size) : SDict<MemberName>(size) {}
    ~MemberNameSDict() {}
 
-   int compareItems(GCI item1,GCI item2);
+   int compareItems(QCollection::Item item1,QCollection::Item item2);
 };
 
+/** Data associated with a MemberDef in an inheritance relation. */
 struct MemberInfo
 {
   MemberInfo(MemberDef *md,Protection p,Specifier v,bool inh) :
@@ -63,17 +67,19 @@ struct MemberInfo
   ClassDef  *ambigClass;
 };
 
+/** Class representing all MemberInfo objects with the same name */
 class MemberNameInfo : public QList<MemberInfo>
 {
   public:
     MemberNameInfo(const char *name);  
    ~MemberNameInfo() {}
     const char *memberName() const { return name; }
-    int compareItems(GCI item1,GCI item2);
+    int compareItems(QCollection::Item item1,QCollection::Item item2);
   private:
     QCString name;
 };
 
+/** Iterator for MemberInfo objects in a MemberNameInfo list. */
 class MemberNameInfoIterator : public QListIterator<MemberInfo>
 {
   public:
@@ -81,14 +87,14 @@ class MemberNameInfoIterator : public QListIterator<MemberInfo>
       : QListIterator<MemberInfo>(mnii) {}
 };
 
-
+/** Sorted dictionary of MemberNameInfo objects. */
 class MemberNameInfoSDict : public SDict<MemberNameInfo>
 {
   public:
     MemberNameInfoSDict(int size) : SDict<MemberNameInfo>(size) {}
    ~MemberNameInfoSDict() {}
-    int compareItems(GCI item1,GCI item2) 
-    { return stricmp(
+    int compareItems(QCollection::Item item1,QCollection::Item item2) 
+    { return qstricmp(
                     ((MemberNameInfo *)item1)->memberName(),
                     ((MemberNameInfo *)item2)->memberName()
                    );
