@@ -2,7 +2,7 @@
  *
  * $Id: msc.h,v 1.14 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,8 +18,7 @@
 #ifndef _MSC_H
 #define _MSC_H
 
-#include "qtbc.h"
-
+class QCString;
 class FTextStream;
 
 enum MscOutputFormat { MSC_BITMAP , MSC_EPS };
