@@ -22,9 +22,15 @@
 "\n"
 "function localStorageSupported()\n"
 "{\n"
-"  return 'localStorage' in window && window['localStorage'] !== null;\n"
+"  try {\n"
+"    return 'localStorage' in window && window['localStorage'] !== null && window.localStorage.getItem;\n"
+"  }\n"
+"  catch(e) {\n"
+"    return false;\n"
+"  }\n"
 "}\n"
 "\n"
+"\n"
 "function storeLink(link)\n"
 "{\n"
 "  if (!$(\"#nav-sync\").hasClass('sync') && localStorageSupported()) {\n"
@@ -57,7 +63,7 @@
 "  script.onload = func; \n"
 "  script.src = scriptName+'.js'; \n"
 "  if ($.browser.msie && $.browser.version<=8) { \n"
-"    // script.onload does work with older versions of IE\n"
+"    // script.onload does not work with older versions of IE\n"
 "    script.onreadystatechange = function() {\n"
 "      if (script.readyState=='complete' || script.readyState=='loaded') { \n"
 "        func(); if (show) showRoot(); \n"
@@ -69,24 +75,22 @@
 "\n"
 "function createIndent(o,domNode,node,level)\n"
 "{\n"
-"  if (node.parentNode && node.parentNode.parentNode) {\n"
-"    createIndent(o,domNode,node.parentNode,level+1);\n"
-"  }\n"
+"  var level=-1;\n"
+"  var n = node;\n"
+"  while (n.parentNode) { level++; n=n.parentNode; }\n"
 "  var imgNode = document.createElement(\"img\");\n"
-"  imgNode.width = 16;\n"
+"  imgNode.style.paddingLeft=(16*level).toString()+'px';\n"
+"  imgNode.width  = 16;\n"
 "  imgNode.height = 22;\n"
-"  if (level==0 && node.childrenData) {\n"
+"  imgNode.border = 0;\n"
+"  if (node.childrenData) {\n"
 "    node.plus_img = imgNode;\n"
 "    node.expandToggle = document.createElement(\"a\");\n"
 "    node.expandToggle.href = \"javascript:void(0)\";\n"
 "    node.expandToggle.onclick = function() {\n"
 "      if (node.expanded) {\n"
 "        $(node.getChildrenUL()).slideUp(\"fast\");\n"
-"        if (node.isLast) {\n"
-"          node.plus_img.src = node.relpath+\"ftv2plastnode.png\";\n"
-"        } else {\n"
-"          node.plus_img.src = node.relpath+\"ftv2pnode.png\";\n"
-"        }\n"
+"        node.plus_img.src = node.relpath+\"ftv2pnode.png\";\n"
 "        node.expanded = false;\n"
 "      } else {\n"
 "        expandNode(o, node, false, false);\n"
@@ -94,33 +98,39 @@
 "    }\n"
 "    node.expandToggle.appendChild(imgNode);\n"
 "    domNode.appendChild(node.expandToggle);\n"
+"    imgNode.src = node.relpath+\"ftv2pnode.png\";\n"
 "  } else {\n"
+"    imgNode.src = node.relpath+\"ftv2node.png\";\n"
 "    domNode.appendChild(imgNode);\n"
+"  } \n"
+"}\n"
+"\n"
+"var animationInProgress = false;\n"
+"\n"
+"function gotoAnchor(anchor,aname,updateLocation)\n"
+"{\n"
+"  var pos, docContent = $('#doc-content');\n"
+"  if (anchor.parent().attr('class')=='memItemLeft' ||\n"
+"      anchor.parent().attr('class')=='fieldtype' ||\n"
+"      anchor.parent().is(':header')) \n"
+"  {\n"
+"    pos = anchor.parent().position().top;\n"
+"  } else if (anchor.position()) {\n"
+"    pos = anchor.position().top;\n"
 "  }\n"
-"  if (level==0) {\n"
-"    if (node.isLast) {\n"
-"      if (node.childrenData) {\n"
-"        imgNode.src = node.relpath+\"ftv2plastnode.png\";\n"
-"      } else {\n"
-"        imgNode.src = node.relpath+\"ftv2lastnode.png\";\n"
-"        domNode.appendChild(imgNode);\n"
-"      }\n"
-"    } else {\n"
-"      if (node.childrenData) {\n"
-"        imgNode.src = node.relpath+\"ftv2pnode.png\";\n"
-"      } else {\n"
-"        imgNode.src = node.relpath+\"ftv2node.png\";\n"
-"        domNode.appendChild(imgNode);\n"
-"      }\n"
-"    }\n"
-"  } else {\n"
-"    if (node.isLast) {\n"
-"      imgNode.src = node.relpath+\"ftv2blank.png\";\n"
-"    } else {\n"
-"      imgNode.src = node.relpath+\"ftv2vertline.png\";\n"
-"    }\n"
+"  if (pos) {\n"
+"    var dist = Math.abs(Math.min(\n"
+"               pos-docContent.offset().top,\n"
+"               docContent[0].scrollHeight-\n"
+"               docContent.height()-docContent.scrollTop()));\n"
+"    animationInProgress=true;\n"
+"    docContent.animate({\n"
+"      scrollTop: pos + docContent.scrollTop() - docContent.offset().top\n"
+"    },Math.max(50,Math.min(500,dist)),function(){\n"
+"      if (updateLocation) window.location.href=aname;\n"
+"      animationInProgress=false;\n"
+"    });\n"
 "  }\n"
-"  imgNode.border = \"0\";\n"
 "}\n"
 "\n"
 "function newNode(o, po, text, link, childrenData, lastNode)\n"
@@ -164,7 +174,7 @@
 "      var aname = '#'+link.split('#')[1];\n"
 "      var srcPage = stripPath($(location).attr('pathname'));\n"
 "      var targetPage = stripPath(link.split('#')[0]);\n"
-"      a.href = srcPage!=targetPage ? url : '#';\n"
+"      a.href = srcPage!=targetPage ? url : \"javascript:void(0)\"; \n"
 "      a.onclick = function(){\n"
 "        storeLink(link);\n"
 "        if (!$(a).parent().parent().hasClass('selected'))\n"
@@ -174,23 +184,8 @@
 "          $(a).parent().parent().addClass('selected');\n"
 "          $(a).parent().parent().attr('id','selected');\n"
 "        }\n"
-"        var pos, anchor = $(aname), docContent = $('#doc-content');\n"
-"        if (anchor.parent().attr('class')=='memItemLeft') {\n"
-"          pos = anchor.parent().position().top;\n"
-"        } else if (anchor.position()) {\n"
-"          pos = anchor.position().top;\n"
-"        }\n"
-"        if (pos) {\n"
-"          var dist = Math.abs(Math.min(\n"
-"                     pos-docContent.offset().top,\n"
-"                     docContent[0].scrollHeight-\n"
-"                     docContent.height()-docContent.scrollTop()));\n"
-"          docContent.animate({\n"
-"            scrollTop: pos + docContent.scrollTop() - docContent.offset().top\n"
-"          },Math.max(50,Math.min(500,dist)),function(){\n"
-"            window.location.replace(aname);\n"
-"          });\n"
-"        }\n"
+"        var anchor = $(aname);\n"
+"        gotoAnchor(anchor,aname,true);\n"
 "      };\n"
 "    } else {\n"
 "      a.href = url;\n"
@@ -271,7 +266,8 @@
 "\n"
 "function highlightAnchor()\n"
 "{\n"
-"  var anchor = $($(location).attr('hash'));\n"
+"  var aname = $(location).attr('hash');\n"
+"  var anchor = $(aname);\n"
 "  if (anchor.parent().attr('class')=='memItemLeft'){\n"
 "    var rows = $('.memberdecls tr[class$=\"'+\n"
 "               window.location.hash.substring(1)+'\"]');\n"
@@ -285,6 +281,7 @@
 "  } else {\n"
 "    glowEffect(anchor.next(),1000); // normal member\n"
 "  }\n"
+"  gotoAnchor(anchor,aname,false);\n"
 "}\n"
 "\n"
 "function selectAndHighlight(hash,n)\n"
@@ -302,6 +299,11 @@
 "    $(n.itemDiv).addClass('selected');\n"
 "    $(n.itemDiv).attr('id','selected');\n"
 "  }\n"
+"  if ($('#nav-tree-contents .item:first').hasClass('selected')) {\n"
+"    $('#nav-sync').css('top','30px');\n"
+"  } else {\n"
+"    $('#nav-sync').css('top','5px');\n"
+"  }\n"
 "  showRoot();\n"
 "}\n"
 "\n"
@@ -338,7 +340,7 @@
 "          },true);\n"
 "        } else {\n"
 "          var rootBase = stripPath(o.toroot.replace(/\\..+$/, ''));\n"
-"          if (rootBase==\"index\" || rootBase==\"pages\") {\n"
+"          if (rootBase==\"index\" || rootBase==\"pages\" || rootBase==\"search\") {\n"
 "            expandNode(o, n, true, true);\n"
 "          }\n"
 "          selectAndHighlight(hash,n);\n"
@@ -385,11 +387,6 @@
 "    if (parts.length>1) hash = '#'+parts[1];\n"
 "    else hash='';\n"
 "  }\n"
-"  if (root==NAVTREE[0][1]) {\n"
-"    $('#nav-sync').css('top','30px');\n"
-"  } else {\n"
-"    $('#nav-sync').css('top','5px');\n"
-"  }\n"
 "  if (hash.match(/^#l\\d+$/)) {\n"
 "    var anchor=$('a[name='+hash.substring(1)+']');\n"
 "    glowEffect(anchor.parent(),1000); // line number\n"
@@ -399,6 +396,7 @@
 "  var url=root+hash;\n"
 "  var i=-1;\n"
 "  while (NAVTREEINDEX[i+1]<=url) i++;\n"
+"  if (i==-1) { i=0; root=NAVTREE[0][1]; } // fallback: show index\n"
 "  if (navTreeSubIndices[i]) {\n"
 "    gotoNode(o,i,root,hash,relpath)\n"
 "  } else {\n"
@@ -411,16 +409,26 @@
 "  }\n"
 "}\n"
 "\n"
+"function showSyncOff(n,relpath)\n"
+"{\n"
+"    n.html('<img src=\"'+relpath+'sync_off.png\" title=\"'+SYNCOFFMSG+'\"/>');\n"
+"}\n"
+"\n"
+"function showSyncOn(n,relpath)\n"
+"{\n"
+"    n.html('<img src=\"'+relpath+'sync_on.png\" title=\"'+SYNCONMSG+'\"/>');\n"
+"}\n"
+"\n"
 "function toggleSyncButton(relpath)\n"
 "{\n"
 "  var navSync = $('#nav-sync');\n"
 "  if (navSync.hasClass('sync')) {\n"
 "    navSync.removeClass('sync');\n"
-"    navSync.html('<img src=\"'+relpath+'sync_off.png\"/>');\n"
+"    showSyncOff(navSync,relpath);\n"
 "    storeLink(stripPath2($(location).attr('pathname'))+$(location).attr('hash'));\n"
 "  } else {\n"
 "    navSync.addClass('sync');\n"
-"    navSync.html('<img src=\"'+relpath+'sync_on.png\"/>');\n"
+"    showSyncOn(navSync,relpath);\n"
 "    deleteLink();\n"
 "  }\n"
 "}\n"
@@ -448,10 +456,10 @@
 "  if (localStorageSupported()) {\n"
 "    var navSync = $('#nav-sync');\n"
 "    if (cachedLink()) {\n"
-"      navSync.html('<img src=\"'+relpath+'sync_off.png\"/>');\n"
+"      showSyncOff(navSync,relpath);\n"
 "      navSync.removeClass('sync');\n"
 "    } else {\n"
-"      navSync.html('<img src=\"'+relpath+'sync_on.png\"/>');\n"
+"      showSyncOn(navSync,relpath);\n"
 "    }\n"
 "    navSync.click(function(){ toggleSyncButton(relpath); });\n"
 "  }\n"
@@ -472,6 +480,11 @@
 "       }\n"
 "       var link=stripPath2($(location).attr('pathname'));\n"
 "       navTo(o,link,$(location).attr('hash'),relpath);\n"
+"     } else if (!animationInProgress) {\n"
+"       $('#doc-content').scrollTop(0);\n"
+"       $('.item').removeClass('selected');\n"
+"       $('.item').removeAttr('id');\n"
+"       navTo(o,toroot,window.location.hash,relpath);\n"
 "     }\n"
 "  })\n"
 "\n"
