@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.cpp,v 1.15 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -17,7 +17,8 @@
 
 #include <stdlib.h>
 
-#include "qtbc.h"
+#include <qfile.h>
+
 #include "outputgen.h"
 #include "message.h"
 #include "portable.h"
