@@ -2,7 +2,7 @@
  *
  * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,11 @@
 #ifndef OUTPUTGEN_H
 #define OUTPUTGEN_H
 
-#include "qtbc.h"
-#include "ftextstream.h"
-#include <qbuffer.h>
-#include <qfile.h>
 #include <qstack.h>
+
 #include "index.h"
 #include "section.h"
+#include "ftextstream.h"
 
 class ClassDiagram;
 class DotClassGraph;
@@ -37,6 +35,7 @@ class DocNode;
 class MemberDef;
 class GroupDef;
 class Definition;
+class QFile;
 
 /** Output interface for code parser. 
  */
@@ -74,6 +73,8 @@ class CodeOutputInterface
     virtual void writeCodeAnchor(const char *name) = 0;
     virtual void linkableSymbol(int line,const char *symName,
                  Definition *symDef,Definition *context) = 0;
+    virtual void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile) = 0;
+    virtual void addWord(const char *word,bool hiPriority) = 0;
 };
 
 /** Base Interface used for generating output outside of the
@@ -97,8 +98,6 @@ class BaseOutputDocInterface : public CodeOutputInterface
                         Examples 
                       };
 
-    virtual void parseDoc(const char *,int, const char *,MemberDef *,
-                          const QCString &,bool)  {} 
     virtual void parseText(const QCString &)  {}
     
     /*! Start of a bullet list: e.g. \c \<ul\> in html. startItemListItem() is
@@ -247,7 +246,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void addIndexItem(const char *s1,const char *s2) = 0;
 
     virtual void writeNonBreakableSpace(int) = 0;
-    virtual void startDescTable() = 0;
+    virtual void startDescTable(const char *title) = 0;
     virtual void endDescTable() = 0;
     virtual void startDescTableTitle() = 0;
     virtual void endDescTableTitle() = 0;
@@ -294,7 +293,7 @@ class OutputGenerator : public BaseOutputDocInterface
     //void setEncoding(const QCString &enc) { encoding = enc; }
     //virtual void postProcess(QByteArray &) { }
 
-    virtual void printDoc(DocNode *,const char *langExt) = 0;
+    virtual void writeDoc(DocNode *,Definition *ctx,MemberDef *md) = 0;
 
     ///////////////////////////////////////////////////////////////
     // structural output interface
@@ -343,7 +342,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void startMemberItem(const char *,int,const char *) = 0;
     virtual void endMemberItem() = 0;
     virtual void startMemberTemplateParams() = 0;
-    virtual void endMemberTemplateParams(const char *) = 0;
+    virtual void endMemberTemplateParams(const char *,const char *) = 0;
     virtual void startMemberGroupHeader(bool) = 0;
     virtual void endMemberGroupHeader() = 0;
     virtual void startMemberGroupDocs() = 0;
@@ -364,6 +363,8 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void writeEndAnnoItem(const char *name) = 0;
     virtual void startMemberDescription(const char *anchor,const char *inheritId) = 0;
     virtual void endMemberDescription() = 0;
+    virtual void startMemberDeclaration() = 0;
+    virtual void endMemberDeclaration(const char *anchor,const char *inheritId) = 0;
     virtual void writeInheritedSectionTitle(const char *id,const char *ref,
                                             const char *file,const char *anchor,
                                             const char *title,const char *name) = 0;
@@ -478,7 +479,7 @@ class OutputDocInterface : public BaseOutputDocInterface
     /*! Enables a specific output format (useful for OutputList only) */
     virtual void enable(OutputGenerator::OutputType o) = 0;
 
-    /*! Check whether a specific output format is currenly enabled 
+    /*! Check whether a specific output format is currently enabled 
      *  (useful for OutputList only) 
      */
     virtual bool isEnabled(OutputGenerator::OutputType o) = 0;
