@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.cpp,v 1.35 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,8 +27,8 @@
 #include "config.h"
 #include "message.h"
 #include "definition.h"
-
 #include "docparser.h"
+#include "vhdldocgen.h"
 
 OutputList::OutputList(bool)
 {
@@ -166,10 +166,12 @@ void OutputList::parseDoc(const char *fileName,int startLine,
   {
     //printf("og->printDoc(extension=%s)\n",
     //    ctx?ctx->getDefFileExtension().data():"<null>");
-    if (og->isEnabled()) og->printDoc(root,ctx?ctx->getDefFileExtension():QCString(""));
+    if (og->isEnabled()) og->writeDoc(root,ctx,md);
     og=outputs->next();
   }
 
+  VhdlDocGen::setFlowMember(0);
+
   delete root;
 }
 
@@ -189,7 +191,7 @@ void OutputList::parseText(const QCString &textStr)
   og=outputs->first();
   while (og)
   {
-    if (og->isEnabled()) og->printDoc(root,0);
+    if (og->isEnabled()) og->writeDoc(root,0,0);
     og=outputs->next();
   }
 
@@ -319,6 +321,7 @@ FORALL3(const char *a1,const char *a2,bool a3,a1,a2,a3)
 FORALL3(const char *a1,int a2,const char *a3,a1,a2,a3)
 FORALL3(const char *a1,const char *a2,SectionInfo::SectionType a3,a1,a2,a3)
 FORALL3(uchar a1,uchar a2,uchar a3,a1,a2,a3)
+FORALL3(Definition *a1,const char *a2,bool a3,a1,a2,a3)
 FORALL4(SectionTypes a1,const char *a2,const char *a3,const char *a4,a1,a2,a3,a4)
 FORALL4(const char *a1,const char *a2,const char *a3,const char *a4,a1,a2,a3,a4)
 FORALL4(const char *a1,const char *a2,const char *a3,int a4,a1,a2,a3,a4)
