@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,6 @@
 #ifndef OUTPUTLIST_H
 #define OUTPUTLIST_H
 
-#include "qtbc.h"
 #include <qlist.h>
 #include "index.h" // for IndexSections
 #include "outputgen.h"
@@ -213,8 +212,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endMemberItem); }
     void startMemberTemplateParams() 
     { forall(&OutputGenerator::startMemberTemplateParams); }
-    void endMemberTemplateParams(const char *anchor) 
-    { forall(&OutputGenerator::endMemberTemplateParams,anchor); }
+    void endMemberTemplateParams(const char *anchor,const char *inheritId) 
+    { forall(&OutputGenerator::endMemberTemplateParams,anchor,inheritId); }
     void startMemberGroupHeader(bool b) 
     { forall(&OutputGenerator::startMemberGroupHeader,b); }
     void endMemberGroupHeader()
@@ -305,6 +304,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberDescription,anchor,inheritId); }
     void endMemberDescription() 
     { forall(&OutputGenerator::endMemberDescription); }
+    void startMemberDeclaration()
+    { forall(&OutputGenerator::startMemberDeclaration); }
+    void endMemberDeclaration(const char *anchor,const char *inheritId)
+    { forall(&OutputGenerator::endMemberDeclaration,anchor,inheritId); }
     void writeInheritedSectionTitle(const char *id,   const char *ref,
                                     const char *file, const char *anchor,
                                     const char *title,const char *name)
@@ -359,8 +362,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endContents); }
     void writeNonBreakableSpace(int num)
     { forall(&OutputGenerator::writeNonBreakableSpace,num); }
-    void startDescTable()
-    { forall(&OutputGenerator::startDescTable); }
+    void startDescTable(const char *title)
+    { forall(&OutputGenerator::startDescTable,title); }
     void endDescTable()
     { forall(&OutputGenerator::endDescTable); }
     void startDescTableTitle()
@@ -467,6 +470,11 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endFontClass); }
     void writeCodeAnchor(const char *name)
     { forall(&OutputGenerator::writeCodeAnchor,name); }
+    void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile)
+    { forall(&OutputGenerator::setCurrentDoc,context,anchor,isSourceFile); }
+    void addWord(const char *word,bool hiPriority)
+    { forall(&OutputGenerator::addWord,word,hiPriority); }
+
     void startPlainFile(const char *name)
     { 
       OutputGenerator *og=outputs->first();
@@ -526,6 +534,7 @@ class OutputList : public OutputDocInterface
     FORALLPROTO3(uchar,uchar,uchar);
     FORALLPROTO3(const char *,const char *,const char *);
     FORALLPROTO3(const ClassDiagram &,const char *,const char *);
+    FORALLPROTO3(Definition*,const char *,bool);
     FORALLPROTO4(SectionTypes,const char *,const char *,const char *);
     FORALLPROTO4(const char *,const char *,const char *,const char *);
     FORALLPROTO4(const char *,const char *,const char *,bool);
