@@ -2,7 +2,7 @@
  *
  * $Id: parserintf.h,v 1.15 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,6 +24,7 @@ class Entry;
 class FileDef;
 class CodeOutputInterface;
 class MemberDef;
+class Definition;
 
 /** \brief Abstract interface for programming language parsers.
  *
@@ -70,6 +71,7 @@ class ParserInterface
      *             for a member).
      *  @param[in] showLineNumbers if set to TRUE and also fileDef is not 0,
      *             line numbers will be added to the source fragement
+     *  @param[in] searchCtx context under which search data has to be stored.
      */
     virtual void parseCode(CodeOutputInterface &codeOutIntf,
                            const char *scopeName,
@@ -81,7 +83,8 @@ class ParserInterface
                            int endLine=-1,
                            bool inlineFragment=FALSE,
                            MemberDef *memberDef=0,
-                           bool showLineNumbers=TRUE
+                           bool showLineNumbers=TRUE,
+                           Definition *searchCtx=0
                           ) = 0;
 
     /** Resets the state of the code parser.
@@ -120,8 +123,8 @@ class ParserManager
      *  @param[in] name      A symbolic name of the parser, i.e. "c",
      *                       "python", "fortran", "vhdl", ...
      *  @param[in] parser    The parser that is to be used for the
-     *             given extension.
-     *  @param[in] defParser Use this parser as the default parser, using
+     *                       given name.
+     *  @param[in] defParser Use this parser as the default parser, used
      *                       for unregistered file extensions.
      */
     void registerParser(const char *name,ParserInterface *parser,bool defParser=FALSE)
