@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,8 @@
 #include <qfileinfo.h> 
 #include "parserintf.h"
 #include "msc.h"
-
+#include "filedef.h"
+#include "config.h"
 
 //#define DBG_RTF(x) m_t << x
 #define DBG_RTF(x) do {} while(0)
@@ -1669,6 +1670,16 @@ void RTFDocVisitor::visitPost(DocHtmlBlockQuote *)
   m_lastIsPara=TRUE;
 }
 
+void RTFDocVisitor::visitPre(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
+void RTFDocVisitor::visitPost(DocVhdlFlow *)
+{
+  if (m_hide) return;
+}
+
 
 //static char* getMultiByte(int c)
 //{
@@ -1683,7 +1694,7 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
   {
     const unsigned char *p=(const unsigned char *)str;
     unsigned char c;
-    unsigned char pc='\0';
+    //unsigned char pc='\0';
     while (*p)
     {
       //static bool MultiByte = FALSE;
@@ -1718,7 +1729,7 @@ void RTFDocVisitor::filter(const char *str,bool verbatim)
                    break;
         default:   m_t << (char)c;
       }
-      pc = c;
+      //pc = c;
     }
   }
 }
