@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -394,9 +394,9 @@ bool StyleData::setStyle(const char* s, const char* styleName)
     }
     else if (*end == '\\')
     {
-      if (0 == strncmp(end, "\\snext", 6))
+      if (0 == qstrncmp(end, "\\snext", 6))
         break;
-      if (0 == strncmp(end, "\\sbasedon", 9))
+      if (0 == qstrncmp(end, "\\sbasedon", 9))
         break;
       if (0 != any_clause.match(end, 0, &len))
         break;
@@ -443,7 +443,7 @@ void loadStylesheet(const char *name, QDict<StyleData>& dict)
   while (!t.eof())
   {
     QCString s(4096); // string buffer of max line length
-    s = t.readLine().stripWhiteSpace();
+    s = t.readLine().stripWhiteSpace().utf8();
     if (s.isEmpty() || s.at(0)=='#') continue; // skip blanks & comments
     int sepLength;
     int sepStart = separator.match(s,0,&sepLength);
@@ -490,7 +490,7 @@ void loadExtensions(const char *name)
   while (!t.eof())
   {
     QCString s(4096); // string buffer of max line length
-    s = t.readLine().stripWhiteSpace();
+    s = t.readLine().stripWhiteSpace().utf8();
     if (s.length()==0 || s.at(0)=='#') continue; // skip blanks & comments
     int sepLength;
     int sepStart = separator.match(s,0,&sepLength);
