@@ -2,7 +2,7 @@
  *
  * $Id: searchindex.cpp,v 1.7 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,14 +15,27 @@
  *
  */
 
-#include "qtbc.h"
+#include <ctype.h>
+#include <assert.h>
+
+#include <qfile.h>
+#include <qregexp.h>
+
 #include "searchindex.h"
 #include "config.h"
 #include "util.h"
-#include <qfile.h>
-#include <ctype.h>
-#include <qregexp.h>
-
+#include "doxygen.h"
+#include "language.h"
+#include "pagedef.h"
+#include "growbuf.h"
+#include "message.h"
+#include "version.h"
+#include "groupdef.h"
+#include "classlist.h"
+#include "filedef.h"
+#include "memberdef.h"
+#include "filename.h"
+#include "membername.h"
 
 // file format: (all multi-byte values are stored in big endian format)
 //   4 byte header
@@ -61,23 +74,107 @@ void IndexWord::addUrlIndex(int idx,bool hiPriority)
 
 //--------------------------------------------------------------------
 
-SearchIndex::SearchIndex() : m_words(328829), m_index(numIndexEntries), m_urlIndex(-1)
+SearchIndex::SearchIndex() : SearchIndexIntf(Internal), 
+      m_words(328829), m_index(numIndexEntries), m_url2IdMap(10007), m_urls(10007), m_urlIndex(-1)
 {
   int i;
   m_words.setAutoDelete(TRUE);
+  m_url2IdMap.setAutoDelete(TRUE);
   m_urls.setAutoDelete(TRUE);
   m_index.setAutoDelete(TRUE);
   for (i=0;i<numIndexEntries;i++) m_index.insert(i,new QList<IndexWord>);
 }
 
-void SearchIndex::setCurrentDoc(const char *name,const char *baseName,const char *anchor)
+void SearchIndex::setCurrentDoc(Definition *ctx,const char *anchor,bool isSourceFile)
 {
-  if (name==0 || baseName==0) return;
+  if (ctx==0) return;
+  assert(!isSourceFile || ctx->definitionType()==Definition::TypeFile);
   //printf("SearchIndex::setCurrentDoc(%s,%s,%s)\n",name,baseName,anchor);
-  QCString url=baseName+Config_getString("HTML_FILE_EXTENSION");
-  if (anchor) url+=(QCString)"#"+anchor;  
-  m_urlIndex++;
-  m_urls.insert(m_urlIndex,new URL(name,url));
+  QCString url=isSourceFile ? ((FileDef*)ctx)->getSourceFileBase() : ctx->getOutputFileBase();
+  url+=Config_getString("HTML_FILE_EXTENSION");
+  if (anchor) url+=QCString("#")+anchor;  
+  QCString name=ctx->qualifiedName();
+  if (ctx->definitionType()==Definition::TypeMember)
+  {
+    MemberDef *md = (MemberDef *)ctx;
+    name.prepend((md->getLanguage()==SrcLangExt_Fortran  ? 
+                 theTranslator->trSubprogram(TRUE,TRUE) :
+                 theTranslator->trMember(TRUE,TRUE))+" ");
+  }
+  else // compound type
+  {
+    SrcLangExt lang = ctx->getLanguage();
+    QCString sep = getLanguageSpecificSeparator(lang);
+    if (sep!="::")
+    {
+      name = substitute(name,"::",sep);
+    }
+    switch (ctx->definitionType())
+    {
+      case Definition::TypePage:
+        {
+          PageDef *pd = (PageDef *)ctx;
+          if (!pd->title().isEmpty())
+          {
+            name = theTranslator->trPage(TRUE,TRUE)+" "+pd->title();
+          }
+          else
+          {
+            name = theTranslator->trPage(TRUE,TRUE)+" "+pd->name();
+          }
+        }
+        break;
+      case Definition::TypeClass:
+        {
+          ClassDef *cd = (ClassDef *)ctx;
+          name.prepend(cd->compoundTypeString()+" ");
+        }
+        break;
+      case Definition::TypeNamespace:
+        {
+          if (lang==SrcLangExt_Java || lang==SrcLangExt_CSharp)
+          {
+            name = theTranslator->trPackage(name);
+          }
+          else if (lang==SrcLangExt_Fortran)
+          {
+            name.prepend(theTranslator->trModule(TRUE,TRUE)+" ");
+          }
+          else
+          {
+            name.prepend(theTranslator->trNamespace(TRUE,TRUE)+" ");
+          }
+        }
+        break;
+      case Definition::TypeGroup:
+        {
+          GroupDef *gd = (GroupDef *)ctx;
+          if (gd->groupTitle())
+          {
+            name = theTranslator->trGroup(TRUE,TRUE)+" "+gd->groupTitle();
+          }
+          else
+          {
+            name.prepend(theTranslator->trGroup(TRUE,TRUE)+" ");
+          }
+        }
+        break;
+      default:
+        break;
+    }
+  }
+
+  int *pIndex = m_url2IdMap.find(url);
+  if (pIndex==0)
+  {
+    ++m_urlIndex;
+    m_url2IdMap.insert(url,new int(m_urlIndex));
+    m_urls.insert(m_urlIndex,new URL(name,url));
+  }
+  else
+  {
+    m_urls.insert(*pIndex,new URL(name,url));
+  }
 }
 
 static int charsToIndex(const char *word)
@@ -95,9 +192,9 @@ static int charsToIndex(const char *word)
   //return h;
 
   // Simple hashing that allows for substring searching
-  uint c1=word[0];
+  uint c1=((uchar *)word)[0];
   if (c1==0) return -1;
-  uint c2=word[1];
+  uint c2=((uchar *)word)[1];
   if (c2==0) return -1;
   return c1*256+c2;
 }
@@ -105,17 +202,16 @@ static int charsToIndex(const char *word)
 void SearchIndex::addWord(const char *word,bool hiPriority,bool recurse)
 {
   static QRegExp nextPart("[_a-z:][A-Z]");
-  //printf("SearchIndex::addWord(%s,%d)\n",word,hiPriority);
-  QString wStr(word);
-  if (wStr.isEmpty()) return;
-  wStr=wStr.lower();
+  if (word==0 || word[0]=='\0') return;
+  QCString wStr = QCString(word).lower();
+  //printf("SearchIndex::addWord(%s,%d) wStr=%s\n",word,hiPriority,wStr.data());
   IndexWord *w = m_words[wStr];
   if (w==0)
   {
     int idx=charsToIndex(wStr);
+    //fprintf(stderr,"addWord(%s) at index %d\n",word,idx);
     if (idx<0) return;
     w = new IndexWord(wStr);
-    //fprintf(stderr,"addWord(%s) at index %d\n",word,idx);
     m_index[idx]->append(w);
     m_words.insert(wStr,w);
   }
@@ -140,6 +236,10 @@ void SearchIndex::addWord(const char *word,bool hiPriority,bool recurse)
   }
 }
 
+void SearchIndex::addWord(const char *word,bool hiPriority)
+{
+  addWord(word,hiPriority,FALSE);
+}
 
 static void writeInt(QFile &f,int index)
 {
@@ -305,11 +405,197 @@ void SearchIndex::write(const char *fileName)
   delete[] wordStatOffsets;
 }
 
+
+//---------------------------------------------------------------------------
+// the following part is for writing an external search index
+
+struct SearchDocEntry
+{
+  QCString type;
+  QCString name;
+  QCString args;
+  QCString extId;
+  QCString url; 
+  GrowBuf  importantText;
+  GrowBuf  normalText;
+};
+
+struct SearchIndexExternal::Private
+{
+  Private() : docEntries(257) {}
+  //QFile f;
+  //bool openOk;
+  //FTextStream t;
+  //bool insideDoc;
+  SDict<SearchDocEntry> docEntries;
+  SearchDocEntry *current;
+};
+
+SearchIndexExternal::SearchIndexExternal() : SearchIndexIntf(External)
+{
+  p = new SearchIndexExternal::Private;
+  p->docEntries.setAutoDelete(TRUE);
+  p->current=0;
+  //p->f.setName(fileName);
+  //p->openOk = p->f.open(IO_WriteOnly);
+  //if (p->openOk) 
+  //{
+  //  p->t.setDevice(&p->f);
+  //  p->t << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
+  //  p->t << "<add>" << endl;
+  //  p->insideDoc=FALSE;
+  //}
+}
+
+SearchIndexExternal::~SearchIndexExternal()
+{
+  //if (p->openOk)
+  //{
+  //  if (p->insideDoc)
+  //  {
+  //    p->t << "  </doc>" << endl;
+  //  }
+  //  p->t << "</add>" << endl;
+  //  p->f.close();
+  //  p->openOk=FALSE;
+  //}
+  delete p;
+}
+
+static QCString definitionToName(Definition *ctx)
+{
+  if (ctx->definitionType()==Definition::TypeMember)
+  {
+    MemberDef *md = (MemberDef*)ctx;
+    if (md->isFunction())
+      return "function";
+    else if (md->isSlot())
+      return "slot";
+    else if (md->isSignal())
+      return "signal";
+    else if (md->isVariable())
+      return "variable";
+    else if (md->isTypedef())
+      return "typedef";
+    else if (md->isEnumerate())
+      return "enum";
+    else if (md->isEnumValue())
+      return "enumvalue";
+    else if (md->isProperty())
+      return "property";
+    else if (md->isEvent())
+      return "event";
+    else if (md->isRelated() || md->isForeign())
+      return "related";
+    else if (md->isFriend())
+      return "friend";
+    else if (md->isDefine())
+      return "define";
+  }
+  else if (ctx)
+  {
+    switch(ctx->definitionType())
+    {
+      case Definition::TypeClass: 
+        return ((ClassDef*)ctx)->compoundTypeString();
+      case Definition::TypeFile:
+        return "file";
+      case Definition::TypeNamespace:
+        return "namespace";
+      case Definition::TypeGroup:
+        return "group";
+      case Definition::TypePackage:
+        return "package";
+      case Definition::TypePage:
+        return "page";
+      case Definition::TypeDir:
+        return "dir";
+      default:
+        break;
+    }
+  }
+  return "unknown";
+}
+
+void SearchIndexExternal::setCurrentDoc(Definition *ctx,const char *anchor,bool isSourceFile)
+{
+  QCString extId = stripPath(Config_getString("EXTERNAL_SEARCH_ID"));
+  QCString baseName = isSourceFile ? ((FileDef*)ctx)->getSourceFileBase() : ctx->getOutputFileBase();
+  QCString url = baseName + Doxygen::htmlFileExtension;
+  if (anchor) url+=QCString("#")+anchor;
+  QCString key = extId+";"+url;
+
+  p->current = p->docEntries.find(key);
+  if (!p->current)
+  {
+    SearchDocEntry *e = new SearchDocEntry;
+    e->type = isSourceFile ? QCString("source") : definitionToName(ctx);
+    e->name = ctx->qualifiedName();
+    if (ctx->definitionType()==Definition::TypeMember)
+    {
+      e->args = ((MemberDef*)ctx)->argsString();
+    }
+    e->extId = extId;
+    e->url  = url;
+    p->current = e;
+    p->docEntries.append(key,e);
+    //printf("searchIndexExt %s : %s\n",e->name.data(),e->url.data());
+  }
+}
+
+void SearchIndexExternal::addWord(const char *word,bool hiPriority)
+{
+  if (word==0 || !isId(*word) || p->current==0) return;
+  GrowBuf *pText = hiPriority ? &p->current->importantText : &p->current->normalText;
+  if (pText->getPos()>0) pText->addChar(' ');
+  pText->addStr(word);
+  //printf("addWord %s\n",word);
+}
+
+void SearchIndexExternal::write(const char *fileName)
+{
+  QFile f(fileName);
+  if (f.open(IO_WriteOnly))
+  {
+    FTextStream t(&f);
+    t << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
+    t << "<add>" << endl;
+    SDict<SearchDocEntry>::Iterator it(p->docEntries);
+    SearchDocEntry *doc;
+    for (it.toFirst();(doc=it.current());++it)
+    {
+      doc->normalText.addChar(0);    // make sure buffer ends with a 0 terminator
+      doc->importantText.addChar(0); // make sure buffer ends with a 0 terminator
+      t << "  <doc>" << endl;
+      t << "    <field name=\"type\">"     << doc->type << "</field>" << endl;
+      t << "    <field name=\"name\">"     << convertToXML(doc->name) << "</field>" << endl;
+      if (!doc->args.isEmpty())
+      {
+        t << "    <field name=\"args\">"     << convertToXML(doc->args) << "</field>" << endl;
+      }
+      if (!doc->extId.isEmpty())
+      {
+        t << "    <field name=\"tag\">"      << convertToXML(doc->extId)  << "</field>" << endl;
+      }
+      t << "    <field name=\"url\">"      << convertToXML(doc->url)  << "</field>" << endl;
+      t << "    <field name=\"keywords\">" << convertToXML(doc->importantText.get())  << "</field>" << endl;
+      t << "    <field name=\"text\">"     << convertToXML(doc->normalText.get())     << "</field>" << endl;
+      t << "  </doc>" << endl;
+    }
+    t << "</add>" << endl;
+  }
+  else
+  {
+    err("Failed to open file %s for writing!\n",fileName);
+  }
+}
+
 //---------------------------------------------------------------------------
 // the following part is for the javascript based search engine
 
 #include "memberdef.h"
 #include "namespacedef.h"
+#include "pagedef.h"
 #include "classdef.h"
 #include "filedef.h"
 #include "language.h"
@@ -321,7 +607,7 @@ static const char search_script[]=
 ;
 
 #define MEMBER_INDEX_ENTRIES   256
-#define NUM_SEARCH_INDICES      13
+
 #define SEARCH_INDEX_ALL         0
 #define SEARCH_INDEX_CLASSES     1
 #define SEARCH_INDEX_NAMESPACES  2
@@ -335,6 +621,9 @@ static const char search_script[]=
 #define SEARCH_INDEX_EVENTS     10
 #define SEARCH_INDEX_RELATED    11
 #define SEARCH_INDEX_DEFINES    12
+#define SEARCH_INDEX_GROUPS     13
+#define SEARCH_INDEX_PAGES      14
+#define NUM_SEARCH_INDICES      15
 
 class SearchIndexList : public SDict< QList<Definition> >
 {
@@ -354,13 +643,13 @@ class SearchIndexList : public SDict< QList<Definition> >
       }
       l->append(d);
     }
-    int compareItems(GCI item1, GCI item2)
+    int compareItems(QCollection::Item item1, QCollection::Item item2)
     {
       QList<Definition> *md1=(QList<Definition> *)item1;
       QList<Definition> *md2=(QList<Definition> *)item2;
       QCString n1 = md1->first()->localName();
       QCString n2 = md2->first()->localName();
-      return stricmp(n1.data(),n2.data());
+      return qstricmp(n1.data(),n2.data());
     }
 };
 
@@ -374,10 +663,13 @@ static void addMemberToSearchIndex(
   ClassDef *cd=0;
   NamespaceDef *nd=0;
   FileDef *fd=0;
-  if (isLinkable             && 
-      (cd=md->getClassDef()) && 
-      cd->isLinkable()       &&
-      cd->templateMaster()==0)
+  GroupDef *gd=0;
+  if (isLinkable && 
+      (
+       ((cd=md->getClassDef()) && cd->isLinkable() && cd->templateMaster()==0) ||
+       ((gd=md->getGroupDef()) && gd->isLinkable())
+      )
+     )
   {
     QCString n = md->name();
     uchar charCode = (uchar)n.at(0);
@@ -522,7 +814,9 @@ static const char *g_searchIndexName[NUM_SEARCH_INDICES] =
     "properties", 
     "events", 
     "related",
-    "defines"
+    "defines",
+    "groups",
+    "pages"
 };
 
 
@@ -544,6 +838,8 @@ class SearchIndexCategoryMapping
       categoryLabel[SEARCH_INDEX_EVENTS]     = theTranslator->trEvents();
       categoryLabel[SEARCH_INDEX_RELATED]    = theTranslator->trFriends();
       categoryLabel[SEARCH_INDEX_DEFINES]    = theTranslator->trDefines();
+      categoryLabel[SEARCH_INDEX_GROUPS]     = theTranslator->trGroup(TRUE,FALSE);
+      categoryLabel[SEARCH_INDEX_PAGES]      = theTranslator->trPage(TRUE,FALSE);
     }
     QCString categoryLabel[NUM_SEARCH_INDICES];
 };
@@ -638,6 +934,68 @@ void writeJavascriptSearchIndex()
       }
     }
   }
+
+  // index groups
+  GroupSDict::Iterator gli(*Doxygen::groupSDict);
+  GroupDef *gd;
+  for (gli.toFirst();(gd=gli.current());++gli)
+  {
+    if (gd->isLinkable())
+    {
+      QCString title = gd->groupTitle();
+      if (!title.isEmpty()) // TODO: able searching for all word in the title
+      {
+        uchar charCode = title.at(0);
+        uint letter = charCode<128 ? tolower(charCode) : charCode;
+        if (isId(letter))
+        {
+          g_searchIndexSymbols[SEARCH_INDEX_ALL][letter].append(gd);
+          g_searchIndexSymbols[SEARCH_INDEX_GROUPS][letter].append(gd);
+          g_searchIndexCount[SEARCH_INDEX_ALL]++;
+          g_searchIndexCount[SEARCH_INDEX_GROUPS]++;
+        }
+      }
+    }
+  }
+
+  // index pages
+  PageSDict::Iterator pdi(*Doxygen::pageSDict);
+  PageDef *pd=0;
+  for (pdi.toFirst();(pd=pdi.current());++pdi)
+  {
+    if (pd->isLinkable())
+    {
+      QCString title = pd->title();
+      if (!title.isEmpty())
+      {
+        uchar charCode = title.at(0);
+        uint letter = charCode<128 ? tolower(charCode) : charCode;
+        if (isId(letter))
+        {
+          g_searchIndexSymbols[SEARCH_INDEX_ALL][letter].append(pd);
+          g_searchIndexSymbols[SEARCH_INDEX_PAGES][letter].append(pd);
+          g_searchIndexCount[SEARCH_INDEX_ALL]++;
+          g_searchIndexCount[SEARCH_INDEX_PAGES]++;
+        }
+      }
+    }
+  }
+  if (Doxygen::mainPage)
+  {
+    QCString title = Doxygen::mainPage->title();
+    if (!title.isEmpty())
+    {
+      uchar charCode = title.at(0);
+      uint letter = charCode<128 ? tolower(charCode) : charCode;
+      if (isId(letter))
+      {
+        g_searchIndexSymbols[SEARCH_INDEX_ALL][letter].append(Doxygen::mainPage);
+        g_searchIndexSymbols[SEARCH_INDEX_PAGES][letter].append(Doxygen::mainPage);
+        g_searchIndexCount[SEARCH_INDEX_ALL]++;
+        g_searchIndexCount[SEARCH_INDEX_PAGES]++;
+      }
+    }
+  }
   
   // sort all lists
   int i,p;
@@ -678,6 +1036,7 @@ void writeJavascriptSearchIndex()
               " \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">" << endl;
             t << "<html><head><title></title>" << endl;
             t << "<meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>" << endl;
+            t << "<meta name=\"generator\" content=\"Doxygen " << versionString << "\">" << endl;
             t << "<link rel=\"stylesheet\" type=\"text/css\" href=\"search.css\"/>" << endl;
             t << "<script type=\"text/javascript\" src=\"" << baseName << ".js\"></script>" << endl;
             t << "<script type=\"text/javascript\" src=\"search.js\"></script>" << endl;
@@ -727,9 +1086,6 @@ void writeJavascriptSearchIndex()
           {
             Definition *d = dl->first();
             QCString id = d->localName();
-//            t << "<div class=\"SRResult\" id=\"SR_"
-//              << searchId(d->localName()) << "\">" << endl;
-//            t << " <div class=\"SREntry\">\n";
 
             if (!firstEntry)
             {
@@ -737,30 +1093,24 @@ void writeJavascriptSearchIndex()
             }
             firstEntry=FALSE;
 
-            ti << "  ['" << searchId(d->localName()) << "',['" 
-               << d->localName() << "',[";
+            QCString dispName = d->localName();
+            if (d->definitionType()==Definition::TypeGroup)
+            {
+              dispName = ((GroupDef*)d)->groupTitle();
+            }
+            else if (d->definitionType()==Definition::TypePage)
+            {
+              dispName = ((PageDef*)d)->title();
+            }
+            ti << "  ['" << searchId(dispName) << "',['" 
+               << convertToXML(dispName) << "',[";
 
             if (dl->count()==1) // item with a unique name
             {
               MemberDef  *md   = 0;
               bool isMemberDef = d->definitionType()==Definition::TypeMember;
               if (isMemberDef) md = (MemberDef*)d;
-//              t << "  <a id=\"Item" << itemCount << "\" "
-//                << "onkeydown=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "onkeypress=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "onkeyup=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "class=\"SRSymbol\" ";
-//              t << externalLinkTarget() << "href=\"" << externalRef("../",d->getReference(),TRUE);
-//              t << d->getOutputFileBase() << Doxygen::htmlFileExtension;
               QCString anchor = d->anchor();
-//              if (!anchor.isEmpty())
-//              {
-//                t << "#" << anchor;
-//              }
-//              t << "\"";
 
               ti << "'" << externalRef("../",d->getReference(),TRUE)
                  << d->getOutputFileBase() << Doxygen::htmlFileExtension;
@@ -773,24 +1123,15 @@ void writeJavascriptSearchIndex()
               static bool extLinksInWindow = Config_getBool("EXT_LINKS_IN_WINDOW");
               if (!extLinksInWindow || d->getReference().isEmpty())
               {
-//                t << " target=\"_parent\"";
                 ti << "1,";
               }
               else
               {
                 ti << "0,";
               }
-//              t << ">";
-//              t << convertToXML(d->localName());
-//              t << "</a>" << endl;
-
 
               if (d->getOuterScope()!=Doxygen::globalScope)
               {
-//                t << "  <span class=\"SRScope\">" 
-//                  << convertToXML(d->getOuterScope()->name()) 
-//                  << "</span>" << endl;
-
                 ti << "'" << convertToXML(d->getOuterScope()->name()) << "'";
               }
               else if (md)
@@ -799,10 +1140,6 @@ void writeJavascriptSearchIndex()
                 if (fd==0) fd = md->getFileDef();
                 if (fd)
                 {
-//                  t << "  <span class=\"SRScope\">" 
-//                    << convertToXML(fd->localName())
-//                    << "</span>" << endl;
-                 
                   ti << "'" << convertToXML(fd->localName()) << "'";
                 }
               }
@@ -814,19 +1151,6 @@ void writeJavascriptSearchIndex()
             }
             else // multiple items with the same name
             {
-//              t << "  <a id=\"Item" << itemCount << "\" "
-//                << "onkeydown=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "onkeypress=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "onkeyup=\""
-//                << "return searchResults.Nav(event," << itemCount << ")\" "
-//                << "class=\"SRSymbol\" "
-//                << "href=\"javascript:searchResults.Toggle('SR_"
-//                << searchId(d->localName()) << "')\">" 
-//                << convertToXML(d->localName()) << "</a>" << endl;
-//              t << "  <div class=\"SRChildren\">" << endl;
-
               QListIterator<Definition> di(*dl);
               bool overloadedFunction = FALSE;
               Definition *prevScope = 0;
@@ -841,31 +1165,7 @@ void writeJavascriptSearchIndex()
                 bool isMemberDef = d->definitionType()==Definition::TypeMember;
                 if (isMemberDef) md = (MemberDef*)d;
                 if (next) nextScope = next->getOuterScope();
-
-//                t << "    <a id=\"Item" << itemCount << "_c" 
-//                  << childCount << "\" "
-//                  << "onkeydown=\""
-//                  << "return searchResults.NavChild(event," 
-//                  << itemCount << "," << childCount << ")\" "
-//                  << "onkeypress=\""
-//                  << "return searchResults.NavChild(event," 
-//                  << itemCount << "," << childCount << ")\" "
-//                  << "onkeyup=\""
-//                  << "return searchResults.NavChild(event," 
-//                  << itemCount << "," << childCount << ")\" "
-//                  << "class=\"SRScope\" ";
-//                if (!d->getReference().isEmpty())
-//                {
-//                  t << externalLinkTarget() << externalRef("../",d->getReference(),FALSE);
-//                }
-//                t << "href=\"" << externalRef("../",d->getReference(),TRUE);
-//                t << d->getOutputFileBase() << Doxygen::htmlFileExtension;
                 QCString anchor = d->anchor();
-//                if (!anchor.isEmpty())
-//                {
-//                  t << "#" << anchor;
-//                }
-//                t << "\"";
 
                 if (childCount>0)
                 {
@@ -882,14 +1182,12 @@ void writeJavascriptSearchIndex()
                 static bool extLinksInWindow = Config_getBool("EXT_LINKS_IN_WINDOW");
                 if (!extLinksInWindow || d->getReference().isEmpty())
                 {
-//                  t << " target=\"_parent\"";
                   ti << "1,";
                 }
                 else
                 {
                   ti << "0,";
                 }
-//                t << ">";
                 bool found=FALSE;
                 overloadedFunction = ((prevScope!=0 && scope==prevScope) ||
                                       (scope && scope==nextScope)
@@ -900,7 +1198,7 @@ void writeJavascriptSearchIndex()
                 if (overloadedFunction) // overloaded member function
                 {
                   prefix+=convertToXML(md->argsString()); 
-                          // show argument list to disambiguate overloaded functions
+                  // show argument list to disambiguate overloaded functions
                 }
                 else if (md) // unique member function
                 {
@@ -948,21 +1246,16 @@ void writeJavascriptSearchIndex()
                 {
                   name = prefix + "("+theTranslator->trGlobalNamespace()+")";
                 }
-//                t << name;
-//                t << "</a>" << endl;
 
                 ti << "'" << name << "'";
 
                 prevScope = scope;
                 childCount++;
               }
-//              t << "  </div>" << endl; // SRChildren
 
               ti << "]]";
             }
             ti << "]";
-//            t << " </div>" << endl; // SREntry
-//            t << "</div>" << endl; // SRResult
             itemCount++;
           }
           if (!firstEntry)
@@ -980,7 +1273,6 @@ void writeJavascriptSearchIndex()
       }
     }
   }
-  //ol.popGeneratorState();
 
   {
     QFile f(searchDirName+"/search.js");
@@ -1053,7 +1345,7 @@ void writeJavascriptSearchIndex()
       t << "</html>" << endl;
     }
   }
-  Doxygen::indexList.addStyleSheetFile("search/search.js");
+  Doxygen::indexList->addStyleSheetFile("search/search.js");
 }
 
 void writeSearchCategories(FTextStream &t)
@@ -1074,5 +1366,33 @@ void writeSearchCategories(FTextStream &t)
   }
 }
 
+//---------------------------------------------------------------------------------------------
+
+void initSearchIndexer()
+{
+  static bool searchEngine      = Config_getBool("SEARCHENGINE");
+  static bool serverBasedSearch = Config_getBool("SERVER_BASED_SEARCH");
+  static bool externalSearch    = Config_getBool("EXTERNAL_SEARCH");
+  if (searchEngine && serverBasedSearch)
+  {
+    if (externalSearch) // external tools produce search index and engine
+    {
+      Doxygen::searchIndex = new SearchIndexExternal;
+    }
+    else // doxygen produces search index and engine
+    {
+      Doxygen::searchIndex = new SearchIndex;
+    }
+  }
+  else // no search engine or pure javascript based search function
+  {
+    Doxygen::searchIndex = 0;
+  }
+}
+
+void finializeSearchIndexer()
+{
+  delete Doxygen::searchIndex;
+}
 
 
