@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -126,6 +126,10 @@ class TextDocVisitor : public DocVisitor
     void visitPost(DocCopy *) {}
     void visitPre(DocText *) {}
     void visitPost(DocText *) {}
+    void visitPre(DocHtmlBlockQuote *) {}
+    void visitPost(DocHtmlBlockQuote *) {}
+    void visitPre(DocVhdlFlow *) {}
+    void visitPost(DocVhdlFlow *) {}
 
   private:
 
