@@ -3,9 +3,8 @@
 
 #include "version.h"
 
-/*! \brief Base of the translator adapter tree
+/** Base of the translator adapter tree.
  *
- 
  *  This abstract class provides access to the english
  *  translations, to be used as a substitute for not implemented
  *  local translations. 
@@ -41,7 +40,90 @@ class TranslatorAdapterBase : public Translator
 
 };
 
-class TranslatorAdapter_1_6_3 : public TranslatorAdapterBase
+class TranslatorAdapter_1_8_2 : public TranslatorAdapterBase
+{
+  public:
+    virtual QCString updateNeededMessage()
+    { return createUpdateNeededMessage(idLanguage(),"release 1.8.2"); }
+
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    { return english.trPanelSynchronisationTooltip(enable); }
+
+    virtual QCString trProvidedByCategory()
+    { return english.trProvidedByCategory(); }
+
+    virtual QCString trExtendsClass()
+    { return english.trExtendsClass(); }
+
+    virtual QCString trClassMethods()
+    { return english.trClassMethods(); }
+
+    virtual QCString trInstanceMethods()
+    { return english.trInstanceMethods(); }
+
+    virtual QCString trMethodDocumentation()
+    { return english.trMethodDocumentation(); }
+
+    virtual QCString trDesignOverview()
+    { return english.trDesignOverview(); }
+};
+
+
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.8.0. 
+ */
+class TranslatorAdapter_1_8_0 : public TranslatorAdapter_1_8_2
+{
+  public:
+    virtual QCString updateNeededMessage()
+    { return createUpdateNeededMessage(idLanguage(),"release 1.8.0"); }
+
+    virtual QCString trDetailLevel()
+    { return english.trDetailLevel(); }
+
+    virtual QCString trTemplateParameters()
+    { return english.trTemplateParameters(); }
+
+    virtual QCString trAndMore(const QCString &number)
+    { return english.trAndMore(number); }
+
+    virtual QCString trEnumGeneratedFromFiles(bool single)
+    { return english.trEnumGeneratedFromFiles(single); }
+
+    virtual QCString trEnumReference(const char *name)
+    { return english.trEnumReference(name); }
+
+    virtual QCString trInheritedFrom(const char *members,const char *what)
+    { return english.trInheritedFrom(members,what); }
+
+    virtual QCString trAdditionalInheritedMembers()
+    { return english.trAdditionalInheritedMembers(); }
+
+};
+
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.7.5.
+ */
+class TranslatorAdapter_1_7_5 : public TranslatorAdapter_1_8_0
+{
+  public:
+    virtual QCString updateNeededMessage()
+    { return createUpdateNeededMessage(idLanguage(),"release 1.7.5"); }
+
+    virtual QCString trCiteReferences()
+    { return english.trCiteReferences(); }
+
+    virtual QCString trCopyright()
+    { return english.trCopyright(); }
+
+    virtual QCString trDirDepGraph(const char *name)
+    { return english.trDirDepGraph(name); }
+};
+
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.6.3.
+ */
+class TranslatorAdapter_1_6_3 : public TranslatorAdapter_1_7_5
 {
   public:
     virtual QCString updateNeededMessage()
@@ -59,6 +141,9 @@ class TranslatorAdapter_1_6_3 : public TranslatorAdapterBase
     { return english.trDateTime(year,month,day,dayOfWeek,hour,minutes,seconds,includeTime); }
 };
 
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.6.0.
+ */
 class TranslatorAdapter_1_6_0 : public TranslatorAdapter_1_6_3
 {
   public:
@@ -81,6 +166,9 @@ class TranslatorAdapter_1_6_0 : public TranslatorAdapter_1_6_3
     { return english.trNoMatches(); }
 };
 
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.5.4
+ */
 class TranslatorAdapter_1_5_4 : public TranslatorAdapter_1_6_0
 {
   public:
@@ -157,6 +245,9 @@ class TranslatorAdapter_1_5_4 : public TranslatorAdapter_1_6_0
     { return english.trTypeConstraints(); }
 };
 
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.4.6
+ */
 class TranslatorAdapter_1_4_6 : public TranslatorAdapter_1_5_4
 {
   public:
@@ -173,6 +264,9 @@ class TranslatorAdapter_1_4_6 : public TranslatorAdapter_1_5_4
     }
 };
 
+/** Adapter class for languages that only contain translations upto 
+ *  version 1.4.1
+ */
 class TranslatorAdapter_1_4_1 : public TranslatorAdapter_1_4_6
 {
   public:
@@ -183,52 +277,5 @@ class TranslatorAdapter_1_4_1 : public TranslatorAdapter_1_4_6
     { return english.trOverloadText(); }
 };
 
-class TranslatorAdapter_1_3_9 : public TranslatorAdapter_1_4_1
-{
-  public:
-    virtual QCString updateNeededMessage()
-    { return createUpdateNeededMessage(idLanguage(),"release 1.3.9"); }
-    
-    virtual QCString trDirIndex()
-    { return english.trDirIndex(); }
-    virtual QCString trDirDocumentation()
-    { return english.trDirDocumentation(); }
-    virtual QCString trDirectories()
-    { return english.trDirectories(); }
-    virtual QCString trDirDescription()
-    { return english.trDirDescription(); }
-    virtual QCString trDirReference(const char *dirName)
-    { return english.trDirReference(dirName); }
-    virtual QCString trDir(bool first_capital, bool singular)
-    { return english.trDir(first_capital,singular); }
-};
-
-class TranslatorAdapter_1_3_8 : public TranslatorAdapter_1_3_9
-{
-  public:
-    virtual QCString updateNeededMessage()
-    { return createUpdateNeededMessage(idLanguage(),"release 1.3.8"); }
-    
-    virtual QCString trSourceFile(QCString& filename)
-    { return english.trSourceFile(filename); }
-};
-
-class TranslatorAdapter_1_3_3 : public TranslatorAdapter_1_3_8
-{
-  public:
-    virtual QCString updateNeededMessage() 
-    { return createUpdateNeededMessage(idLanguage(),"release 1.3.3"); }
-
-    virtual QCString trSearchForIndex()
-    { return english.trSearchForIndex(); }
-    virtual QCString trSearchResultsTitle()
-    { return english.trSearchResultsTitle(); }
-    virtual QCString trSearchResults(int numDocuments)
-    { return english.trSearchResults(numDocuments); }
-    virtual QCString trSearchMatches()
-    { return english.trSearchMatches(); }
-
-};
-
 #endif
 
