@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,7 +24,7 @@
 */
 #define CN_SPC " "
 
-class TranslatorChinese : public Translator
+class TranslatorChinese : public TranslatorAdapter_1_8_2
 {
   public:
     /*! Used for identification of the language. The identification
@@ -543,7 +543,7 @@ class TranslatorChinese : public Translator
         if (i!=numEntries-1)  // not the last entry, so we need a separator
         {
           if (i<numEntries-2) // not the fore last entry 
-            result+=",";
+            result+=","CN_SPC;
           else                // the fore last entry
             result+=CN_SPC", 以及"CN_SPC;
         }
