@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -182,7 +182,7 @@ class TranslatorFinnish : public TranslatorAdapter_1_6_0
 
      /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Lista kaikista jäsenistä."; } // "List of all members."
+    { return "Lista kaikista jäsenistä"; } // "List of all members."
     virtual QCString trMemberList()
 
     /*! used as the title of the "list of all members" page of a class */
