@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -113,7 +113,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Список на сите членови."; }
+    { return "Список на сите членови"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
@@ -1190,7 +1190,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trRTFansicp()
     {
-      return "1252";
+      return "1251";
     }
     
 
@@ -1199,7 +1199,7 @@ class TranslatorMacedonian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trRTFCharSet()
     {
-      return "238";
+      return "204";
     }
 
     /*! Used as header RTF general index */
