@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1736,7 +1736,7 @@ class TranslatorTurkish : public TranslatorAdapter_1_7_5
       QCString result=(QCString)"Bu ";
       switch(compType)
       {
-        case ClassDef::Class:      result+="mdoül"; break;
+        case ClassDef::Class:      result+="modül"; break;
         case ClassDef::Struct:     result+="tip"; break;
         case ClassDef::Union:      result+="birleşim(union)"; break;
         case ClassDef::Interface:  result+="arayüz"; break;
