@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,7 @@
 #include "translator.h"
 #include "portable.h"
 
+/** Decoder adapter for translator file that are not yet UTF-8 encoded. */
 class TranslatorDecoder : public Translator
 {
   public:
@@ -65,11 +66,11 @@ class TranslatorDecoder : public Translator
       QCString output(oSize);
       size_t iLeft     = iSize;
       size_t oLeft     = oSize;
-      const char *iPtr = s.data();
+      char *iPtr       = s.data();
       char *oPtr       = output.data();
       if (!portable_iconv(cd,&iPtr,&iLeft,&oPtr,&oLeft))
       {
-        oSize -= oLeft;
+        oSize -= (int)oLeft;
         output.resize(oSize+1);
         output.at(oSize)='\0';
         return output;
@@ -749,6 +750,44 @@ class TranslatorDecoder : public Translator
     QCString trDirDepGraph(const char *name)
     { return toUtf8(m_translator->trDirDepGraph(fromUtf8(name))); }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.0
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trDetailLevel()
+    { return toUtf8(m_translator->trDetailLevel()); }
+    QCString trTemplateParameters()
+    { return toUtf8(m_translator->trTemplateParameters()); }
+    QCString trAndMore(const QCString &number)
+    { return toUtf8(m_translator->trAndMore(fromUtf8(number))); }
+    QCString trEnumGeneratedFromFiles(bool single)
+    { return toUtf8(m_translator->trEnumGeneratedFromFiles(single)); }
+    QCString trEnumReference(const char *name)
+    { return toUtf8(m_translator->trEnumReference(fromUtf8(name))); }
+    QCString trInheritedFrom(const char *members,const char *what)
+    { return toUtf8(m_translator->trInheritedFrom(fromUtf8(members),fromUtf8(what))); }
+    QCString trAdditionalInheritedMembers()
+    { return toUtf8(m_translator->trAdditionalInheritedMembers()); }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trPanelSynchronisationTooltip(bool enable)
+    { return toUtf8(m_translator->trPanelSynchronisationTooltip(enable)); }
+    QCString trProvidedByCategory()
+    { return toUtf8(m_translator->trProvidedByCategory()); }
+    QCString trExtendsClass()
+    { return toUtf8(m_translator->trExtendsClass()); }
+    QCString trClassMethods()
+    { return toUtf8(m_translator->trClassMethods()); }
+    QCString trInstanceMethods()
+    { return toUtf8(m_translator->trInstanceMethods()); }
+    QCString trMethodDocumentation()
+    { return toUtf8(m_translator->trMethodDocumentation()); }
+    QCString trDesignOverview()
+    { return toUtf8(m_translator->trDesignOverview()); }
+
 //////////////////////////////////////////////////////////////////////////
   private:
     Translator *m_translator;
