@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,11 +22,8 @@
  *  \brief A bunch of utility functions.
  */
 
-#include "qtbc.h"
 #include <qlist.h>
-#include <qtextstream.h>
 #include <ctype.h>
-#include "sortdict.h"
 #include "types.h"
 
 //--------------------------------------------------------------------
@@ -106,7 +103,7 @@ void linkifyText(const TextGeneratorIntf &ol,
                  int indentLevel=0
                 );
 
-void setAnchors(ClassDef *cd,char id,MemberList *ml,int groupId=-1);
+void setAnchors(MemberList *ml);
 
 QCString fileToString(const char *name,bool filter=FALSE,bool isSourceCode=FALSE);
 
@@ -261,13 +258,16 @@ void addMembersToMemberGroup(/* in */     MemberList *ml,
 int extractClassNameFromType(const QCString &type,int &pos,
                               QCString &name,QCString &templSpec,SrcLangExt=SrcLangExt_Unknown);
 
+QCString normalizeNonTemplateArgumentsInString(
+       const QCString &name,
+       Definition *context,
+       const ArgumentList *formalArgs);
+
 QCString substituteTemplateArgumentsInString(
        const QCString &name,
        ArgumentList *formalArgs,
        ArgumentList *actualArgs);
 
-ArgumentList *copyArgumentList(const ArgumentList *src);
-
 QList<ArgumentList> *copyArgumentLists(const QList<ArgumentList> *srcLists);
 
 QCString stripTemplateSpecifiersFromScope(const QCString &fullName,
