@@ -1,8 +1,6 @@
 /******************************************************************************
  *
- * $Id: vhdlscanner.h,v 1.9 2001/03/19 19:27:39 root Exp $
- *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -26,29 +24,21 @@
 #include <qdict.h>
 #include <qcstring.h>
 #include "layout.h"
-#include "memberlist.h"
+#include "arguments.h"
 
-class QStringList;
 class Entry;
-class ClassSDict;
-class FileStorage;
-class EntryNav;
 class ClassDef;
+class MemberList;
 class MemberDef;
+class FTextStream;
+class OutputList;
+class Definition;
+class GroupDef;
+class FileDef;
+class NamespaceDef;
+struct Argument;
 
-// wrapper class for the vhdl parser
-class MyParserVhdl 
-{
-  public:
-  uint iFileSize; 
-
-  ~MyParserVhdl(){}
-  MyParserVhdl(){}
-  
- int parse(MyParserVhdl*);
- int doLex();
- }; 
-
+/** Class for generating documentation specific for VHDL */
 class VhdlDocGen  
 {
   public:
@@ -82,27 +72,25 @@ class VhdlDocGen
       PORT,
       UNITS,	  
       GENERIC,
-      COMPONENT_INST,
+      INSTANTIATION,
       GROUP,
       VFILE,   
       SHAREDVARIABLE,
       CONFIG,
       ALIAS,
-	  MISCELLANEOUS,
-	  UCF_CONST
+      MISCELLANEOUS,
+      UCF_CONST
     };
 
-
-
-
     VhdlDocGen();
     virtual ~VhdlDocGen();
     static void init();
- static QCString convertFileNameToClassName(QCString name);
+    static QCString convertFileNameToClassName(QCString name);
     // --- used by vhdlscanner.l -----------
     
+    static bool isSubClass(ClassDef* cd,ClassDef *scd, bool followInstances,int level);
+
     static QCString getIndexWord(const char* ,int index);
-    static  bool    foundInsertedComponent(const QCString& name,Entry* root);
     static bool     deleteCharRev(QCString &s,char c);
     static void     deleteAllChars(QCString &s,char c);
     static void     parseFuncProto(const char* text,
@@ -112,13 +100,10 @@ class VhdlDocGen
                                    bool doc=false);
     // -----------------------------------
 
-
     static void computeVhdlComponentRelations();
 
-
     static QCString* findKeyWord(const QCString& word);
 
-
     static ClassDef* getPackageName(const QCString& name);
     static MemberDef* findMember(const QCString& className, 
                                  const QCString& memName);
@@ -126,72 +111,44 @@ class VhdlDocGen
                                 QDict<QCString>&);
     static MemberDef* findMemberDef(ClassDef* cd,
                                 const QCString& key,
-                                MemberList::ListType type);
+                                MemberListType type);
     static ClassDef *getClass(const char *name);
     static MemberDef* findFunction(const QList<Argument> &ql,
                                    const QCString& name,
                                    const QCString& package, bool type);
-    static bool compareString(const QCString& s1,
-                              const QCString& s2);
+    static int compareString(const QCString& s1,
+                             const QCString& s2);
     static QCString getClassTitle(const ClassDef*);
     static void writeInlineClassLink(const ClassDef*,
                                      OutputList &ol);
 
-
-    static bool isConstraint(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::UCF_CONST; }   
-    static bool isConfig(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::CONFIG; }
-    static bool isAlias(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::ALIAS; }
-    static bool isLibrary(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::LIBRARY; }
-    static bool isGeneric(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::GENERIC; }
-    static bool isPort(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::PORT; }
-    static bool isComponent(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::COMPONENT; }
-    static bool isPackage(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::USE; }
-    static bool isEntity(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::ENTITY; }
-    static bool isConstant(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::CONSTANT; }
-    static bool isVType(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::TYPE; }
-    static bool isSubType(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::SUBTYPE; }
-    static bool isVhdlFunction(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::FUNCTION; }
-    static bool isProcess(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::PROCESS; }
-    static bool isSignal(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::SIGNAL; }
-    static bool isAttribute(const MemberDef *mdef)
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::ATTRIBUTE; }
-    static bool isSignals(const MemberDef *mdef)
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::SIGNAL; }
-    static bool isProcedure(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::PROCEDURE; }
-    static bool isRecord(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::RECORD; }
-    static bool isArchitecture(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::ARCHITECTURE; }
-    static bool isUnit(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::UNITS; }
-    static bool isPackageBody(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::PACKAGE_BODY; }
-    static bool isVariable(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::SHAREDVARIABLE; }
-    static bool isFile(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::VFILE; }
-    static bool isGroup(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::GROUP; }
-    static bool isCompInst(const MemberDef *mdef) 
-    { return mdef->getMemberSpecifiers()==VhdlDocGen::COMPONENT_INST; }
-static bool isMisc(const MemberDef *mdef) 
-{ return mdef->getMemberSpecifiers()==VhdlDocGen::MISCELLANEOUS; }
+    static bool isConstraint(const MemberDef *mdef);
+    static bool isConfig(const MemberDef *mdef);
+    static bool isAlias(const MemberDef *mdef);
+    static bool isLibrary(const MemberDef *mdef);
+    static bool isGeneric(const MemberDef *mdef);
+    static bool isPort(const MemberDef *mdef);
+    static bool isComponent(const MemberDef *mdef);
+    static bool isPackage(const MemberDef *mdef);
+    static bool isEntity(const MemberDef *mdef);
+    static bool isConstant(const MemberDef *mdef);
+    static bool isVType(const MemberDef *mdef);
+    static bool isSubType(const MemberDef *mdef);
+    static bool isVhdlFunction(const MemberDef *mdef);
+    static bool isProcess(const MemberDef *mdef);
+    static bool isSignal(const MemberDef *mdef);
+    static bool isAttribute(const MemberDef *mdef);
+    static bool isSignals(const MemberDef *mdef);
+    static bool isProcedure(const MemberDef *mdef);
+    static bool isRecord(const MemberDef *mdef);
+    static bool isArchitecture(const MemberDef *mdef);
+    static bool isUnit(const MemberDef *mdef);
+    static bool isPackageBody(const MemberDef *mdef);
+    static bool isVariable(const MemberDef *mdef);
+    static bool isFile(const MemberDef *mdef);
+    static bool isGroup(const MemberDef *mdef);
+    static bool isCompInst(const MemberDef *mdef);
+    static bool isMisc(const MemberDef *mdef);
 
     //-----------------------------------------------------
     // translatable items
@@ -220,25 +177,19 @@ static bool isMisc(const MemberDef *mdef)
     // trFunctions
     static QCString trFunctionAndProc();
 
-
     //-----------------------------------------------------
 
     static void prepareComment(QCString&);
-    
-	
- 
-    static void formatString(QCString&,OutputList& ol,const MemberDef*);
+    static void formatString(const QCString&,OutputList& ol,const MemberDef*);
 
-    static void writeFormatString(QCString&,OutputList& ol,const MemberDef*);
+    static void writeFormatString(const QCString&,OutputList& ol,const MemberDef*);
     static void writeFunctionProto(OutputList& ol,const ArgumentList *al,const MemberDef*);
     static void writeProcessProto(OutputList& ol,const ArgumentList *al,const MemberDef*);
     static void writeProcedureProto(OutputList& ol, const ArgumentList *al,const MemberDef*);
-    static void writeFuncProcDocu(const MemberDef *mdef, OutputList& ol,const ArgumentList* al,bool type=false);
+    static bool writeFuncProcDocu(const MemberDef *mdef, OutputList& ol,const ArgumentList* al,bool type=false);
     static void writeRecordProto(const MemberDef *mdef, OutputList& ol,const ArgumentList *al);
 
-
-
-    static void writeVHDLTypeDocumentation(const MemberDef* mdef, const Definition* d, OutputList &ol);
+    static bool writeVHDLTypeDocumentation(const MemberDef* mdef, const Definition* d, OutputList &ol);
 
     static void writeVhdlDeclarations(MemberList*,OutputList&,GroupDef*,ClassDef*,FileDef*,NamespaceDef*);
 
@@ -261,7 +212,8 @@ static bool isMisc(const MemberDef *mdef)
     static QCString getRecordNumber();
    
     static QCString getClassName(const ClassDef*);
-    static void adjustRecordMember(MemberDef *mdef);
+    // obsolete
+    // static void adjustRecordMember(MemberDef *mdef);
 
     static void writeLink(const MemberDef* mdef,OutputList &ol);
     static void adjustMemberName(QCString& nn);
@@ -272,26 +224,122 @@ static bool isMisc(const MemberDef *mdef)
     static QCString splitString(QCString & str,  char c);
     static void parseUCF(const char*  input,Entry* entity,QCString f,bool vendor);
 	
-	
     static bool findConstraintFile( LayoutNavEntry *lne);
 
     static ClassDef*  findArchitecture(const ClassDef *cd);
     static ClassDef*  findArchitecture(QCString identifier, QCString entity_name);
 
     static void writeCodeFragment( MemberDef *mdef,OutputList& ol);
+    static void writeCodeFragment (OutputList& ol,int start, QCString & codeFragment,const MemberDef* mdef);
+
     static void writeSource(MemberDef *mdef,OutputList& ol,QCString & cname);
     static void writeAlphbeticalClass(OutputList& ol,const ClassDef* cd,const QCString &);
 
+    static QCString  parseForConfig(QCString & entity,QCString & arch);
+    static QCString  parseForBinding(QCString & entity,QCString & arch);
+    static void addBaseClass(ClassDef* cd,ClassDef *ent);
+    static ClassDef* findVhdlClass(const char *className );
+
+    static void writeOverview(OutputList &ol);
+    static void writeOverview();
+ 
+ // flowcharts
+    static void createFlowChart(const MemberDef*);
+    //static void addFlowImage(const FTextStream &,const QCString &);
+    
+    static void setFlowMember( const MemberDef *flowMember);
+    static const MemberDef *getFlowMember();
 
-	static QCString  parseForConfig(QCString & entity,QCString & arch);
-	static QCString  parseForBinding(QCString & entity,QCString & arch);
   private:
     static void findAllArchitectures(QList<QCString>& ql,const ClassDef *cd);
     static bool compareArgList(ArgumentList*,ArgumentList*);
     static void writeVhdlLink(const ClassDef* cdd ,OutputList& ol,QCString& type,QCString& name,QCString& beh);
     static void writeStringLink(const MemberDef *mdef,QCString mem,OutputList& ol);
-	static void writeRecUnitDocu( const MemberDef *md, OutputList& ol,QCString largs);
-	static void  writeRecorUnit(QCString & largs,OutputList& ol ,const MemberDef *mdef);
+    static void writeRecUnitDocu( const MemberDef *md, OutputList& ol,QCString largs);
+    static void  writeRecorUnit(QCString & largs,OutputList& ol ,const MemberDef *mdef);
+};
+
+//#define DEBUGFLOW
+
+class FlowChart
+{
+  public:
+    enum nodeTypes {
+      IF_NO        = 1<<1,
+      ELSIF_NO     = 1<<2,
+      ELSE_NO      = 1<<3,
+      CASE_NO      = 1<<4,
+      WHEN_NO      = 1<<5,
+      EXIT_NO      = 1<<6,
+      END_NO       = 1<<7,
+      TEXT_NO      = 1<<8,
+      START_NO     = 1<<9,
+      ENDIF_NO     = 1<<10,
+      FOR_NO       = 1<<11,
+      WHILE_NO     = 1<<12,
+      END_LOOP     = 1<<13,
+      END_CASE     = 1<<14,
+      VARIABLE_NO  = 1<<15,
+      RETURN_NO    = 1<<16,
+      LOOP_NO      = 1<<17,
+      NEXT_NO      = 1<<18,
+      EMPTY_NO     = 1<<19,
+      COMMENT_NO   = 1<<20,
+      BEGIN_NO     = 1<<21
+    };
+
+    //---------- create svg ------------------------------------------------------------- 
+    static void createSVG();
+    static void startDot(FTextStream &t);
+    static void endDot(FTextStream &t);
+    static void codify(FTextStream &t,const char *str);
+    static void writeShape(FTextStream &t,const FlowChart* fl);
+    static void writeEdge(FTextStream &t,int fl_from,int fl_to,int i,bool bFrom=FALSE,bool bTo=FALSE);
+    static void writeEdge(FTextStream &t,const FlowChart* fl_from,const FlowChart* fl_to,int i);
+    static void writeFlowLinks(FTextStream &t);
+
+    static QCString getNodeName(int n);
+    static void colTextNodes();
+
+    static int getNextTextLink(const FlowChart* fl,uint index);
+    static int getNextIfLink(const FlowChart*,uint);
+    static int getNextNode(int,int);
+    static int findNode(int index,int stamp,int type);
+    static int findNode(int index,int type);
+    static int findNextLoop(int j,int stamp);
+    static int findPrevLoop(int j,int stamp,bool endif=FALSE);
+    static int findLabel(int j,QCString &);
+    static void delFlowList();
+    static const char* getNodeType(int c);
+
+    static void addFlowChart(int type,const char* text,const char* exp,const char * label=NULL);
+    static void moveToPrevLevel();
+    static int getTimeStamp();
+    static void writeFlowChart();
+    static void alignFuncProc(QCString & q,const ArgumentList*  al,bool isFunc);
+    static QCString convertNameToFileName();
+    static void printNode(const FlowChart* n);
+    static void printFlowTree();
+    static void buildCommentNodes(FTextStream &t);
+    static void alignCommentNode(FTextStream &t,QCString com);
+
+    static QList<FlowChart> flowList;
+
+    FlowChart(int typ,const char*  t,const char* ex,const char* label=0);
+    ~FlowChart();
+
+private:
+    int id;
+    int stamp;
+    int type;
+
+#ifdef DEBUGFLOW  
+    int line;
+#endif
+
+    QCString label;
+    QCString text;
+    QCString exp;
 };
 
 #endif
