@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -15,7 +15,11 @@
 
 #include <stdlib.h>
 
-#include "qtbc.h"
+#include <qdir.h>
+#include <qfile.h>
+#include <qtextstream.h>
+#include <qintdict.h>
+
 #include "xmlgen.h"
 #include "doxygen.h"
 #include "message.h"
@@ -32,11 +36,15 @@
 #include "docparser.h"
 #include "language.h"
 #include "parserintf.h"
-
-#include <qdir.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qintdict.h>
+#include "arguments.h"
+#include "memberlist.h"
+#include "groupdef.h"
+#include "memberdef.h"
+#include "namespacedef.h"
+#include "membername.h"
+#include "membergroup.h"
+#include "dirdef.h"
+#include "section.h"
 
 // no debug info
 #define XML_DB(x) do {} while(0)
@@ -59,46 +67,47 @@ static const char compound_xsd[] =
 
 //------------------
 
+/** Helper class mapping MemberList::ListType to a string representing */
 class XmlSectionMapper : public QIntDict<char>
 {
   public:
     XmlSectionMapper() : QIntDict<char>(47)
     {
-      insert(MemberList::pubTypes,"public-type");
-      insert(MemberList::pubMethods,"public-func");
-      insert(MemberList::pubAttribs,"public-attrib");
-      insert(MemberList::pubSlots,"public-slot");
-      insert(MemberList::signals,"signal");
-      insert(MemberList::dcopMethods,"dcop-func");
-      insert(MemberList::properties,"property");
-      insert(MemberList::events,"event");
-      insert(MemberList::pubStaticMethods,"public-static-func");
-      insert(MemberList::pubStaticAttribs,"public-static-attrib");
-      insert(MemberList::proTypes,"protected-type");
-      insert(MemberList::proMethods,"protected-func");
-      insert(MemberList::proAttribs,"protected-attrib");
-      insert(MemberList::proSlots,"protected-slot");
-      insert(MemberList::proStaticMethods,"protected-static-func");
-      insert(MemberList::proStaticAttribs,"protected-static-attrib");
-      insert(MemberList::pacTypes,"package-type");
-      insert(MemberList::pacMethods,"package-func");
-      insert(MemberList::pacAttribs,"package-attrib");
-      insert(MemberList::pacStaticMethods,"package-static-func");
-      insert(MemberList::pacStaticAttribs,"package-static-attrib");
-      insert(MemberList::priTypes,"private-type");
-      insert(MemberList::priMethods,"private-func");
-      insert(MemberList::priAttribs,"private-attrib");
-      insert(MemberList::priSlots,"private-slot");
-      insert(MemberList::priStaticMethods,"private-static-func");
-      insert(MemberList::priStaticAttribs,"private-static-attrib");
-      insert(MemberList::friends,"friend");
-      insert(MemberList::related,"related");
-      insert(MemberList::decDefineMembers,"define");
-      insert(MemberList::decProtoMembers,"prototype");
-      insert(MemberList::decTypedefMembers,"typedef");
-      insert(MemberList::decEnumMembers,"enum");
-      insert(MemberList::decFuncMembers,"func");
-      insert(MemberList::decVarMembers,"var");
+      insert(MemberListType_pubTypes,"public-type");
+      insert(MemberListType_pubMethods,"public-func");
+      insert(MemberListType_pubAttribs,"public-attrib");
+      insert(MemberListType_pubSlots,"public-slot");
+      insert(MemberListType_signals,"signal");
+      insert(MemberListType_dcopMethods,"dcop-func");
+      insert(MemberListType_properties,"property");
+      insert(MemberListType_events,"event");
+      insert(MemberListType_pubStaticMethods,"public-static-func");
+      insert(MemberListType_pubStaticAttribs,"public-static-attrib");
+      insert(MemberListType_proTypes,"protected-type");
+      insert(MemberListType_proMethods,"protected-func");
+      insert(MemberListType_proAttribs,"protected-attrib");
+      insert(MemberListType_proSlots,"protected-slot");
+      insert(MemberListType_proStaticMethods,"protected-static-func");
+      insert(MemberListType_proStaticAttribs,"protected-static-attrib");
+      insert(MemberListType_pacTypes,"package-type");
+      insert(MemberListType_pacMethods,"package-func");
+      insert(MemberListType_pacAttribs,"package-attrib");
+      insert(MemberListType_pacStaticMethods,"package-static-func");
+      insert(MemberListType_pacStaticAttribs,"package-static-attrib");
+      insert(MemberListType_priTypes,"private-type");
+      insert(MemberListType_priMethods,"private-func");
+      insert(MemberListType_priAttribs,"private-attrib");
+      insert(MemberListType_priSlots,"private-slot");
+      insert(MemberListType_priStaticMethods,"private-static-func");
+      insert(MemberListType_priStaticAttribs,"private-static-attrib");
+      insert(MemberListType_friends,"friend");
+      insert(MemberListType_related,"related");
+      insert(MemberListType_decDefineMembers,"define");
+      insert(MemberListType_decProtoMembers,"prototype");
+      insert(MemberListType_decTypedefMembers,"typedef");
+      insert(MemberListType_decEnumMembers,"enum");
+      insert(MemberListType_decFuncMembers,"func");
+      insert(MemberListType_decVarMembers,"var");
     }
 };
 
@@ -119,8 +128,8 @@ inline void writeXMLCodeString(FTextStream &t,const char *s, int &col)
     {
       case '\t': 
       { 
-	int spacesToNextTabStop = 
-          Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE")); 
+        static int tabSize = Config_getInt("TAB_SIZE");
+	int spacesToNextTabStop = tabSize - (col%tabSize); 
 	col+=spacesToNextTabStop;
 	while (spacesToNextTabStop--) t << "<sp/>";
 	break;
@@ -192,6 +201,7 @@ void writeXMLLink(FTextStream &t,const char *extRef,const char *compoundId,
   t << "</ref>";
 }
 
+/** Implements TextGeneratorIntf for an XML stream. */
 class TextGeneratorXMLImpl : public TextGeneratorIntf
 {
   public:
@@ -211,6 +221,7 @@ class TextGeneratorXMLImpl : public TextGeneratorIntf
     FTextStream &m_t;
 };
 
+/** Helper class representing a stack of objects stored by value */
 template<class T> class ValStack
 {
   public:
@@ -264,7 +275,7 @@ template<class T> class ValStack
     int m_size;
 };
 
-
+/** Generator for producing XML formatted source code. */
 class XMLCodeGenerator : public CodeOutputInterface
 {
   public:
@@ -295,9 +306,9 @@ class XMLCodeGenerator : public CodeOutputInterface
         m_normalHLNeedStartTag=FALSE;
       }
       writeXMLLink(m_t,ref,file,anchor,name,tooltip);
-      col+=strlen(name);
+      col+=qstrlen(name);
     }
-    void startCodeLine() 
+    void startCodeLine(bool) 
     {
       XML_DB(("(startCodeLine)\n"));
       m_t << "<codeline";
@@ -393,6 +404,12 @@ class XMLCodeGenerator : public CodeOutputInterface
     void linkableSymbol(int, const char *,Definition *,Definition *) 
     {
     }
+    void setCurrentDoc(Definition *,const char *,bool)
+    {
+    }
+    void addWord(const char *,bool)
+    {
+    }
 
     void finish()
     {
@@ -585,7 +602,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
   // - call graph
   
   // enum values are written as part of the enum
-  if (md->memberType()==MemberDef::EnumValue) return;
+  if (md->memberType()==MemberType_EnumValue) return;
   if (md->isHidden()) return;
   //if (md->name().at(0)=='@') return; // anonymous member
 
@@ -596,18 +613,18 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
   bool isFunc=FALSE;
   switch (md->memberType())
   {
-    case MemberDef::Define:      memType="define";    break;
-    case MemberDef::EnumValue:   ASSERT(0);           break;
-    case MemberDef::Property:    memType="property";  break;
-    case MemberDef::Event:       memType="event";     break;
-    case MemberDef::Variable:    memType="variable";  break;
-    case MemberDef::Typedef:     memType="typedef";   break;
-    case MemberDef::Enumeration: memType="enum";      break;
-    case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
-    case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-    case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
-    case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
-    case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
+    case MemberType_Define:      memType="define";    break;
+    case MemberType_EnumValue:   ASSERT(0);           break;
+    case MemberType_Property:    memType="property";  break;
+    case MemberType_Event:       memType="event";     break;
+    case MemberType_Variable:    memType="variable";  break;
+    case MemberType_Typedef:     memType="typedef";   break;
+    case MemberType_Enumeration: memType="enum";      break;
+    case MemberType_Function:    memType="function";  isFunc=TRUE; break;
+    case MemberType_Signal:      memType="signal";    isFunc=TRUE; break;
+    case MemberType_Friend:      memType="friend";    isFunc=TRUE; break;
+    case MemberType_DCOP:        memType="dcop";      isFunc=TRUE; break;
+    case MemberType_Slot:        memType="slot";      isFunc=TRUE; break;
   }
 
   ti << "    <member refid=\"" << memberOutputFileBase(md) 
@@ -698,7 +715,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
     t << "\"";
   }
 
-  if (md->memberType() == MemberDef::Variable)
+  if (md->memberType() == MemberType_Variable)
   {
     //ArgumentList *al = md->argumentList();
     //t << " volatile=\"";
@@ -714,7 +731,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
     }
     
   }
-  else if (md->memberType() == MemberDef::Property)
+  else if (md->memberType() == MemberType_Property)
   {
     t << " readable=\"";
     if (md->isReadable()) t << "yes"; else t << "no";
@@ -732,16 +749,18 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
     if (md->isSettable()) t << "yes"; else t << "no";
     t << "\"";
 
-    if (md->isAssign() || md->isCopy() || md->isRetain())
+    if (md->isAssign() || md->isCopy() || md->isRetain() || md->isStrong() || md->isWeak())
     {
       t << " accessor=\"";
-      if (md->isAssign()) t << "assign";
-      else if (md->isCopy()) t << "copy";
+      if (md->isAssign())      t << "assign";
+      else if (md->isCopy())   t << "copy";
       else if (md->isRetain()) t << "retain";
+      else if (md->isStrong()) t << "strong";
+      else if (md->isWeak())   t << "weak";
       t << "\"";
     }
   }
-  else if (md->memberType() == MemberDef::Event)
+  else if (md->memberType() == MemberType_Event)
   {
     t << " add=\"";
     if (md->isAddable()) t << "yes"; else t << "no";
@@ -758,18 +777,18 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
 
   t << ">" << endl;
 
-  if (md->memberType()!=MemberDef::Define &&
-      md->memberType()!=MemberDef::Enumeration
+  if (md->memberType()!=MemberType_Define &&
+      md->memberType()!=MemberType_Enumeration
      )
   {
-    if (md->memberType()!=MemberDef::Typedef)
+    if (md->memberType()!=MemberType_Typedef)
     {
       writeMemberTemplateLists(md,t);
     }
     QCString typeStr = md->typeString(); //replaceAnonymousScopes(md->typeString());
     stripQualifiers(typeStr);
     t << "        <type>";
-    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),typeStr);
+    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,typeStr);
     t << "</type>" << endl;
     t << "        <definition>" << convertToXML(md->definition()) << "</definition>" << endl;
     t << "        <argsstring>" << convertToXML(md->argsString()) << "</argsstring>" << endl;
@@ -777,14 +796,14 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
 
   t << "        <name>" << convertToXML(md->name()) << "</name>" << endl;
   
-  if (md->memberType() == MemberDef::Property)
+  if (md->memberType() == MemberType_Property)
   {
     if (md->isReadable())
       t << "        <read>" << convertToXML(md->getReadAccessor()) << "</read>" << endl;
     if (md->isWritable())
       t << "        <write>" << convertToXML(md->getWriteAccessor()) << "</write>" << endl;
   }
-  if (md->memberType()==MemberDef::Variable && md->bitfieldString())
+  if (md->memberType()==MemberType_Variable && md->bitfieldString())
   {
     QCString bitfield = md->bitfieldString();
     if (bitfield.at(0)==':') bitfield=bitfield.mid(1);
@@ -832,7 +851,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
         if (!a->type.isEmpty())
         {
           t << "          <type>";
-          linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),a->type);
+          linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,a->type);
           t << "</type>" << endl;
         }
         if (!a->name.isEmpty())
@@ -856,7 +875,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
         if (!a->defval.isEmpty())
         {
           t << "          <defval>";
-          linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),a->defval);
+          linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,a->defval);
           t << "</defval>" << endl;
         }
         if (defArg && defArg->hasDocumentation())
@@ -871,7 +890,7 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
       }
     }
   }
-  else if (md->memberType()==MemberDef::Define && 
+  else if (md->memberType()==MemberType_Define && 
           md->argsString()) // define
   {
     if (md->argumentList()->count()==0) // special case for "foo()" to
@@ -894,18 +913,18 @@ static void generateXMLForMember(MemberDef *md,FTextStream &ti,FTextStream &t,De
   if (!md->initializer().isEmpty() && md->initializer().length()<2000)
   {
     t << "        <initializer>";
-    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),md->initializer());
+    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,md->initializer());
     t << "</initializer>" << endl;
   }
 
   if (md->excpString())
   {
     t << "        <exceptions>";
-    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md->name(),md->excpString());
+    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,md->excpString());
     t << "</exceptions>" << endl;
   }
   
-  if (md->memberType()==MemberDef::Enumeration) // enum
+  if (md->memberType()==MemberType_Enumeration) // enum
   {
     LockingPtr<MemberList> enumFields = md->enumFieldList();
     if (enumFields!=0)
@@ -1214,6 +1233,7 @@ static void generateXMLForClass(ClassDef *cd,FTextStream &ti)
   if (cd->isHidden())           return; // skip hidden classes.
   if (cd->name().find('@')!=-1) return; // skip anonymous compounds.
   if (cd->templateMaster()!=0)  return; // skip generated template instances.
+  if (cd->isArtificial())       return; // skip artificially created classes
 
   msg("Generating XML output for class %s\n",cd->name().data());
 
@@ -1243,6 +1263,9 @@ static void generateXMLForClass(ClassDef *cd,FTextStream &ti)
     case Private:   t << "private";   break;
     case Package:   t << "package";   break;
   }
+  if (cd->isFinal()) t << "\" final=\"yes";
+  if (cd->isSealed()) t << "\" sealed=\"yes";
+  if (cd->isAbstract()) t << "\" abstract=\"yes";
   t << "\">" << endl;
   t << "    <compoundname>"; 
   writeXMLString(t,cd->name()); 
@@ -1352,7 +1375,7 @@ static void generateXMLForClass(ClassDef *cd,FTextStream &ti)
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if ((ml->listType()&MemberList::detailedLists)==0)
+    if ((ml->listType()&MemberListType_detailedLists)==0)
     {
       generateXMLSection(cd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
     }
@@ -1483,7 +1506,7 @@ static void generateXMLForNamespace(NamespaceDef *nd,FTextStream &ti)
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if ((ml->listType()&MemberList::declarationLists)!=0)
+    if ((ml->listType()&MemberListType_declarationLists)!=0)
     {
       generateXMLSection(nd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
     }
@@ -1626,7 +1649,7 @@ static void generateXMLForFile(FileDef *fd,FTextStream &ti)
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if ((ml->listType()&MemberList::declarationLists)!=0)
+    if ((ml->listType()&MemberListType_declarationLists)!=0)
     {
       generateXMLSection(fd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
     }
@@ -1716,7 +1739,7 @@ static void generateXMLForGroup(GroupDef *gd,FTextStream &ti)
   MemberList *ml;
   for (mli.toFirst();(ml=mli.current());++mli)
   {
-    if ((ml->listType()&MemberList::declarationLists)!=0)
+    if ((ml->listType()&MemberListType_declarationLists)!=0)
     {
       generateXMLSection(gd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
     }
@@ -1819,10 +1842,26 @@ static void generateXMLForPage(PageDef *pd,FTextStream &ti,bool isExample)
   t << "    <compoundname>" << convertToXML(pd->name()) 
     << "</compoundname>" << endl;
 
-  SectionInfo *si = Doxygen::sectionDict.find(pd->name());
-  if (si)
+  if (pd==Doxygen::mainPage) // main page is special
   {
-    t << "    <title>" << convertToXML(si->title) << "</title>" << endl;
+    QCString title;
+    if (!pd->title().isEmpty() && pd->title().lower()!="notitle")
+    {
+      title = filterTitle(Doxygen::mainPage->title());
+    }
+    else 
+    {
+      title = Config_getString("PROJECT_NAME");
+    }
+    t << "    <title>" << convertToXML(title) << "</title>" << endl;
+  }
+  else
+  {
+    SectionInfo *si = Doxygen::sectionDict->find(pd->name());
+    if (si)
+    {
+      t << "    <title>" << convertToXML(si->title) << "</title>" << endl;
+    }
   }
   writeInnerPages(pd->getSubPages(),t);
   t << "    <detaileddescription>" << endl;
@@ -1857,7 +1896,7 @@ void generateXML()
   QCString outputDirectory = Config_getString("XML_OUTPUT");
   if (outputDirectory.isEmpty())
   {
-    outputDirectory=QDir::currentDirPath();
+    outputDirectory=QDir::currentDirPath().utf8();
   }
   else
   {
@@ -1878,7 +1917,7 @@ void generateXML()
       }
       dir.cd(outputDirectory);
     }
-    outputDirectory=dir.absPath();
+    outputDirectory=dir.absPath().utf8();
   }
 
   QDir dir(outputDirectory);
@@ -1900,7 +1939,7 @@ void generateXML()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  f.writeBlock(index_xsd,strlen(index_xsd));
+  f.writeBlock(index_xsd,qstrlen(index_xsd));
   f.close();
 
   fileName=outputDirectory+"/compound.xsd";
@@ -1910,7 +1949,7 @@ void generateXML()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  f.writeBlock(compound_xsd,strlen(compound_xsd));
+  f.writeBlock(compound_xsd,qstrlen(compound_xsd));
   f.close();
 
   fileName=outputDirectory+"/index.xml";
